/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_M3NGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_M3NGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_M3NGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_M3NGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_M3NGLR::Heavy_WSTD_M3NGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_8gpLsLxH);
  numBytes += sLine_init(&sLine_xKTUl20e);
  numBytes += sLine_init(&sLine_1BFSvd7e);
  numBytes += sLine_init(&sLine_S8oitVEB);
  numBytes += sLine_init(&sLine_IjY6WXbY);
  numBytes += sBiquad_init(&sBiquad_s_vMzzKipS);
  numBytes += sLine_init(&sLine_3GE3uPId);
  numBytes += sLine_init(&sLine_sXWwoWC5);
  numBytes += sLine_init(&sLine_BwceLg0b);
  numBytes += sLine_init(&sLine_dhPTGs5Z);
  numBytes += sLine_init(&sLine_e4C4VoPu);
  numBytes += sBiquad_init(&sBiquad_s_4wsJdvgg);
  numBytes += sLine_init(&sLine_Rds01OCF);
  numBytes += sLine_init(&sLine_koqR3SLU);
  numBytes += sLine_init(&sLine_aCddIJlP);
  numBytes += sLine_init(&sLine_XC1pk1Pj);
  numBytes += sLine_init(&sLine_XkP9wYM6);
  numBytes += sLine_init(&sLine_nZCXD3W8);
  numBytes += sBiquad_init(&sBiquad_s_sQ8A27L8);
  numBytes += sLine_init(&sLine_FB4Lp3v4);
  numBytes += sLine_init(&sLine_AOhYMSCx);
  numBytes += sLine_init(&sLine_0qtg9GTz);
  numBytes += sLine_init(&sLine_hJe11JTT);
  numBytes += sLine_init(&sLine_fIk6GPA8);
  numBytes += sLine_init(&sLine_0TXHjwy5);
  numBytes += sBiquad_init(&sBiquad_s_45oztHpv);
  numBytes += sLine_init(&sLine_S41LmQHg);
  numBytes += sLine_init(&sLine_YsOK3q8m);
  numBytes += sLine_init(&sLine_LxPvXehJ);
  numBytes += sLine_init(&sLine_TYdsVxTG);
  numBytes += sLine_init(&sLine_EiYTq00V);
  numBytes += sBiquad_init(&sBiquad_s_eXUYnWl9);
  numBytes += sLine_init(&sLine_GKuUAZRb);
  numBytes += sLine_init(&sLine_wOBivBL0);
  numBytes += sLine_init(&sLine_J3LuU9yn);
  numBytes += sLine_init(&sLine_rei1ZE9S);
  numBytes += sLine_init(&sLine_VIRQ1hLE);
  numBytes += sLine_init(&sLine_tFOJ0HXl);
  numBytes += sBiquad_init(&sBiquad_s_27ECAHYi);
  numBytes += sLine_init(&sLine_gD0ejcST);
  numBytes += sLine_init(&sLine_8bVpYlcl);
  numBytes += sLine_init(&sLine_6fu6NTyW);
  numBytes += sLine_init(&sLine_2IVthB2H);
  numBytes += sLine_init(&sLine_u37Nps0Z);
  numBytes += sLine_init(&sLine_NeHOBh6o);
  numBytes += sLine_init(&sLine_Opn4Jii6);
  numBytes += sLine_init(&sLine_cekNCDO8);
  numBytes += sLine_init(&sLine_MJGn8zBx);
  numBytes += sLine_init(&sLine_uVjYDY1T);
  numBytes += sLine_init(&sLine_Mhu9rxNI);
  numBytes += sLine_init(&sLine_WJNjnM0b);
  numBytes += sLine_init(&sLine_1UyiRAFS);
  numBytes += sLine_init(&sLine_NScTiuMk);
  numBytes += sLine_init(&sLine_hn2kkQd5);
  numBytes += sEnv_init(&sEnv_Gd2P1O9f, 512, 256);
  numBytes += sEnv_init(&sEnv_hU5NBXq2, 512, 256);
  numBytes += sLine_init(&sLine_7JfwaUPA);
  numBytes += sLine_init(&sLine_EU04SOaF);
  numBytes += sLine_init(&sLine_m3LvETdm);
  numBytes += sLine_init(&sLine_oS6FfjSh);
  numBytes += sLine_init(&sLine_OmSc8pO4);
  numBytes += sLine_init(&sLine_fZO0Ig5m);
  numBytes += sLine_init(&sLine_SbSYLvwI);
  numBytes += sLine_init(&sLine_XFQ13COj);
  numBytes += sLine_init(&sLine_NolKfIJy);
  numBytes += sLine_init(&sLine_ai4Rrm7G);
  numBytes += sLine_init(&sLine_HBTMyIZf);
  numBytes += sLine_init(&sLine_N3hcnKQo);
  numBytes += sLine_init(&sLine_xjcHCRuk);
  numBytes += sLine_init(&sLine_8YJRabq6);
  numBytes += sLine_init(&sLine_REDl5Uqi);
  numBytes += sLine_init(&sLine_3RXeUR7A);
  numBytes += sLine_init(&sLine_Mb0pdEZa);
  numBytes += sLine_init(&sLine_UqEeyZfd);
  numBytes += sEnv_init(&sEnv_3SELgnaC, 512, 256);
  numBytes += sEnv_init(&sEnv_cEiuOTs7, 512, 256);
  numBytes += sLine_init(&sLine_jtDRkTkJ);
  numBytes += sLine_init(&sLine_DarPhv4Q);
  numBytes += sLine_init(&sLine_ga5m3mKQ);
  numBytes += sLine_init(&sLine_aEeksWFX);
  numBytes += sLine_init(&sLine_64gJ7tKS);
  numBytes += sLine_init(&sLine_PcSQ6FKx);
  numBytes += sLine_init(&sLine_eCfaiA5m);
  numBytes += sLine_init(&sLine_ejDWa4FM);
  numBytes += sLine_init(&sLine_okPYuU48);
  numBytes += sLine_init(&sLine_R7azneKs);
  numBytes += sLine_init(&sLine_PMHA5GTN);
  numBytes += sLine_init(&sLine_69WkWKvF);
  numBytes += sLine_init(&sLine_eaJZyw5k);
  numBytes += sLine_init(&sLine_Qz7dTHu5);
  numBytes += sLine_init(&sLine_WOqcMuL3);
  numBytes += sLine_init(&sLine_YkYXmOHe);
  numBytes += sLine_init(&sLine_L5WK36Ua);
  numBytes += sLine_init(&sLine_FqWXKSmt);
  numBytes += sLine_init(&sLine_nrHpvxkH);
  numBytes += sLine_init(&sLine_UYaDsbfU);
  numBytes += sEnv_init(&sEnv_vcgZ2LL6, 512, 256);
  numBytes += sEnv_init(&sEnv_JIyREpcF, 512, 256);
  numBytes += sLine_init(&sLine_BpRSXwHJ);
  numBytes += sLine_init(&sLine_PaRdogbl);
  numBytes += sLine_init(&sLine_V4LoWqTS);
  numBytes += sLine_init(&sLine_T4I8O7Mc);
  numBytes += sLine_init(&sLine_2fnAS4nS);
  numBytes += sLine_init(&sLine_Wpj6s014);
  numBytes += sLine_init(&sLine_WsMcg8UO);
  numBytes += sLine_init(&sLine_aomvCmHE);
  numBytes += sLine_init(&sLine_XEcftdHw);
  numBytes += sLine_init(&sLine_Pkc45DKp);
  numBytes += sLine_init(&sLine_ysAZcFxE);
  numBytes += sLine_init(&sLine_GLKdnCcg);
  numBytes += sLine_init(&sLine_TACRu5EH);
  numBytes += sLine_init(&sLine_hN4Pls2d);
  numBytes += sLine_init(&sLine_J19F3H07);
  numBytes += sLine_init(&sLine_q2AwyQW0);
  numBytes += sLine_init(&sLine_6MxNGPwW);
  numBytes += sLine_init(&sLine_rIE7SRqP);
  numBytes += sEnv_init(&sEnv_1dPjBiEk, 512, 256);
  numBytes += sEnv_init(&sEnv_enKgWCs2, 512, 256);
  numBytes += sLine_init(&sLine_rkz0pLsA);
  numBytes += sLine_init(&sLine_07yhCwhI);
  numBytes += sLine_init(&sLine_6VoHkq2m);
  numBytes += sLine_init(&sLine_y3Ps1lHi);
  numBytes += sLine_init(&sLine_MgGaFfPB);
  numBytes += sLine_init(&sLine_7ue3O4bS);
  numBytes += sLine_init(&sLine_zhUtgIM3);
  numBytes += sLine_init(&sLine_SIm3w3Ih);
  numBytes += sLine_init(&sLine_yH6wYZhb);
  numBytes += sLine_init(&sLine_lr0LSgxU);
  numBytes += sLine_init(&sLine_yp0LMf3D);
  numBytes += sLine_init(&sLine_9tgs0eVw);
  numBytes += sLine_init(&sLine_yk1lRhWZ);
  numBytes += sLine_init(&sLine_asrZ7lxw);
  numBytes += sLine_init(&sLine_DbZY1k9p);
  numBytes += sLine_init(&sLine_nuzbB8h7);
  numBytes += sLine_init(&sLine_Gso6HGdm);
  numBytes += sLine_init(&sLine_8nHhH0J2);
  numBytes += sLine_init(&sLine_65cMgABG);
  numBytes += sLine_init(&sLine_C1CpC1Ef);
  numBytes += sEnv_init(&sEnv_FqfYkyAB, 512, 256);
  numBytes += sEnv_init(&sEnv_Ji0eJU6W, 512, 256);
  numBytes += sLine_init(&sLine_qNa9P7QN);
  numBytes += sLine_init(&sLine_IukNwyPa);
  numBytes += sLine_init(&sLine_JtA5RVrk);
  numBytes += sLine_init(&sLine_lBf3Oew8);
  numBytes += sLine_init(&sLine_ZLla85wY);
  numBytes += sLine_init(&sLine_e7eMtbwg);
  numBytes += sLine_init(&sLine_fHQFuWGv);
  numBytes += sLine_init(&sLine_CCRHszti);
  numBytes += sLine_init(&sLine_zXwH0fOf);
  numBytes += sLine_init(&sLine_77cbYjrW);
  numBytes += sLine_init(&sLine_OC57oWxP);
  numBytes += sLine_init(&sLine_pYemoRag);
  numBytes += sLine_init(&sLine_Agu4Knfp);
  numBytes += sLine_init(&sLine_KrFrWn1R);
  numBytes += sLine_init(&sLine_2b3hOLJC);
  numBytes += sLine_init(&sLine_VX3Jzxxd);
  numBytes += sLine_init(&sLine_p7r21KzS);
  numBytes += sLine_init(&sLine_aYmJYLQG);
  numBytes += sEnv_init(&sEnv_KfxuD6TR, 512, 256);
  numBytes += sEnv_init(&sEnv_fiGc2qn4, 512, 256);
  numBytes += sLine_init(&sLine_X5XYuGDA);
  numBytes += sLine_init(&sLine_zS1cQmAk);
  numBytes += sLine_init(&sLine_FeTzf2sk);
  numBytes += sLine_init(&sLine_qKQvoe99);
  numBytes += sLine_init(&sLine_lVdl2olh);
  numBytes += sLine_init(&sLine_fGAaMbC9);
  numBytes += cVar_init_f(&cVar_mcglm4nA, 0.0f);
  numBytes += cVar_init_f(&cVar_QWg5XA9h, 0.0f);
  numBytes += cVar_init_f(&cVar_HjXN0Ank, 0.0f);
  numBytes += cVar_init_f(&cVar_2xlSJCPv, 0.0f);
  numBytes += cVar_init_f(&cVar_19dctzJM, 0.0f);
  numBytes += cVar_init_f(&cVar_Afk1tPnT, 1.0f);
  numBytes += cVar_init_f(&cVar_FgMXNGIE, 0.0f);
  numBytes += cVar_init_f(&cVar_AwFZpHnv, 0.0f);
  numBytes += cVar_init_f(&cVar_P7kGlOd9, 0.0f);
  numBytes += cVar_init_f(&cVar_VRJULdfm, 0.0f);
  numBytes += cSlice_init(&cSlice_uMSQNcsG, 1, -1);
  numBytes += cVar_init_f(&cVar_v5LxHMPg, 1337.0f);
  numBytes += cVar_init_f(&cVar_0JcAXdMt, 0.0f);
  numBytes += cIf_init(&cIf_7mA8uPB1, false);
  numBytes += cIf_init(&cIf_LPHOkcUl, false);
  numBytes += cBinop_init(&cBinop_sNDYs4aL, 0.0f); // __pow
  numBytes += cIf_init(&cIf_x6gGApQq, false);
  numBytes += cBinop_init(&cBinop_T1mrilzz, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_NzFL2JqW, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_BPwKfckO, 0.0f);
  numBytes += cIf_init(&cIf_eHEVECJb, false);
  numBytes += cIf_init(&cIf_7SfwuC3G, false);
  numBytes += cBinop_init(&cBinop_bOM5LqJK, 0.0f); // __pow
  numBytes += cIf_init(&cIf_RUoi9xV6, false);
  numBytes += cBinop_init(&cBinop_UxTar7F7, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_2ZO3jYos, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_NDae5hLR, 0.0f);
  numBytes += cIf_init(&cIf_rf4ammSw, false);
  numBytes += cIf_init(&cIf_vUUnaLXp, false);
  numBytes += cBinop_init(&cBinop_XKHUicAU, 0.0f); // __pow
  numBytes += cIf_init(&cIf_pOFm1c0u, false);
  numBytes += cBinop_init(&cBinop_suxmj7k3, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_2ASpla4i, -15.0f); // __eq
  numBytes += cIf_init(&cIf_tKbeoD3V, false);
  numBytes += cSlice_init(&cSlice_tR0XmsoS, 1, -1);
  numBytes += cVar_init_f(&cVar_TU5GhfIl, 0.0f);
  numBytes += cSlice_init(&cSlice_1v7qHthl, 1, -1);
  numBytes += cVar_init_f(&cVar_l9YylZc9, 0.0f);
  numBytes += cSlice_init(&cSlice_ead1K9zV, 1, -1);
  numBytes += cVar_init_f(&cVar_Ig47BK8P, 0.0f);
  numBytes += cSlice_init(&cSlice_bVLt8DTU, 1, -1);
  numBytes += cVar_init_f(&cVar_05JEKXfM, 0.313f);
  numBytes += cBinop_init(&cBinop_sQCfx012, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_MRvCzAa9, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_KwzcJXDp, 0.0f);
  numBytes += cVar_init_f(&cVar_m0Vc20vo, 1337.0f);
  numBytes += cVar_init_f(&cVar_bsYqLucC, 0.3f);
  numBytes += cBinop_init(&cBinop_alsCAW9Q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TU6MF71O, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LW908pfR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ors5PC2j, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9YuepUIb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TTVn8CKZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_irbbeK2S, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ru7h02Ca, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_XJmEDEQU, 0.0f);
  numBytes += cVar_init_f(&cVar_OENN9mS6, 1337.0f);
  numBytes += cVar_init_f(&cVar_nU31FFJ6, 0.313f);
  numBytes += cBinop_init(&cBinop_ck8TVKEt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3kbvE3iZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_o5jM3xwd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eeUpSmYt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IunRnoeS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rD7HuRED, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_rnxyCX8a, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_KIhFbl6Z, 0.0f);
  numBytes += cVar_init_f(&cVar_5xuEdGxO, 1037.0f);
  numBytes += cVar_init_f(&cVar_x5gvfgUw, 0.4f);
  numBytes += cBinop_init(&cBinop_JBSbfXUm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qyUgyrrp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Re8SPv3I, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_U13J4Y4V, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_edCwSuWu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XuxxSQng, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_ljAmi6oY, 1, -1);
  numBytes += cVar_init_f(&cVar_qOLIP4vi, 1337.0f);
  numBytes += cVar_init_f(&cVar_fiXderSY, 0.0f);
  numBytes += cIf_init(&cIf_1GttdHg5, false);
  numBytes += cIf_init(&cIf_Cw4ptgeP, false);
  numBytes += cBinop_init(&cBinop_HmYptOlS, 0.0f); // __pow
  numBytes += cIf_init(&cIf_F9pKtxo6, false);
  numBytes += cBinop_init(&cBinop_YmbYp4RX, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_tjuoo3os, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_JZCqzOUf, 0.0f);
  numBytes += cIf_init(&cIf_jNKY52gs, false);
  numBytes += cIf_init(&cIf_a5lIv6aW, false);
  numBytes += cBinop_init(&cBinop_OXGKbaOc, 0.0f); // __pow
  numBytes += cIf_init(&cIf_DECUHymT, false);
  numBytes += cBinop_init(&cBinop_gliST4lq, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_fH23yGbo, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_HDCKI7bg, 0.0f);
  numBytes += cIf_init(&cIf_XsdNI2tN, false);
  numBytes += cIf_init(&cIf_flNWgLmI, false);
  numBytes += cBinop_init(&cBinop_9XTKtzUM, 0.0f); // __pow
  numBytes += cIf_init(&cIf_r24SpNRY, false);
  numBytes += cBinop_init(&cBinop_8A3nBfcB, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_zjnOjSys, -15.0f); // __eq
  numBytes += cIf_init(&cIf_Aj8As7KZ, false);
  numBytes += cSlice_init(&cSlice_HNqiRNEs, 1, -1);
  numBytes += cVar_init_f(&cVar_ZVcCdinu, 0.0f);
  numBytes += cSlice_init(&cSlice_779EDx9t, 1, -1);
  numBytes += cVar_init_f(&cVar_6HVuIM0B, 0.0f);
  numBytes += cSlice_init(&cSlice_SpQS44pB, 1, -1);
  numBytes += cVar_init_f(&cVar_3YxGIfqG, 0.0f);
  numBytes += cSlice_init(&cSlice_cP3BzFln, 1, -1);
  numBytes += cVar_init_f(&cVar_GGCOpbLJ, 0.313f);
  numBytes += cBinop_init(&cBinop_3fzRUD9M, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_iS849c08, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_67i5FgAh, 0.0f);
  numBytes += cVar_init_f(&cVar_5BBDrIb1, 1337.0f);
  numBytes += cVar_init_f(&cVar_6gsMX7Q0, 0.3f);
  numBytes += cBinop_init(&cBinop_tT1z7LRs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZL4D2BkL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_M5VEcc8g, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yiVNgx1N, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jmoqnOpH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YqUQfFQz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aqbHj8ix, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_5RjJJKQS, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_a614hpDJ, 0.0f);
  numBytes += cVar_init_f(&cVar_e1sEp9ve, 1337.0f);
  numBytes += cVar_init_f(&cVar_SEAAGHM3, 0.313f);
  numBytes += cBinop_init(&cBinop_xXL6YYNb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_v8Hefri0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kjwVAkui, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yZwM4dUk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fgNT0Jcm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MV8ymh3N, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_X4DzLsle, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_jjZnv9O8, 0.0f);
  numBytes += cVar_init_f(&cVar_ua7fajCy, 1037.0f);
  numBytes += cVar_init_f(&cVar_smvdDYcc, 0.4f);
  numBytes += cBinop_init(&cBinop_POtlFmRC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mS1sEUh7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mUBTtB4N, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_t1F27EYr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2t3znAV4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wKLlhCJM, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_SvvMEBSW, 5705.6f);
  numBytes += cVar_init_f(&cVar_aQnh1Ejj, 313.3f);
  numBytes += cBinop_init(&cBinop_4UxIfNKk, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_w42YnwFd, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_NF0JEzBJ, 0.0f); // __div
  numBytes += cSlice_init(&cSlice_JRoGNJVI, 1, -1);
  numBytes += cVar_init_f(&cVar_zEIlwV5j, 0.5f);
  numBytes += cVar_init_f(&cVar_Oj4A7OKa, 0.0f);
  numBytes += cVar_init_f(&cVar_bIZpjZpk, 0.0f);
  numBytes += cIf_init(&cIf_lSVu5GeI, false);
  numBytes += cIf_init(&cIf_O2SaXXXd, false);
  numBytes += cDelay_init(this, &cDelay_ncBZq8nt, 10.0f);
  numBytes += cIf_init(&cIf_C8yCcb19, false);
  numBytes += cIf_init(&cIf_S7KVMWuV, false);
  numBytes += cDelay_init(this, &cDelay_8RDCL34R, 10.0f);
  numBytes += cIf_init(&cIf_byoN0JGe, false);
  numBytes += cIf_init(&cIf_qL0dLI8P, false);
  numBytes += cDelay_init(this, &cDelay_bGJPAzYl, 10.0f);
  numBytes += cIf_init(&cIf_x75mQZ3i, false);
  numBytes += cIf_init(&cIf_g0eapp7g, false);
  numBytes += cDelay_init(this, &cDelay_SQJ3vaN8, 10.0f);
  numBytes += cIf_init(&cIf_R9PxDJp4, false);
  numBytes += cIf_init(&cIf_1gcr4NZg, false);
  numBytes += cDelay_init(this, &cDelay_lgT8wfiG, 10.0f);
  numBytes += cIf_init(&cIf_AXBxuG0j, false);
  numBytes += cIf_init(&cIf_F81Gy1Wv, false);
  numBytes += cDelay_init(this, &cDelay_ICAqj3kt, 10.0f);
  numBytes += cIf_init(&cIf_J9zy9h2f, false);
  numBytes += cIf_init(&cIf_S9hc6vdN, false);
  numBytes += cDelay_init(this, &cDelay_5dekMLTj, 10.0f);
  numBytes += cIf_init(&cIf_eYOt1iBx, false);
  numBytes += cIf_init(&cIf_lkUORr64, false);
  numBytes += cDelay_init(this, &cDelay_xyo9DM4D, 10.0f);
  numBytes += cIf_init(&cIf_G8tfZ1G5, false);
  numBytes += cIf_init(&cIf_bW8lBpYr, false);
  numBytes += cDelay_init(this, &cDelay_t1OEa1Zo, 10.0f);
  numBytes += cIf_init(&cIf_axAySBrJ, false);
  numBytes += cIf_init(&cIf_0rT7rU2z, false);
  numBytes += cDelay_init(this, &cDelay_XwsXlcyO, 10.0f);
  numBytes += cIf_init(&cIf_UtIQxqAN, false);
  numBytes += cIf_init(&cIf_w7FIZ7V0, false);
  numBytes += cDelay_init(this, &cDelay_c9Yot7Xy, 10.0f);
  numBytes += cIf_init(&cIf_1wDijQ37, false);
  numBytes += cIf_init(&cIf_lvMQZPGT, false);
  numBytes += cDelay_init(this, &cDelay_bjqlbF7Y, 10.0f);
  numBytes += sVarf_init(&sVarf_n6Kh2wKY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZfzWhi2h, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wbiKmOrQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GQp3Pyfj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wQiL2RQe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Wydcnaol, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Vf5bU7Me, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8e2PBywl, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_dD1rzvho, 0.0f);
  numBytes += cSlice_init(&cSlice_BIcwOZZg, 1, -1);
  numBytes += cVar_init_f(&cVar_c9xBnI8G, 1.0f);
  numBytes += cSlice_init(&cSlice_L8XAFiQ0, 1, -1);
  numBytes += cVar_init_f(&cVar_M83fCIG2, 0.0f);
  numBytes += cSlice_init(&cSlice_I4Qljcmx, 1, -1);
  numBytes += cVar_init_f(&cVar_5UAAzONG, 512.0f);
  numBytes += cSlice_init(&cSlice_gTNAZqu1, 1, -1);
  numBytes += cVar_init_f(&cVar_lGWefWbR, 1.0f);
  numBytes += cSlice_init(&cSlice_iMwWFtd8, 1, -1);
  numBytes += cVar_init_f(&cVar_fTCEF38k, 1.0f);
  numBytes += cDelay_init(this, &cDelay_EuAktXof, 20.0f);
  numBytes += cVar_init_f(&cVar_whNx5gkl, 0.0f);
  numBytes += cIf_init(&cIf_XcFDszuh, false);
  numBytes += cIf_init(&cIf_kQvJhEBK, false);
  numBytes += cBinop_init(&cBinop_Aao0obeY, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_IT0klA8b, 1, -1);
  numBytes += cVar_init_f(&cVar_iAahEpV5, 0.0f);
  numBytes += sVarf_init(&sVarf_ClZDZOO0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZzHqHHdh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_z2uePwkE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TzEVZb9I, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_O4xkAT0b, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kuXZFnFu, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_dTCyg6YT, 0.0f);
  numBytes += cVar_init_f(&cVar_pQGYgT7G, 0.0f);
  numBytes += cIf_init(&cIf_kiT99krS, false);
  numBytes += cIf_init(&cIf_hNlmvR7A, false);
  numBytes += cDelay_init(this, &cDelay_ssESGz4A, 10.0f);
  numBytes += cIf_init(&cIf_y9OLLYDN, false);
  numBytes += cIf_init(&cIf_qFRsnQaK, false);
  numBytes += cDelay_init(this, &cDelay_9qSdyX4g, 10.0f);
  numBytes += cIf_init(&cIf_2f7gCmyB, false);
  numBytes += cIf_init(&cIf_n2k2xn05, false);
  numBytes += cDelay_init(this, &cDelay_j5caUFmy, 10.0f);
  numBytes += cIf_init(&cIf_PM9e2rQz, false);
  numBytes += cIf_init(&cIf_FV030KCa, false);
  numBytes += cDelay_init(this, &cDelay_KvqV9Ydr, 10.0f);
  numBytes += cIf_init(&cIf_oroNxklm, false);
  numBytes += cIf_init(&cIf_ZBrIvZUc, false);
  numBytes += cDelay_init(this, &cDelay_h9Owo7GV, 10.0f);
  numBytes += cIf_init(&cIf_SulS2nth, false);
  numBytes += cIf_init(&cIf_FEiydZ8P, false);
  numBytes += cDelay_init(this, &cDelay_TQeZQSlc, 10.0f);
  numBytes += cIf_init(&cIf_slFgPi7w, false);
  numBytes += cIf_init(&cIf_d8uQYM0Q, false);
  numBytes += cDelay_init(this, &cDelay_jJfgfhcb, 10.0f);
  numBytes += cIf_init(&cIf_8JgKCP0I, false);
  numBytes += cIf_init(&cIf_vcdi9adZ, false);
  numBytes += cDelay_init(this, &cDelay_D5LO328a, 10.0f);
  numBytes += cIf_init(&cIf_Xa5CAnM7, false);
  numBytes += cIf_init(&cIf_GGXmeEzt, false);
  numBytes += cDelay_init(this, &cDelay_Hunrctuy, 10.0f);
  numBytes += cIf_init(&cIf_BpZlm9jY, false);
  numBytes += cIf_init(&cIf_VOstMcip, false);
  numBytes += cDelay_init(this, &cDelay_kYX1yui1, 10.0f);
  numBytes += cIf_init(&cIf_PvhtSkbO, false);
  numBytes += cIf_init(&cIf_yIE2iri9, false);
  numBytes += cDelay_init(this, &cDelay_iaseVmfn, 10.0f);
  numBytes += cIf_init(&cIf_4aWnjP96, false);
  numBytes += cIf_init(&cIf_WD40CjnL, false);
  numBytes += cDelay_init(this, &cDelay_OOGVPRmC, 10.0f);
  numBytes += sVarf_init(&sVarf_bBZfNgTW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gxfIuslo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XSiyPETZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_H6DhoqA8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oVr0Pxkh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xaU3Y9u6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Q8CsfXKn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Laxrfx8d, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_apzprhBi, 0.0f);
  numBytes += cSlice_init(&cSlice_lfx0QEzz, 1, -1);
  numBytes += cVar_init_f(&cVar_lT7SXneM, 1.0f);
  numBytes += cSlice_init(&cSlice_0k1UYMtF, 1, -1);
  numBytes += cVar_init_f(&cVar_Fr5ydkOR, 0.0f);
  numBytes += cSlice_init(&cSlice_QwfN48Bk, 1, -1);
  numBytes += cVar_init_f(&cVar_SNedbURD, 512.0f);
  numBytes += cSlice_init(&cSlice_tufsCuQK, 1, -1);
  numBytes += cVar_init_f(&cVar_Mq40YHWg, 1.0f);
  numBytes += cSlice_init(&cSlice_8c4jbWAm, 1, -1);
  numBytes += cVar_init_f(&cVar_7QfeL9uu, 1.0f);
  numBytes += cDelay_init(this, &cDelay_rK1uMbyz, 20.0f);
  numBytes += cVar_init_f(&cVar_wLwkwpan, 0.0f);
  numBytes += cIf_init(&cIf_ge7LTOZx, false);
  numBytes += cIf_init(&cIf_huyUjwpj, false);
  numBytes += cBinop_init(&cBinop_8ytvcxgW, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_1dEjVlWW, 1, -1);
  numBytes += cVar_init_f(&cVar_2qY37F5t, 0.0f);
  numBytes += sVarf_init(&sVarf_icgUy75s, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dkzVQRGk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XI9McXIg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tAgFyoWp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7b5yGqqk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_f5nmAiSL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_740iwOxx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zo0VrZCI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_S1ZXCq5C, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SoCHF71H, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_581Knwc0, 0.0f);
  numBytes += cVar_init_f(&cVar_1vLQPGIC, 0.0f);
  numBytes += cVar_init_f(&cVar_VnxUnboj, 0.0f);
  numBytes += cVar_init_f(&cVar_YEFuJkRF, 0.0f);
  numBytes += cVar_init_f(&cVar_5sfuyrn6, 0.0f);
  numBytes += cVar_init_f(&cVar_tXaTEpBi, 1.0f);
  numBytes += cSlice_init(&cSlice_kDBuYYiT, 1, -1);
  numBytes += cVar_init_f(&cVar_jNrNVveR, 0.5f);
  numBytes += cVar_init_f(&cVar_I2P4LNZk, 0.0f);
  numBytes += cVar_init_f(&cVar_8GPIVeAd, 0.0f);
  numBytes += cIf_init(&cIf_uqGYK3ZM, false);
  numBytes += cIf_init(&cIf_66erumbU, false);
  numBytes += cDelay_init(this, &cDelay_x7TGAjcx, 10.0f);
  numBytes += cIf_init(&cIf_2XCCzXfO, false);
  numBytes += cIf_init(&cIf_ghyjE3KI, false);
  numBytes += cDelay_init(this, &cDelay_idI7GJEy, 10.0f);
  numBytes += cIf_init(&cIf_RJWXhOik, false);
  numBytes += cIf_init(&cIf_4qjBRpXv, false);
  numBytes += cDelay_init(this, &cDelay_2EVgC6YH, 10.0f);
  numBytes += cIf_init(&cIf_7G2x1xFd, false);
  numBytes += cIf_init(&cIf_nyaQEb8x, false);
  numBytes += cDelay_init(this, &cDelay_VL3ynPg2, 10.0f);
  numBytes += cIf_init(&cIf_T1tEJHfz, false);
  numBytes += cIf_init(&cIf_CoX64POT, false);
  numBytes += cDelay_init(this, &cDelay_AZgfyzjz, 10.0f);
  numBytes += cIf_init(&cIf_eMYV9h02, false);
  numBytes += cIf_init(&cIf_jJ55CWAp, false);
  numBytes += cDelay_init(this, &cDelay_lkOn4XGS, 10.0f);
  numBytes += cIf_init(&cIf_XJy9ESSp, false);
  numBytes += cIf_init(&cIf_V0UHLmR2, false);
  numBytes += cDelay_init(this, &cDelay_3JwbNLZe, 10.0f);
  numBytes += cIf_init(&cIf_gafbH4iM, false);
  numBytes += cIf_init(&cIf_7sUBmv6i, false);
  numBytes += cDelay_init(this, &cDelay_L77Hit4c, 10.0f);
  numBytes += cIf_init(&cIf_4n0SZAeC, false);
  numBytes += cIf_init(&cIf_uPNyFdZY, false);
  numBytes += cDelay_init(this, &cDelay_XKdtF62Q, 10.0f);
  numBytes += cIf_init(&cIf_qD0FSMN7, false);
  numBytes += cIf_init(&cIf_7FDkC6Tj, false);
  numBytes += cDelay_init(this, &cDelay_62n6flAg, 10.0f);
  numBytes += cIf_init(&cIf_tNxgVM9u, false);
  numBytes += cIf_init(&cIf_amzqM7UF, false);
  numBytes += cDelay_init(this, &cDelay_v6gQNbGA, 10.0f);
  numBytes += cIf_init(&cIf_izDO9NKL, false);
  numBytes += cIf_init(&cIf_mdOvirVY, false);
  numBytes += cDelay_init(this, &cDelay_lWRv9PcY, 10.0f);
  numBytes += sVarf_init(&sVarf_9KxqXH6s, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zGtH5SIP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cejG6Nlk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yf2giuu7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TgtUX2gs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zml5aHWa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ug7gKEy7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rxbgbOjV, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_4rBynSrH, 0.0f);
  numBytes += cSlice_init(&cSlice_FzGijjJE, 1, -1);
  numBytes += cVar_init_f(&cVar_VgtG77b4, 1.0f);
  numBytes += cSlice_init(&cSlice_eLVFRSIH, 1, -1);
  numBytes += cVar_init_f(&cVar_Dft3JYeP, 0.0f);
  numBytes += cSlice_init(&cSlice_xwiiECaE, 1, -1);
  numBytes += cVar_init_f(&cVar_ACBRmulD, 512.0f);
  numBytes += cSlice_init(&cSlice_XyiY3Qg6, 1, -1);
  numBytes += cVar_init_f(&cVar_0TXJyXQW, 1.0f);
  numBytes += cSlice_init(&cSlice_cytoYvui, 1, -1);
  numBytes += cVar_init_f(&cVar_lZEtyw0M, 1.0f);
  numBytes += cDelay_init(this, &cDelay_OLC0XDzk, 20.0f);
  numBytes += cVar_init_f(&cVar_toqPhChe, 0.0f);
  numBytes += cIf_init(&cIf_vaFZpcLj, false);
  numBytes += cIf_init(&cIf_uN3XB0mf, false);
  numBytes += cBinop_init(&cBinop_skzvmAOy, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_HL4SbNnF, 1, -1);
  numBytes += cVar_init_f(&cVar_yXW42IFC, 0.0f);
  numBytes += sVarf_init(&sVarf_DRs3ztqL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_T7UcQyBo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MIxuz5pw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SSlweyh4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_b0zUknuW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fCQUxXof, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ZoX8s6kT, 0.0f);
  numBytes += cVar_init_f(&cVar_imyiyuSt, 0.0f);
  numBytes += cIf_init(&cIf_ayqKLEag, false);
  numBytes += cIf_init(&cIf_oUc0ciUa, false);
  numBytes += cDelay_init(this, &cDelay_ChexeGmc, 10.0f);
  numBytes += cIf_init(&cIf_8W6tprpo, false);
  numBytes += cIf_init(&cIf_kW5I4Icb, false);
  numBytes += cDelay_init(this, &cDelay_RpV4W9JK, 10.0f);
  numBytes += cIf_init(&cIf_hIC6Nnw9, false);
  numBytes += cIf_init(&cIf_abGegoeO, false);
  numBytes += cDelay_init(this, &cDelay_JYvTkWYF, 10.0f);
  numBytes += cIf_init(&cIf_gMoZKqCk, false);
  numBytes += cIf_init(&cIf_3gM0KqRp, false);
  numBytes += cDelay_init(this, &cDelay_OtfELiQr, 10.0f);
  numBytes += cIf_init(&cIf_45qL64rD, false);
  numBytes += cIf_init(&cIf_5SVHD2eO, false);
  numBytes += cDelay_init(this, &cDelay_EBDMiked, 10.0f);
  numBytes += cIf_init(&cIf_I57f90tR, false);
  numBytes += cIf_init(&cIf_lE9DM127, false);
  numBytes += cDelay_init(this, &cDelay_yh80TAgo, 10.0f);
  numBytes += cIf_init(&cIf_3FM8a92H, false);
  numBytes += cIf_init(&cIf_aGaaIV6E, false);
  numBytes += cDelay_init(this, &cDelay_XoJURZcB, 10.0f);
  numBytes += cIf_init(&cIf_Vqupt3e3, false);
  numBytes += cIf_init(&cIf_But8wg8k, false);
  numBytes += cDelay_init(this, &cDelay_UTvQuPD8, 10.0f);
  numBytes += cIf_init(&cIf_Xs91vK5t, false);
  numBytes += cIf_init(&cIf_JpCafUaF, false);
  numBytes += cDelay_init(this, &cDelay_AQDtqUT6, 10.0f);
  numBytes += cIf_init(&cIf_MQvpu18S, false);
  numBytes += cIf_init(&cIf_08tDmS76, false);
  numBytes += cDelay_init(this, &cDelay_cW1NbEdf, 10.0f);
  numBytes += cIf_init(&cIf_LunMRVi2, false);
  numBytes += cIf_init(&cIf_lCmEYyMh, false);
  numBytes += cDelay_init(this, &cDelay_9rUabswW, 10.0f);
  numBytes += cIf_init(&cIf_cITDaRg9, false);
  numBytes += cIf_init(&cIf_qGsIuYNH, false);
  numBytes += cDelay_init(this, &cDelay_TylRQdqF, 10.0f);
  numBytes += sVarf_init(&sVarf_2UuEqcD9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EuvKND7z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aCmEaCB8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zT3dEssM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_f2xbb8gy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ckIr5NfA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_m0eubqHj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CCruBUQt, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_3mCiBYhv, 0.0f);
  numBytes += cSlice_init(&cSlice_p746wS7P, 1, -1);
  numBytes += cVar_init_f(&cVar_i2ZpbJJ0, 1.0f);
  numBytes += cSlice_init(&cSlice_U7wQF1do, 1, -1);
  numBytes += cVar_init_f(&cVar_E061iVAs, 0.0f);
  numBytes += cSlice_init(&cSlice_hEFRwUkm, 1, -1);
  numBytes += cVar_init_f(&cVar_lNPRH2MB, 512.0f);
  numBytes += cSlice_init(&cSlice_H9HYkPYK, 1, -1);
  numBytes += cVar_init_f(&cVar_47xNtCvu, 1.0f);
  numBytes += cSlice_init(&cSlice_08za4JIx, 1, -1);
  numBytes += cVar_init_f(&cVar_RGj2nIFy, 1.0f);
  numBytes += cDelay_init(this, &cDelay_OK7JZkWp, 20.0f);
  numBytes += cVar_init_f(&cVar_X0Cbs1Ef, 0.0f);
  numBytes += cIf_init(&cIf_pU6eSnkQ, false);
  numBytes += cIf_init(&cIf_ItN2RFO8, false);
  numBytes += cBinop_init(&cBinop_PlUSfrCm, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_K2ZOmwJM, 1, -1);
  numBytes += cVar_init_f(&cVar_HjbRCSEJ, 0.0f);
  numBytes += sVarf_init(&sVarf_cLq7k8qF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vv5iwHZm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2QMMPMjs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fc9KDPDS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CeoHOFM9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FPSX6p5b, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9NTS9ehV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sO93V4Uu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JPWigo7k, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IkFlSehr, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_j6uvWIKl, 0.0f);
  numBytes += cVar_init_f(&cVar_1e6HILXf, 0.0f);
  numBytes += cVar_init_f(&cVar_6rYTSDjx, 0.0f);
  numBytes += cVar_init_f(&cVar_s1OG7rt0, 0.0f);
  numBytes += cVar_init_f(&cVar_Xu9yOu5a, 0.0f);
  numBytes += cVar_init_f(&cVar_AlxebHFj, 1.0f);
  numBytes += cSlice_init(&cSlice_MwUpyl9d, 1, -1);
  numBytes += cVar_init_f(&cVar_japzphwf, 0.5f);
  numBytes += cVar_init_f(&cVar_Clt6Zoyn, 0.0f);
  numBytes += cVar_init_f(&cVar_OMJWE3G8, 0.0f);
  numBytes += cIf_init(&cIf_X3892LuM, false);
  numBytes += cIf_init(&cIf_vfCEankQ, false);
  numBytes += cDelay_init(this, &cDelay_B2pPOvEW, 10.0f);
  numBytes += cIf_init(&cIf_DRovn13X, false);
  numBytes += cIf_init(&cIf_ZWORqBXa, false);
  numBytes += cDelay_init(this, &cDelay_bpxVCz5n, 10.0f);
  numBytes += cIf_init(&cIf_CCfgBMKe, false);
  numBytes += cIf_init(&cIf_wlFdWLCO, false);
  numBytes += cDelay_init(this, &cDelay_IwMyulu1, 10.0f);
  numBytes += cIf_init(&cIf_5aIt18Al, false);
  numBytes += cIf_init(&cIf_U2muVnui, false);
  numBytes += cDelay_init(this, &cDelay_QA4vpxCa, 10.0f);
  numBytes += cIf_init(&cIf_cWPTSJhM, false);
  numBytes += cIf_init(&cIf_QGgPEnjQ, false);
  numBytes += cDelay_init(this, &cDelay_kSNpmi9p, 10.0f);
  numBytes += cIf_init(&cIf_XmgTY7xu, false);
  numBytes += cIf_init(&cIf_foUQtTSO, false);
  numBytes += cDelay_init(this, &cDelay_xrnmeCWU, 10.0f);
  numBytes += cIf_init(&cIf_OIc0hwbg, false);
  numBytes += cIf_init(&cIf_NY4R4myj, false);
  numBytes += cDelay_init(this, &cDelay_GPw8gOW8, 10.0f);
  numBytes += cIf_init(&cIf_OVtSd1RM, false);
  numBytes += cIf_init(&cIf_VoPSr4Gi, false);
  numBytes += cDelay_init(this, &cDelay_TR8cfUKg, 10.0f);
  numBytes += cIf_init(&cIf_zqyHvaK7, false);
  numBytes += cIf_init(&cIf_zJ6rGqxd, false);
  numBytes += cDelay_init(this, &cDelay_GvFhTwCC, 10.0f);
  numBytes += cIf_init(&cIf_CSYy1mxs, false);
  numBytes += cIf_init(&cIf_RdzZpjb7, false);
  numBytes += cDelay_init(this, &cDelay_200DWjKS, 10.0f);
  numBytes += cIf_init(&cIf_ABKLeIcK, false);
  numBytes += cIf_init(&cIf_8SAYR2L9, false);
  numBytes += cDelay_init(this, &cDelay_AZxK5f6h, 10.0f);
  numBytes += cIf_init(&cIf_qX80SwX7, false);
  numBytes += cIf_init(&cIf_BOR3lbj2, false);
  numBytes += cDelay_init(this, &cDelay_C6Fmhkfo, 10.0f);
  numBytes += sVarf_init(&sVarf_VLyKH5JU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6WIvKO1X, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kOOZrFhP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JrDnlNHO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qITs2nKH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iYTnRa6G, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8dLzlYVj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MMxWYGzI, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_WMrGwTmP, 0.0f);
  numBytes += cSlice_init(&cSlice_C51KiI8W, 1, -1);
  numBytes += cVar_init_f(&cVar_EW2X8Ct7, 1.0f);
  numBytes += cSlice_init(&cSlice_aNJajyXD, 1, -1);
  numBytes += cVar_init_f(&cVar_qGgomkPo, 0.0f);
  numBytes += cSlice_init(&cSlice_s73Zijn5, 1, -1);
  numBytes += cVar_init_f(&cVar_7LsTmTX5, 512.0f);
  numBytes += cSlice_init(&cSlice_aMFUgKAD, 1, -1);
  numBytes += cVar_init_f(&cVar_lDiTs6tI, 1.0f);
  numBytes += cSlice_init(&cSlice_xM3l11R9, 1, -1);
  numBytes += cVar_init_f(&cVar_Zxh8KC1Z, 1.0f);
  numBytes += cDelay_init(this, &cDelay_6QZ1rGwq, 20.0f);
  numBytes += cVar_init_f(&cVar_o6w5MxAC, 0.0f);
  numBytes += cIf_init(&cIf_tOohxStX, false);
  numBytes += cIf_init(&cIf_dRIowNZS, false);
  numBytes += cBinop_init(&cBinop_0TULY9QE, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_ypqlEIcG, 1, -1);
  numBytes += cVar_init_f(&cVar_QKTHFUJw, 0.0f);
  numBytes += sVarf_init(&sVarf_YOZs2DVd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lPTUjxxA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_18XO6nvd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9nNyWmk3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RcT1jPL8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3MLa2HWK, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_6xYnj5YY, 0.0f);
  numBytes += cVar_init_f(&cVar_mQo5nD7E, 0.0f);
  numBytes += cIf_init(&cIf_85Od2iKo, false);
  numBytes += cIf_init(&cIf_2uuf3j0S, false);
  numBytes += cDelay_init(this, &cDelay_wULsN3Kw, 10.0f);
  numBytes += cIf_init(&cIf_MnH1fX0f, false);
  numBytes += cIf_init(&cIf_S5ljgGVo, false);
  numBytes += cDelay_init(this, &cDelay_W6gULqam, 10.0f);
  numBytes += cIf_init(&cIf_oq9xePxq, false);
  numBytes += cIf_init(&cIf_KY64qmzR, false);
  numBytes += cDelay_init(this, &cDelay_2JYfjnkn, 10.0f);
  numBytes += cIf_init(&cIf_JuzUgZ84, false);
  numBytes += cIf_init(&cIf_6j3nt6v3, false);
  numBytes += cDelay_init(this, &cDelay_tQHPn1EO, 10.0f);
  numBytes += cIf_init(&cIf_ZhYAdAQE, false);
  numBytes += cIf_init(&cIf_zpnmdaOg, false);
  numBytes += cDelay_init(this, &cDelay_W2HcfOl5, 10.0f);
  numBytes += cIf_init(&cIf_JErM0S6S, false);
  numBytes += cIf_init(&cIf_hHjJtlWA, false);
  numBytes += cDelay_init(this, &cDelay_nqa3bm97, 10.0f);
  numBytes += cIf_init(&cIf_F7MyXYCX, false);
  numBytes += cIf_init(&cIf_vm2QN0t0, false);
  numBytes += cDelay_init(this, &cDelay_CL3mQzId, 10.0f);
  numBytes += cIf_init(&cIf_yUFbeLTT, false);
  numBytes += cIf_init(&cIf_jVmeXM9E, false);
  numBytes += cDelay_init(this, &cDelay_N7Ti76fN, 10.0f);
  numBytes += cIf_init(&cIf_Cz5yjzp9, false);
  numBytes += cIf_init(&cIf_fFeYzYGi, false);
  numBytes += cDelay_init(this, &cDelay_WkJLDFQd, 10.0f);
  numBytes += cIf_init(&cIf_paeEFSSx, false);
  numBytes += cIf_init(&cIf_h2DJrqrP, false);
  numBytes += cDelay_init(this, &cDelay_vQrVyuLQ, 10.0f);
  numBytes += cIf_init(&cIf_cLLaQk9p, false);
  numBytes += cIf_init(&cIf_xc1EBUsm, false);
  numBytes += cDelay_init(this, &cDelay_E6PAGGso, 10.0f);
  numBytes += cIf_init(&cIf_WxbktpZk, false);
  numBytes += cIf_init(&cIf_PJTr92UP, false);
  numBytes += cDelay_init(this, &cDelay_X0QNDpUl, 10.0f);
  numBytes += sVarf_init(&sVarf_p3YIGcOF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AquSokwA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6I8HNCff, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_t1DNI8Qx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JvNoxnd6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_J23k8DWH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_15HeWC4S, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BWLUurPE, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ZwjETQDb, 0.0f);
  numBytes += cSlice_init(&cSlice_0HdJ3KLb, 1, -1);
  numBytes += cVar_init_f(&cVar_k8pweSoF, 1.0f);
  numBytes += cSlice_init(&cSlice_mJxDlffu, 1, -1);
  numBytes += cVar_init_f(&cVar_NxWm7J2N, 0.0f);
  numBytes += cSlice_init(&cSlice_B9IE28nt, 1, -1);
  numBytes += cVar_init_f(&cVar_8C4eOfTs, 512.0f);
  numBytes += cSlice_init(&cSlice_pSVYJCy6, 1, -1);
  numBytes += cVar_init_f(&cVar_TGRleW5p, 1.0f);
  numBytes += cSlice_init(&cSlice_YzpUrc8l, 1, -1);
  numBytes += cVar_init_f(&cVar_rEXjIWTS, 1.0f);
  numBytes += cDelay_init(this, &cDelay_KeJUWUKU, 20.0f);
  numBytes += cVar_init_f(&cVar_3njrxZ2M, 0.0f);
  numBytes += cIf_init(&cIf_A4fz3pR5, false);
  numBytes += cIf_init(&cIf_7jJk5oYe, false);
  numBytes += cBinop_init(&cBinop_47ThQ5GM, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_fZq7jbN3, 1, -1);
  numBytes += cVar_init_f(&cVar_oPf1ERCy, 0.0f);
  numBytes += sVarf_init(&sVarf_RNGg40al, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZaPMLG49, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_K06Dv6mD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ChLgByKY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_asIvEpak, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bF81wwx9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_W6iEKoY7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5DlaoNim, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xT9XsFaX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_C2UMUZIV, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_G96eb8EG, 0.0f);
  numBytes += cVar_init_f(&cVar_3GEbv2a2, 0.0f);
  numBytes += cVar_init_f(&cVar_Sh94fjUY, 0.0f);
  numBytes += sVarf_init(&sVarf_xKR11wq8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YYpfE8vd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BDdpu7ib, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4LCaiTDf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gSxOzEVH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iFMk81KR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eSX7Ct8Q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eR0W3xYR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_d7dCHSaV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QRPqVnnR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KmSAnXtT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oc2lKD8U, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_M3NGLR::~Heavy_WSTD_M3NGLR() {
  sEnv_free(&sEnv_Gd2P1O9f);
  sEnv_free(&sEnv_hU5NBXq2);
  sEnv_free(&sEnv_3SELgnaC);
  sEnv_free(&sEnv_cEiuOTs7);
  sEnv_free(&sEnv_vcgZ2LL6);
  sEnv_free(&sEnv_JIyREpcF);
  sEnv_free(&sEnv_1dPjBiEk);
  sEnv_free(&sEnv_enKgWCs2);
  sEnv_free(&sEnv_FqfYkyAB);
  sEnv_free(&sEnv_Ji0eJU6W);
  sEnv_free(&sEnv_KfxuD6TR);
  sEnv_free(&sEnv_fiGc2qn4);
}

HvTable *Heavy_WSTD_M3NGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_M3NGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3qc0W03f_sendMessage);
      break;
    }
    case 0xCFF7A234: { // High_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GQulbnvZ_sendMessage);
      break;
    }
    case 0x12EF45B9: { // High_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yeAe2wmo_sendMessage);
      break;
    }
    case 0xC05E9A15: { // High_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pC3fK8Sj_sendMessage);
      break;
    }
    case 0x8E596A67: { // High_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5TXpXGiv_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FNHFSRAj_sendMessage);
      break;
    }
    case 0x585E4A54: { // High_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qaZgB91j_sendMessage);
      break;
    }
    case 0x14A9747F: { // High_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VONRHEsa_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CxmzKkM3_sendMessage);
      break;
    }
    case 0xEBDB0C5E: { // Low_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2wx4snFG_sendMessage);
      break;
    }
    case 0xF974E926: { // Low_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iVKiS28S_sendMessage);
      break;
    }
    case 0xBB56D13C: { // Low_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_h6Ksl2zW_sendMessage);
      break;
    }
    case 0xB4EFBAC1: { // Low_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CY5kSDMI_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o8mRO4Bl_sendMessage);
      break;
    }
    case 0x1665AEE9: { // Low_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A6BwoHJI_sendMessage);
      break;
    }
    case 0x860CA1D9: { // Low_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XhlqMELE_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Sj9Eiy1t_sendMessage);
      break;
    }
    case 0xEA9DEF12: { // Mid_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7qyJXOw8_sendMessage);
      break;
    }
    case 0xDBF6FE0A: { // Mid_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cyPZSapt_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mlK7DrTl_sendMessage);
      break;
    }
    case 0x23F5E910: { // Mid_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OvJd2g86_sendMessage);
      break;
    }
    case 0x33C126B6: { // Mid_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MdRNnIwv_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P2NWIZcn_sendMessage);
      break;
    }
    case 0x64B1268F: { // Mid_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ssXx6hgV_sendMessage);
      break;
    }
    case 0xA91022F8: { // Mid_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_goCIr6U1_sendMessage);
      break;
    }
    case 0x1AFCE6EB: { // 1025-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cZRsYZDj_sendMessage);
      break;
    }
    case 0xD8B5B1DB: { // 1025-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U8DLnmL2_sendMessage);
      break;
    }
    case 0x3794F656: { // 1025-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O2goxc45_sendMessage);
      break;
    }
    case 0x94AE0ED9: { // 1025-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w4TkuJ3B_sendMessage);
      break;
    }
    case 0xCC4DB41E: { // 1025-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U3apDi9P_sendMessage);
      break;
    }
    case 0xAFE114F6: { // 1084-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_k5csx9Vi_sendMessage);
      break;
    }
    case 0x98647BAD: { // 1084-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_conJjrk6_sendMessage);
      break;
    }
    case 0xA4661944: { // 1084-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8hNvUIyG_sendMessage);
      break;
    }
    case 0x505CED7B: { // 1125-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VwDYbti5_sendMessage);
      break;
    }
    case 0x82611A6: { // 1125-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Cfq0M0sl_sendMessage);
      break;
    }
    case 0x1B990984: { // 1125-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7vUadh1g_sendMessage);
      break;
    }
    case 0x5F0AFAC5: { // 1166-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3eLHJgNH_sendMessage);
      break;
    }
    case 0x25349984: { // 1166-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fErdnAh4_sendMessage);
      break;
    }
    case 0x8258EF5C: { // 1166-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iNyXsMch_sendMessage);
      break;
    }
    case 0xBC1DF870: { // 1181-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_btM8hIZD_sendMessage);
      break;
    }
    case 0x9A5A2ED: { // 1181-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qySrtmQ7_sendMessage);
      break;
    }
    case 0x6714DCEB: { // 1181-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_urx2DN0L_sendMessage);
      break;
    }
    case 0xE583CFFE: { // 1181-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XquoLF4a_sendMessage);
      break;
    }
    case 0xA6D36AFA: { // 1181-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lRpP0hsU_sendMessage);
      break;
    }
    case 0x2AD225: { // 1240-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0nte55Mp_sendMessage);
      break;
    }
    case 0x7DD55B03: { // 1240-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ITeliLSH_sendMessage);
      break;
    }
    case 0xCF4D157B: { // 1240-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6PxujwKo_sendMessage);
      break;
    }
    case 0x4DF9D195: { // 1281-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pu0YKREN_sendMessage);
      break;
    }
    case 0x58CB5D1B: { // 1281-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e4B9sPNv_sendMessage);
      break;
    }
    case 0xE926ADAA: { // 1281-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QaRU7Ygz_sendMessage);
      break;
    }
    case 0x839669AF: { // 1322-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hPsxYuyV_sendMessage);
      break;
    }
    case 0x89AA8991: { // 1322-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_H65yZ30g_sendMessage);
      break;
    }
    case 0xC43C6A92: { // 1322-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oETZPW2q_sendMessage);
      break;
    }
    case 0x44C46A9A: { // 1345-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uGfPaAjP_sendMessage);
      break;
    }
    case 0x5B005CAA: { // 1352-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vDXrPMbf_sendMessage);
      break;
    }
    case 0xBBD23460: { // 1352-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8JgDoyPF_sendMessage);
      break;
    }
    case 0x23884B06: { // 1352-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2YaiIynC_sendMessage);
      break;
    }
    case 0x91BE5650: { // 1352-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZYD9MMCM_sendMessage);
      break;
    }
    case 0x51E8B18D: { // 1352-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PJrhQlVs_sendMessage);
      break;
    }
    case 0x2CAD1402: { // 1352-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_B25a8IGz_sendMessage);
      break;
    }
    case 0x8CE949DD: { // 1470-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yjwZGhoS_sendMessage);
      break;
    }
    case 0x1A98A8C5: { // 1470-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9KcC0fSq_sendMessage);
      break;
    }
    case 0x4211FC92: { // 1470-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K09PyThU_sendMessage);
      break;
    }
    case 0x86F6710B: { // 1470-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kJJJziUz_sendMessage);
      break;
    }
    case 0x102FAA7E: { // 1470-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4vrS2Acb_sendMessage);
      break;
    }
    case 0x1A325FAC: { // 1470-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qEvkzBJt_sendMessage);
      break;
    }
    case 0x5FF45DD7: { // 1602-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LD8z40W5_sendMessage);
      break;
    }
    case 0xA63D49D8: { // 1609-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LS9xq3sQ_sendMessage);
      break;
    }
    case 0xFB1C4FF4: { // 1609-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZOjQKwGI_sendMessage);
      break;
    }
    case 0x2D7D2212: { // 1609-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OUZ9iJr0_sendMessage);
      break;
    }
    case 0xB4610071: { // 1609-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WcbraJ7f_sendMessage);
      break;
    }
    case 0x47BBE59E: { // 1609-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nRje5SyF_sendMessage);
      break;
    }
    case 0xD51403EB: { // 1609-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VN4jK5OJ_sendMessage);
      break;
    }
    case 0x559ECA90: { // 1727-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2lIvgMws_sendMessage);
      break;
    }
    case 0xB4F19FB9: { // 1727-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_35P53LmB_sendMessage);
      break;
    }
    case 0x7CE4DF88: { // 1727-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VWVT6StR_sendMessage);
      break;
    }
    case 0x9FD7A64D: { // 1727-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BdLC17S2_sendMessage);
      break;
    }
    case 0x52C25AFE: { // 1727-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_trPS2f08_sendMessage);
      break;
    }
    case 0x801C27A5: { // 1727-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AWkXwkSE_sendMessage);
      break;
    }
    case 0xE5875B65: { // 1859-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RVa5cbT7_sendMessage);
      break;
    }
    case 0x40898D28: { // 1866-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AcmkmZuE_sendMessage);
      break;
    }
    case 0x9D616407: { // 1866-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0tKO5vnk_sendMessage);
      break;
    }
    case 0xE8DBDB0: { // 1866-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ucEet2P3_sendMessage);
      break;
    }
    case 0xD770731A: { // 1866-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gqFwzkTz_sendMessage);
      break;
    }
    case 0x124CD18B: { // 1866-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dIGu07Lq_sendMessage);
      break;
    }
    case 0x4017FCCD: { // 1866-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KPCmRHBr_sendMessage);
      break;
    }
    case 0x1B1DD5FB: { // 1984-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qfHqTJ5K_sendMessage);
      break;
    }
    case 0xA478FA4C: { // 1984-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sXvzAFpW_sendMessage);
      break;
    }
    case 0x97EB3671: { // 1984-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tN7KX4u8_sendMessage);
      break;
    }
    case 0xF3FECDEE: { // 1984-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DgYnVEDk_sendMessage);
      break;
    }
    case 0x9558C335: { // 1984-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mIG0QdlH_sendMessage);
      break;
    }
    case 0x4131288C: { // 1984-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Zrq52lhK_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Mp9V8uLN_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_M3NGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Crshr";
        info->hash = 0xCFF7A234;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 2: {
        info->name = "High_Fldr";
        info->hash = 0x12EF45B9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 3: {
        info->name = "High_Gain";
        info->hash = 0xC05E9A15;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "High_Lmtr";
        info->hash = 0x8E596A67;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 5: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 6: {
        info->name = "High_Smthr";
        info->hash = 0x585E4A54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "High_Sqnc";
        info->hash = 0x14A9747F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 9: {
        info->name = "Low_Crshr";
        info->hash = 0xEBDB0C5E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 10: {
        info->name = "Low_Fldr";
        info->hash = 0xF974E926;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 11: {
        info->name = "Low_Gain";
        info->hash = 0xBB56D13C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Lmtr";
        info->hash = 0xB4EFBAC1;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 13: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 14: {
        info->name = "Low_Smthr";
        info->hash = 0x1665AEE9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 15: {
        info->name = "Low_Sqnc";
        info->hash = 0x860CA1D9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Crshr";
        info->hash = 0xEA9DEF12;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Fldr";
        info->hash = 0xDBF6FE0A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Gain";
        info->hash = 0x23F5E910;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 21: {
        info->name = "Mid_Lmtr";
        info->hash = 0x33C126B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 22: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 23: {
        info->name = "Mid_Smthr";
        info->hash = 0x64B1268F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 24: {
        info->name = "Mid_Sqnc";
        info->hash = 0xA91022F8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 25;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_M3NGLR::cVar_mcglm4nA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XUOFNk95_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_QWg5XA9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WIGbMiaq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_HjXN0Ank_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YogoqD3Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_2xlSJCPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sAnxzqdz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_19dctzJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IpHLFrhK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Afk1tPnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TPhtlqIw_sendMessage);
  cMsg_9Tpsb7UI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_TPhtlqIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Afk1tPnT, 1, m, &cVar_Afk1tPnT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ahtvu1s2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MOPAb0CE_sendMessage(_c, 0, m);
  cMsg_PoFbsPo7_sendMessage(_c, 0, m);
  cMsg_gwHreIBK_sendMessage(_c, 0, m);
  cMsg_wpMltKed_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_FgMXNGIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VP7HxV5V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_AwFZpHnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P7Ehb8hX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_P7kGlOd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2GNHzTBQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_VRJULdfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VokDtX4d_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KpaxiY1j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ShEpcgSv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TWUb8lLx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tXVwlloJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uMSQNcsG, 0, m, &cSlice_uMSQNcsG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nYY7rxHu_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_uMSQNcsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_55GQprRI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_55GQprRI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_v5LxHMPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_55GQprRI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_55GQprRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_O2goxc45_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_0JcAXdMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Dfwb8nen_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_7mA8uPB1, 0, m, &cIf_7mA8uPB1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_7mA8uPB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iyoWMZ0c_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_LPHOkcUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_7pGLUjT0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_am7sbEBT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_hbrYLwuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sNDYs4aL, HV_BINOP_POW, 0, m, &cBinop_sNDYs4aL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sNDYs4aL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x6gGApQq, 0, m, &cIf_x6gGApQq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TDlDD0pm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_AM5N22HQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RcuTamXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LPHOkcUl, 0, m, &cIf_LPHOkcUl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_paqQ3VFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_guq9FfPS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_guq9FfPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LPHOkcUl, 1, m, &cIf_LPHOkcUl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_am7sbEBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_TDlDD0pm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7pGLUjT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_x6gGApQq, 0, m, &cIf_x6gGApQq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AM5N22HQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sNDYs4aL, HV_BINOP_POW, 1, m, &cBinop_sNDYs4aL_sendMessage);
  cMsg_hbrYLwuD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_x6gGApQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pFKcZYJl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_Dfwb8nen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7mA8uPB1, 1, m, &cIf_7mA8uPB1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iyoWMZ0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IfuLWHyt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s6CLMh3m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Rha3lTvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_paqQ3VFs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RcuTamXY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T1mrilzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x6gGApQq, 1, m, &cIf_x6gGApQq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NzFL2JqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ykGS3pdB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ykGS3pdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_pFKcZYJl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FMiaIHhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_Rha3lTvy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IfuLWHyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NzFL2JqW, HV_BINOP_EQ, 1, m, &cBinop_NzFL2JqW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s6CLMh3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T1mrilzz, HV_BINOP_GREATER_THAN, 1, m, &cBinop_T1mrilzz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xMBXQg0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T1mrilzz, HV_BINOP_GREATER_THAN, 0, m, &cBinop_T1mrilzz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_g4zNVHhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0JcAXdMt, 0, m, &cVar_0JcAXdMt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Np1OC2JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NzFL2JqW, HV_BINOP_EQ, 0, m, &cBinop_NzFL2JqW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dtYzCdR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FMiaIHhA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_BPwKfckO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OaMupRXq_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_eHEVECJb, 0, m, &cIf_eHEVECJb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_eHEVECJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xskukYBC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7SfwuC3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_5bJPZ0Qn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ZM1VTJ8d_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_UvmOpAjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bOM5LqJK, HV_BINOP_POW, 0, m, &cBinop_bOM5LqJK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bOM5LqJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RUoi9xV6, 0, m, &cIf_RUoi9xV6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JwRI8IHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_v5PmNIRG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eri3ImeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7SfwuC3G, 0, m, &cIf_7SfwuC3G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hheU1tc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YYJThXca_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YYJThXca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7SfwuC3G, 1, m, &cIf_7SfwuC3G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZM1VTJ8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_JwRI8IHB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5bJPZ0Qn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_RUoi9xV6, 0, m, &cIf_RUoi9xV6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_v5PmNIRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bOM5LqJK, HV_BINOP_POW, 1, m, &cBinop_bOM5LqJK_sendMessage);
  cMsg_UvmOpAjL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_RUoi9xV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9i6ZKeuO_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EkvrR91g_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_OaMupRXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eHEVECJb, 1, m, &cIf_eHEVECJb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xskukYBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YGmR5Plu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0P6TLj6a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VOgE4MSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hheU1tc0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eri3ImeI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UxTar7F7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RUoi9xV6, 1, m, &cIf_RUoi9xV6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2ZO3jYos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_otpj3isG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_otpj3isG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9i6ZKeuO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EkvrR91g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2ud4EX6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_VOgE4MSe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YGmR5Plu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2ZO3jYos, HV_BINOP_EQ, 1, m, &cBinop_2ZO3jYos_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0P6TLj6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UxTar7F7, HV_BINOP_GREATER_THAN, 1, m, &cBinop_UxTar7F7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z1GN2wKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2ZO3jYos, HV_BINOP_EQ, 0, m, &cBinop_2ZO3jYos_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HMYZuVv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BPwKfckO, 0, m, &cVar_BPwKfckO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_95XvjZ3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2ud4EX6k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Mn1FeQuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UxTar7F7, HV_BINOP_GREATER_THAN, 0, m, &cBinop_UxTar7F7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_NDae5hLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_43z6GVN6_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_rf4ammSw, 0, m, &cIf_rf4ammSw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_rf4ammSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TMT8dwFf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vUUnaLXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_pK1eYP0W_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_EjsDg3pZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_syeB2gqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XKHUicAU, HV_BINOP_POW, 0, m, &cBinop_XKHUicAU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XKHUicAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pOFm1c0u, 0, m, &cIf_pOFm1c0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DVFBwrzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vdrKEGD3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_36osG4PA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wbS4s9w4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2hiVdBVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vUUnaLXp, 0, m, &cIf_vUUnaLXp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wbS4s9w4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vUUnaLXp, 1, m, &cIf_vUUnaLXp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EjsDg3pZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_DVFBwrzF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pK1eYP0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_pOFm1c0u, 0, m, &cIf_pOFm1c0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vdrKEGD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XKHUicAU, HV_BINOP_POW, 1, m, &cBinop_XKHUicAU_sendMessage);
  cMsg_syeB2gqh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_pOFm1c0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9oqZuBL8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_43z6GVN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rf4ammSw, 1, m, &cIf_rf4ammSw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TMT8dwFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A9oD8U7k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ory7k5AX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SGZEIHpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_36osG4PA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2hiVdBVn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_suxmj7k3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pOFm1c0u, 1, m, &cIf_pOFm1c0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2ASpla4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DBoYU1gY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DBoYU1gY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_9oqZuBL8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QyQoeZw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_SGZEIHpV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ory7k5AX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_suxmj7k3, HV_BINOP_GREATER_THAN, 1, m, &cBinop_suxmj7k3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A9oD8U7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2ASpla4i, HV_BINOP_EQ, 1, m, &cBinop_2ASpla4i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0N6NgLPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NDae5hLR, 0, m, &cVar_NDae5hLR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GNjFznof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2ASpla4i, HV_BINOP_EQ, 0, m, &cBinop_2ASpla4i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_C3QsM7qN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QyQoeZw5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_sk1zkC2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_suxmj7k3, HV_BINOP_GREATER_THAN, 0, m, &cBinop_suxmj7k3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_tKbeoD3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1Q2joYFY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_p2DyqGNN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tR0XmsoS, 0, m, &cSlice_tR0XmsoS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nXsnk045_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_tR0XmsoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KuCOsOJd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KuCOsOJd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_TU5GhfIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KuCOsOJd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_KuCOsOJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cZRsYZDj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nXsnk045_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1v7qHthl, 0, m, &cSlice_1v7qHthl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_tXVwlloJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_1v7qHthl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_1YLPx3e6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_1YLPx3e6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_l9YylZc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1YLPx3e6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_1YLPx3e6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_U3apDi9P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nYY7rxHu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ead1K9zV, 0, m, &cSlice_ead1K9zV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_33ZOctOr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ead1K9zV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_52ycwlRV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_52ycwlRV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Ig47BK8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_52ycwlRV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_52ycwlRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_U8DLnmL2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_33ZOctOr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bVLt8DTU, 0, m, &cSlice_bVLt8DTU_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_bVLt8DTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ihBQCW2r_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ihBQCW2r_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_05JEKXfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ihBQCW2r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ihBQCW2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_w4TkuJ3B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LxUPOSro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8gpLsLxH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ir5JVllw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xKTUl20e, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5g5IrwVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1BFSvd7e, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_frL0dGql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S8oitVEB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_myyIyK3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IjY6WXbY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jMC6zvXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rfPpQFqa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_rfPpQFqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sQCfx012, HV_BINOP_DIVIDE, 1, m, &cBinop_sQCfx012_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sPcZYjxT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_876MD3ig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Ui02z7Bf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kaHneXL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_876MD3ig_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ui02z7Bf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sQCfx012, HV_BINOP_DIVIDE, 0, m, &cBinop_sQCfx012_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sPcZYjxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kaHneXL3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_sQCfx012_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MRvCzAa9, HV_BINOP_MULTIPLY, 1, m, &cBinop_MRvCzAa9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MRvCzAa9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4rcngxRq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0EZncOx8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_N18DOIwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gdVe1Zaf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_nAhKlSq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_R1XOroKo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_SykqwGQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_02bBMqcz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_02bBMqcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MRvCzAa9, HV_BINOP_MULTIPLY, 0, m, &cBinop_MRvCzAa9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_552Q0AdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_aM8BuRXT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aM8BuRXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Pe2FaniL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_HC87nd3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KwzcJXDp, 1, m, &cVar_KwzcJXDp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_KwzcJXDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nwq5Mufx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WwwzGBYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TU6MF71O, HV_BINOP_MULTIPLY, 1, m, &cBinop_TU6MF71O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ETIXt2TV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WwwzGBYg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MmVBZlVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ynzJeAXz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ynzJeAXz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LW908pfR, HV_BINOP_MULTIPLY, 1, m, &cBinop_LW908pfR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_brBN9I7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ors5PC2j, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ors5PC2j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iBG1Kp6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_brBN9I7W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8sLwF1ok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9YuepUIb, HV_BINOP_MULTIPLY, 1, m, &cBinop_9YuepUIb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7bbAcTzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1VqNgVLj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1VqNgVLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TTVn8CKZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_TTVn8CKZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_m0Vc20vo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y7JzFEU6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_SykqwGQx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_884ELKxN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_bsYqLucC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_552Q0AdW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4rcngxRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_N18DOIwJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0EZncOx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_nAhKlSq6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_gdVe1Zaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8hNvUIyG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_R1XOroKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_conJjrk6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_M0im5nHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_k5csx9Vi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Pe2FaniL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rLrHqTXe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rLrHqTXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_alsCAW9Q, HV_BINOP_MULTIPLY, 1, m, &cBinop_alsCAW9Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_alsCAW9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LUTLHhfQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LUTLHhfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_M0im5nHx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Nwq5Mufx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Yz9PZK0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Yz9PZK0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FfVVnDxV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1UC7S5GX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UFq3z4Qr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wRT9FOy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SUEy5SRu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wBt0oQpX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TU6MF71O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LxUPOSro_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_LW908pfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ir5JVllw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Ors5PC2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5g5IrwVX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_9YuepUIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_frL0dGql_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_TTVn8CKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_myyIyK3L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_LCEvaEID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m0Vc20vo, 0, m, &cVar_m0Vc20vo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7PkB8ZF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bsYqLucC, 1, m, &cVar_bsYqLucC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FfVVnDxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_SUEy5SRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LW908pfR, HV_BINOP_MULTIPLY, 0, m, &cBinop_LW908pfR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8wRT9FOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ors5PC2j, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ors5PC2j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wBt0oQpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TU6MF71O, HV_BINOP_MULTIPLY, 0, m, &cBinop_TU6MF71O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1UC7S5GX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TTVn8CKZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_TTVn8CKZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UFq3z4Qr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9YuepUIb, HV_BINOP_MULTIPLY, 0, m, &cBinop_9YuepUIb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y7JzFEU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bsYqLucC, 0, m, &cVar_bsYqLucC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_884ELKxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KwzcJXDp, 0, m, &cVar_KwzcJXDp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_x077ssjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sXWwoWC5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4BMNynT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BwceLg0b, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jkv5dQLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dhPTGs5Z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1glmIAHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e4C4VoPu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_luzq25KS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QYDl1Q9V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_QYDl1Q9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_irbbeK2S, HV_BINOP_DIVIDE, 1, m, &cBinop_irbbeK2S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W1wlH9Cx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_rPkRsL4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_B44jDI2u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KnnU443L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_rPkRsL4F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_B44jDI2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_irbbeK2S, HV_BINOP_DIVIDE, 0, m, &cBinop_irbbeK2S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W1wlH9Cx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KnnU443L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_irbbeK2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ru7h02Ca, HV_BINOP_MULTIPLY, 1, m, &cBinop_ru7h02Ca_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ru7h02Ca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9KVBjuCU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1uq8kinG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_6y1G9tOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_l2W09YGb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_rMZX1g0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KrRPaCX4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_D2MtbVJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_SQYBpKvL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SQYBpKvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ru7h02Ca, HV_BINOP_MULTIPLY, 0, m, &cBinop_ru7h02Ca_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TzvOuAVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_IKBrW2U8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IKBrW2U8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CvYXiuSE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_iC0qfXzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o5jM3xwd, HV_BINOP_MULTIPLY, 1, m, &cBinop_o5jM3xwd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UTop13RN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XJmEDEQU, 1, m, &cVar_XJmEDEQU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9wsXUfTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eeUpSmYt, HV_BINOP_MULTIPLY, 1, m, &cBinop_eeUpSmYt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HiTmROqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uwymZuUT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uwymZuUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IunRnoeS, HV_BINOP_MULTIPLY, 1, m, &cBinop_IunRnoeS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_XJmEDEQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0bpAjLHS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_OENN9mS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DzB9cuBP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_D2MtbVJ3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KGCCRrKw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_nU31FFJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_TzvOuAVm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1uq8kinG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_rMZX1g0k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9KVBjuCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_6y1G9tOw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_l2W09YGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7vUadh1g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_KrRPaCX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Cfq0M0sl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dahttBf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VwDYbti5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CvYXiuSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NikZcvZi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NikZcvZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ck8TVKEt, HV_BINOP_MULTIPLY, 1, m, &cBinop_ck8TVKEt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ck8TVKEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AQnGpV13_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AQnGpV13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dahttBf2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0bpAjLHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qxqbrEQ7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qxqbrEQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ILXZebXS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SWCC54IQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KxMS0GXX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EKnES0hb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3kbvE3iZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x077ssjq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_o5jM3xwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4BMNynT1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_eeUpSmYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jkv5dQLa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_IunRnoeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1glmIAHw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_WNOQLMOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OENN9mS6, 0, m, &cVar_OENN9mS6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PohJjaoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nU31FFJ6, 1, m, &cVar_nU31FFJ6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KGCCRrKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XJmEDEQU, 0, m, &cVar_XJmEDEQU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DzB9cuBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nU31FFJ6, 0, m, &cVar_nU31FFJ6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ILXZebXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IunRnoeS, HV_BINOP_MULTIPLY, 0, m, &cBinop_IunRnoeS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KxMS0GXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o5jM3xwd, HV_BINOP_MULTIPLY, 0, m, &cBinop_o5jM3xwd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EKnES0hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3kbvE3iZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_3kbvE3iZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SWCC54IQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eeUpSmYt, HV_BINOP_MULTIPLY, 0, m, &cBinop_eeUpSmYt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7TJHnrTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_koqR3SLU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PEe2dHTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aCddIJlP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1Yfs2cNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XC1pk1Pj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KSLrWRC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XkP9wYM6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BuiWqBRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nZCXD3W8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MLGejcIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CDx4pS6P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_CDx4pS6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rD7HuRED, HV_BINOP_DIVIDE, 1, m, &cBinop_rD7HuRED_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HJGrylEb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_CUa9ycb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_b74STmXX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tb84jxDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_CUa9ycb8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_b74STmXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rD7HuRED, HV_BINOP_DIVIDE, 0, m, &cBinop_rD7HuRED_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HJGrylEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tb84jxDk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_rD7HuRED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rnxyCX8a, HV_BINOP_MULTIPLY, 1, m, &cBinop_rnxyCX8a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rnxyCX8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_47ajwDKR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AVTaYbuN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_fMmEEXIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_U1Uphi3w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_XnJv9Sw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_msv2RrI9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_FxbXJdJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_3hiaV8x7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3hiaV8x7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rnxyCX8a, HV_BINOP_MULTIPLY, 0, m, &cBinop_rnxyCX8a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Jk57H4U2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_veJugdkl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_veJugdkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ulYDGu42_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_gV6k9rM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qyUgyrrp, HV_BINOP_MULTIPLY, 1, m, &cBinop_qyUgyrrp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8UAV8X9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3beeCk7w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3beeCk7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gV6k9rM2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LJP6aCC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_dUR2rXro_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dUR2rXro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Re8SPv3I, HV_BINOP_MULTIPLY, 1, m, &cBinop_Re8SPv3I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lpTDOfro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U13J4Y4V, HV_BINOP_MULTIPLY, 1, m, &cBinop_U13J4Y4V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8tNC6FIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ktoHpnPm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ktoHpnPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lpTDOfro_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j1eHzF2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KIhFbl6Z, 1, m, &cVar_KIhFbl6Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BCEE370E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_edCwSuWu, HV_BINOP_MULTIPLY, 1, m, &cBinop_edCwSuWu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N51SbXpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hU5e8T2L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hU5e8T2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XuxxSQng, HV_BINOP_MULTIPLY, 1, m, &cBinop_XuxxSQng_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_KIhFbl6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w4pNIHG1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_5xuEdGxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z9Kv9rFC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_FxbXJdJE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XS7Xsn49_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_x5gvfgUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Jk57H4U2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_47ajwDKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_fMmEEXIq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AVTaYbuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_XnJv9Sw0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_U1Uphi3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iNyXsMch_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_msv2RrI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fErdnAh4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_93byA8fF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3eLHJgNH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ulYDGu42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_25NQPX3A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_25NQPX3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JBSbfXUm, HV_BINOP_MULTIPLY, 1, m, &cBinop_JBSbfXUm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JBSbfXUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZLmRVWCn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZLmRVWCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_93byA8fF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_w4pNIHG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PhqnyxsO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PhqnyxsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uD7vlAca_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qemRUTVW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LEQrMio6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1wmvdhRM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7keNVPcC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J62cuCjG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qyUgyrrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7TJHnrTX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Re8SPv3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PEe2dHTI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_U13J4Y4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1Yfs2cNe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_edCwSuWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KSLrWRC1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_XuxxSQng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BuiWqBRo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_IPUiHyJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5xuEdGxO, 0, m, &cVar_5xuEdGxO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uZJxgDjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x5gvfgUw, 1, m, &cVar_x5gvfgUw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uD7vlAca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_LEQrMio6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_edCwSuWu, HV_BINOP_MULTIPLY, 0, m, &cBinop_edCwSuWu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7keNVPcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Re8SPv3I, HV_BINOP_MULTIPLY, 0, m, &cBinop_Re8SPv3I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_J62cuCjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qyUgyrrp, HV_BINOP_MULTIPLY, 0, m, &cBinop_qyUgyrrp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qemRUTVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XuxxSQng, HV_BINOP_MULTIPLY, 0, m, &cBinop_XuxxSQng_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1wmvdhRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U13J4Y4V, HV_BINOP_MULTIPLY, 0, m, &cBinop_U13J4Y4V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XS7Xsn49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KIhFbl6Z, 0, m, &cVar_KIhFbl6Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z9Kv9rFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x5gvfgUw, 0, m, &cVar_x5gvfgUw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NQkodW4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tKbeoD3V, 1, m, &cIf_tKbeoD3V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_npzuHWwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_1Q2joYFY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_GB15pQPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_npzuHWwJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_QfiEY36I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tKbeoD3V, 0, m, &cIf_tKbeoD3V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pFKcZYJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3GE3uPId, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1Q2joYFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Rds01OCF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9oqZuBL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FB4Lp3v4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_9i6ZKeuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NQkodW4O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GB15pQPo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EkvrR91g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_QfiEY36I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pIiw6xOb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ljAmi6oY, 0, m, &cSlice_ljAmi6oY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8ENG6NSu_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ljAmi6oY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8FAeJRtB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8FAeJRtB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qOLIP4vi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8FAeJRtB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_8FAeJRtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_urx2DN0L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_fiXderSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dDIAJlby_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_1GttdHg5, 0, m, &cIf_1GttdHg5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_1GttdHg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jgFEQmp5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Cw4ptgeP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_zPA3SSbW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_1sHM4J4D_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_A2fV0ZXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HmYptOlS, HV_BINOP_POW, 0, m, &cBinop_HmYptOlS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HmYptOlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F9pKtxo6, 0, m, &cIf_F9pKtxo6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ggcazvEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Bc5OlYex_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NMNJiq0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_e32VaYf5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ouL2hmG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Cw4ptgeP, 0, m, &cIf_Cw4ptgeP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_e32VaYf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Cw4ptgeP, 1, m, &cIf_Cw4ptgeP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1sHM4J4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ggcazvEH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zPA3SSbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_F9pKtxo6, 0, m, &cIf_F9pKtxo6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Bc5OlYex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HmYptOlS, HV_BINOP_POW, 1, m, &cBinop_HmYptOlS_sendMessage);
  cMsg_A2fV0ZXn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_F9pKtxo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LrRasBHT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_dDIAJlby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1GttdHg5, 1, m, &cIf_1GttdHg5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jgFEQmp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FxtajTgO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L0yRvoRZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PDSeeLIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NMNJiq0t_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ouL2hmG7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YmbYp4RX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F9pKtxo6, 1, m, &cIf_F9pKtxo6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tjuoo3os_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DgX8T80y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DgX8T80y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_LrRasBHT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_z5SbbTtZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_PDSeeLIB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L0yRvoRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YmbYp4RX, HV_BINOP_GREATER_THAN, 1, m, &cBinop_YmbYp4RX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FxtajTgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tjuoo3os, HV_BINOP_EQ, 1, m, &cBinop_tjuoo3os_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TjK76G2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fiXderSY, 0, m, &cVar_fiXderSY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_m0mvRESl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z5SbbTtZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_nTjU2imZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tjuoo3os, HV_BINOP_EQ, 0, m, &cBinop_tjuoo3os_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iageSayo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YmbYp4RX, HV_BINOP_GREATER_THAN, 0, m, &cBinop_YmbYp4RX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_JZCqzOUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4jYubli2_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_jNKY52gs, 0, m, &cIf_jNKY52gs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_jNKY52gs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iJXXZuSR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_a5lIv6aW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_LFTs2LPJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_fbVC91yR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_UrnjBnWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OXGKbaOc, HV_BINOP_POW, 0, m, &cBinop_OXGKbaOc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OXGKbaOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DECUHymT, 0, m, &cIf_DECUHymT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FtPci9YE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_QAbDcjCo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kUxruTf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a5lIv6aW, 0, m, &cIf_a5lIv6aW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DWqm0ScF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_aIwWq2DV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aIwWq2DV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a5lIv6aW, 1, m, &cIf_a5lIv6aW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fbVC91yR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_FtPci9YE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LFTs2LPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_DECUHymT, 0, m, &cIf_DECUHymT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QAbDcjCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OXGKbaOc, HV_BINOP_POW, 1, m, &cBinop_OXGKbaOc_sendMessage);
  cMsg_UrnjBnWe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_DECUHymT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sQ4xzloD_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hsn8srAj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_4jYubli2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jNKY52gs, 1, m, &cIf_jNKY52gs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iJXXZuSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2M3K4XGD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tNuoK0oc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TFwNfsmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DWqm0ScF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kUxruTf7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gliST4lq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DECUHymT, 1, m, &cIf_DECUHymT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fH23yGbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xoNQ9pbe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xoNQ9pbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sQ4xzloD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hsn8srAj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ivb3JKZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_TFwNfsmK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tNuoK0oc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gliST4lq, HV_BINOP_GREATER_THAN, 1, m, &cBinop_gliST4lq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2M3K4XGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fH23yGbo, HV_BINOP_EQ, 1, m, &cBinop_fH23yGbo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_N33uqKR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fH23yGbo, HV_BINOP_EQ, 0, m, &cBinop_fH23yGbo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_g5lvB5bf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ivb3JKZW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_BXijdTbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gliST4lq, HV_BINOP_GREATER_THAN, 0, m, &cBinop_gliST4lq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WggiHaNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JZCqzOUf, 0, m, &cVar_JZCqzOUf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_HDCKI7bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YGF6OIvw_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_XsdNI2tN, 0, m, &cIf_XsdNI2tN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_XsdNI2tN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MuUzG2D7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_flNWgLmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_MFRKfmhp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_jkxm7rR3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_ZeFeV6cr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9XTKtzUM, HV_BINOP_POW, 0, m, &cBinop_9XTKtzUM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9XTKtzUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_r24SpNRY, 0, m, &cIf_r24SpNRY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ITPGGtYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_1hymF48l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tcin2SLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IMnq9c8u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L7gYR22g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_flNWgLmI, 0, m, &cIf_flNWgLmI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IMnq9c8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_flNWgLmI, 1, m, &cIf_flNWgLmI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jkxm7rR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ITPGGtYf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MFRKfmhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_r24SpNRY, 0, m, &cIf_r24SpNRY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1hymF48l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9XTKtzUM, HV_BINOP_POW, 1, m, &cBinop_9XTKtzUM_sendMessage);
  cMsg_ZeFeV6cr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_r24SpNRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_40Yzn0J9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_YGF6OIvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XsdNI2tN, 1, m, &cIf_XsdNI2tN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MuUzG2D7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JT3nmmdR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hJiF473K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sDWIp0F4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tcin2SLT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L7gYR22g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8A3nBfcB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_r24SpNRY, 1, m, &cIf_r24SpNRY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zjnOjSys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LLqbWRM5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LLqbWRM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_40Yzn0J9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2v9hnbEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_sDWIp0F4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hJiF473K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8A3nBfcB, HV_BINOP_GREATER_THAN, 1, m, &cBinop_8A3nBfcB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JT3nmmdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zjnOjSys, HV_BINOP_EQ, 1, m, &cBinop_zjnOjSys_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3WxUgMmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8A3nBfcB, HV_BINOP_GREATER_THAN, 0, m, &cBinop_8A3nBfcB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sX2Ng8bq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2v9hnbEd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_NF95rGIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HDCKI7bg, 0, m, &cVar_HDCKI7bg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CeMbVcX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zjnOjSys, HV_BINOP_EQ, 0, m, &cBinop_zjnOjSys_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_Aj8As7KZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PJlksfOK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UDwLoU5o_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HNqiRNEs, 0, m, &cSlice_HNqiRNEs_sendMessage);
      break;
    }
    default: {
      cSwitchcase_10VbPd7M_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_HNqiRNEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ny5xVqij_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ny5xVqij_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ZVcCdinu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ny5xVqij_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ny5xVqij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_btM8hIZD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_10VbPd7M_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_779EDx9t, 0, m, &cSlice_779EDx9t_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pIiw6xOb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_779EDx9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Im9RUdSb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Im9RUdSb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_6HVuIM0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Im9RUdSb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Im9RUdSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lRpP0hsU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8ENG6NSu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SpQS44pB, 0, m, &cSlice_SpQS44pB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4lFjRuYL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_SpQS44pB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Ei4G43Pm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Ei4G43Pm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3YxGIfqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ei4G43Pm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Ei4G43Pm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qySrtmQ7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4lFjRuYL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cP3BzFln, 0, m, &cSlice_cP3BzFln_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_cP3BzFln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IbhiHEe2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IbhiHEe2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GGCOpbLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IbhiHEe2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_IbhiHEe2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XquoLF4a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lbv3IxTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AOhYMSCx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Prn006xj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0qtg9GTz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bfe99dPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hJe11JTT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1CptuPxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fIk6GPA8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cqGqFG84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0TXHjwy5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CK0Ql1JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_K10GCkfc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_K10GCkfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3fzRUD9M, HV_BINOP_DIVIDE, 1, m, &cBinop_3fzRUD9M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_msYFVdaj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_ECEDdIao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_BbtnpdWs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PJCnYL5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ECEDdIao_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BbtnpdWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3fzRUD9M, HV_BINOP_DIVIDE, 0, m, &cBinop_3fzRUD9M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_msYFVdaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PJCnYL5N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_3fzRUD9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iS849c08, HV_BINOP_MULTIPLY, 1, m, &cBinop_iS849c08_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iS849c08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f3FJLVre_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0wNMZ3Zy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_JGIdAb52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_a0z0YOcM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_ykbLmycp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eZ1ozeHR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_EQmhVsKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_D9nO8EQm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D9nO8EQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iS849c08, HV_BINOP_MULTIPLY, 0, m, &cBinop_iS849c08_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bJvR7Eie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Pi5xznKh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Pi5xznKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pqzrfrsV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_rxzXrZHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_67i5FgAh, 1, m, &cVar_67i5FgAh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_67i5FgAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RWHpCehC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_tvV01O0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZL4D2BkL, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZL4D2BkL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mEFwBMYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tvV01O0f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MQoM6M89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0cXLTvsp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0cXLTvsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M5VEcc8g, HV_BINOP_MULTIPLY, 1, m, &cBinop_M5VEcc8g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jsjtp3XZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yiVNgx1N, HV_BINOP_MULTIPLY, 1, m, &cBinop_yiVNgx1N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2kBvZNRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jsjtp3XZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rWZklM9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jmoqnOpH, HV_BINOP_MULTIPLY, 1, m, &cBinop_jmoqnOpH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_25gGFcGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fDFDfulj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fDFDfulj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YqUQfFQz, HV_BINOP_MULTIPLY, 1, m, &cBinop_YqUQfFQz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_5BBDrIb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dwBrQRLY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_EQmhVsKP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0z0u99me_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_6gsMX7Q0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_bJvR7Eie_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f3FJLVre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_JGIdAb52_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0wNMZ3Zy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ykbLmycp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_a0z0YOcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6PxujwKo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_eZ1ozeHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ITeliLSH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_QWGTqE26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0nte55Mp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pqzrfrsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LGG6RMZ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LGG6RMZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tT1z7LRs, HV_BINOP_MULTIPLY, 1, m, &cBinop_tT1z7LRs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tT1z7LRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Z64kdlmq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Z64kdlmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QWGTqE26_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RWHpCehC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_L7E33V0i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L7E33V0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kQtCrSjF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7FyditH9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6nZtspVq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GS3h6UnO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_km4QBkT6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aR51ev49_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZL4D2BkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lbv3IxTv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_M5VEcc8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Prn006xj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_yiVNgx1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bfe99dPS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_jmoqnOpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1CptuPxz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_YqUQfFQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cqGqFG84_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_U0xnsyvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5BBDrIb1, 0, m, &cVar_5BBDrIb1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z5JUO7st_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6gsMX7Q0, 1, m, &cVar_6gsMX7Q0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7FyditH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YqUQfFQz, HV_BINOP_MULTIPLY, 0, m, &cBinop_YqUQfFQz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_km4QBkT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M5VEcc8g, HV_BINOP_MULTIPLY, 0, m, &cBinop_M5VEcc8g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aR51ev49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZL4D2BkL, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZL4D2BkL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kQtCrSjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_GS3h6UnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yiVNgx1N, HV_BINOP_MULTIPLY, 0, m, &cBinop_yiVNgx1N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6nZtspVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jmoqnOpH, HV_BINOP_MULTIPLY, 0, m, &cBinop_jmoqnOpH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0z0u99me_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_67i5FgAh, 0, m, &cVar_67i5FgAh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dwBrQRLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6gsMX7Q0, 0, m, &cVar_6gsMX7Q0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_G8TNGvcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YsOK3q8m, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AAh0SFeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LxPvXehJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_b2kIlkje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TYdsVxTG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GDJC2efn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EiYTq00V, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vGg8KU27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UWJbizfx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_UWJbizfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aqbHj8ix, HV_BINOP_DIVIDE, 1, m, &cBinop_aqbHj8ix_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gSjuA8ke_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_cFpkhBXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_UNbsLOFq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R3lFIc0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_cFpkhBXF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UNbsLOFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aqbHj8ix, HV_BINOP_DIVIDE, 0, m, &cBinop_aqbHj8ix_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gSjuA8ke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R3lFIc0N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_aqbHj8ix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5RjJJKQS, HV_BINOP_MULTIPLY, 1, m, &cBinop_5RjJJKQS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5RjJJKQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DAIGfQcr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hw1kpLl7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_9KDcvalU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UMN9JpRM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_gLhwTpaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gE6scNIJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Weh8TM5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_6nmOGWXc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6nmOGWXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5RjJJKQS, HV_BINOP_MULTIPLY, 0, m, &cBinop_5RjJJKQS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PSx1JpZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_wCax951Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wCax951Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bk38WZC8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_slWZOd6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kjwVAkui, HV_BINOP_MULTIPLY, 1, m, &cBinop_kjwVAkui_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1oYQvzdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a614hpDJ, 1, m, &cVar_a614hpDJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bpfk01RM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yZwM4dUk, HV_BINOP_MULTIPLY, 1, m, &cBinop_yZwM4dUk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jqB29Z69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XjxRAvLz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XjxRAvLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fgNT0Jcm, HV_BINOP_MULTIPLY, 1, m, &cBinop_fgNT0Jcm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_a614hpDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HDS1prNV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_e1sEp9ve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B47OueKC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Weh8TM5t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uHa2csqd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_SEAAGHM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_PSx1JpZf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DAIGfQcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_9KDcvalU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Hw1kpLl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_gLhwTpaR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_UMN9JpRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QaRU7Ygz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_gE6scNIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_e4B9sPNv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Yc9IJarw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pu0YKREN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Bk38WZC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6nEewsoR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6nEewsoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xXL6YYNb, HV_BINOP_MULTIPLY, 1, m, &cBinop_xXL6YYNb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xXL6YYNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_X2mC6Bnx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_X2mC6Bnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Yc9IJarw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HDS1prNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0BAtGyRb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0BAtGyRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5aphICbM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wpy37IDB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cpmUMFPF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sUEqjPdb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_v8Hefri0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G8TNGvcG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_kjwVAkui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AAh0SFeW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_yZwM4dUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b2kIlkje_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_fgNT0Jcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GDJC2efn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_pIRMcl4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SEAAGHM3, 1, m, &cVar_SEAAGHM3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_69b6jdno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e1sEp9ve, 0, m, &cVar_e1sEp9ve_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uHa2csqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a614hpDJ, 0, m, &cVar_a614hpDJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_B47OueKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SEAAGHM3, 0, m, &cVar_SEAAGHM3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5aphICbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fgNT0Jcm, HV_BINOP_MULTIPLY, 0, m, &cBinop_fgNT0Jcm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sUEqjPdb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v8Hefri0, HV_BINOP_MULTIPLY, 0, m, &cBinop_v8Hefri0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cpmUMFPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kjwVAkui, HV_BINOP_MULTIPLY, 0, m, &cBinop_kjwVAkui_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wpy37IDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yZwM4dUk, HV_BINOP_MULTIPLY, 0, m, &cBinop_yZwM4dUk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YqrVw8OU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wOBivBL0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xk1ayEmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J3LuU9yn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7xdh6vXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rei1ZE9S, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NLPqpUq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VIRQ1hLE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OYEEqeIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tFOJ0HXl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_T1k4X9Cs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gxCpMhFY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_gxCpMhFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MV8ymh3N, HV_BINOP_DIVIDE, 1, m, &cBinop_MV8ymh3N_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8rMuJfHe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_ncMz73Jr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_LB8yICJh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eXCJhsAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ncMz73Jr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LB8yICJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MV8ymh3N, HV_BINOP_DIVIDE, 0, m, &cBinop_MV8ymh3N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8rMuJfHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eXCJhsAo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_MV8ymh3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X4DzLsle, HV_BINOP_MULTIPLY, 1, m, &cBinop_X4DzLsle_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_X4DzLsle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sEF8XjXE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Kp4F8M6q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_fUFEGCtt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uwmxQABm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_reWVDdL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Nc36eWUj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_HgxDZXf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_d1eRpju0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d1eRpju0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X4DzLsle, HV_BINOP_MULTIPLY, 0, m, &cBinop_X4DzLsle_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5kzNZUPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_YkkAyTFu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YkkAyTFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s1wPacgy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_qHARUhfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mS1sEUh7, HV_BINOP_MULTIPLY, 1, m, &cBinop_mS1sEUh7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oeXdGiZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_IDp2KYUe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IDp2KYUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qHARUhfO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Iq8GclSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Z95MgQsU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Z95MgQsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mUBTtB4N, HV_BINOP_MULTIPLY, 1, m, &cBinop_mUBTtB4N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sa34ZqMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t1F27EYr, HV_BINOP_MULTIPLY, 1, m, &cBinop_t1F27EYr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_29MM8uN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VlMeiRp0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VlMeiRp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sa34ZqMf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_61dDhOlK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jjZnv9O8, 1, m, &cVar_jjZnv9O8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0bD7l6Iz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2t3znAV4, HV_BINOP_MULTIPLY, 1, m, &cBinop_2t3znAV4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DtZAVpLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8nUgNbY3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8nUgNbY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wKLlhCJM, HV_BINOP_MULTIPLY, 1, m, &cBinop_wKLlhCJM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_jjZnv9O8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lgg14alq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ua7fajCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8wuiCodZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_HgxDZXf6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8yYscg1v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_smvdDYcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_5kzNZUPW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Kp4F8M6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_reWVDdL4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sEF8XjXE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_fUFEGCtt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_uwmxQABm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oETZPW2q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Nc36eWUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_H65yZ30g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_KJDFFy6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hPsxYuyV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_s1wPacgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kORX5wpq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kORX5wpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_POtlFmRC, HV_BINOP_MULTIPLY, 1, m, &cBinop_POtlFmRC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_POtlFmRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_GlkuyeOh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GlkuyeOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KJDFFy6K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lgg14alq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bxhVu9tG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bxhVu9tG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WGhu35w7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cKvd9mEZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vAwvfpr8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RZ5WQWCC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I38aBM3E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9Os7FPv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mS1sEUh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YqrVw8OU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_mUBTtB4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xk1ayEmc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_t1F27EYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7xdh6vXy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_2t3znAV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NLPqpUq9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wKLlhCJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OYEEqeIq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_f7zkuRay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ua7fajCy, 0, m, &cVar_ua7fajCy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tvuxfOvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_smvdDYcc, 1, m, &cVar_smvdDYcc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X9Os7FPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mS1sEUh7, HV_BINOP_MULTIPLY, 0, m, &cBinop_mS1sEUh7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I38aBM3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mUBTtB4N, HV_BINOP_MULTIPLY, 0, m, &cBinop_mUBTtB4N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cKvd9mEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wKLlhCJM, HV_BINOP_MULTIPLY, 0, m, &cBinop_wKLlhCJM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vAwvfpr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2t3znAV4, HV_BINOP_MULTIPLY, 0, m, &cBinop_2t3znAV4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WGhu35w7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_RZ5WQWCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t1F27EYr, HV_BINOP_MULTIPLY, 0, m, &cBinop_t1F27EYr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8wuiCodZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_smvdDYcc, 0, m, &cVar_smvdDYcc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8yYscg1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jjZnv9O8, 0, m, &cVar_jjZnv9O8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n5WANJvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Aj8As7KZ, 1, m, &cIf_Aj8As7KZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yk8IHs6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_PJlksfOK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_lYyFkvGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yk8IHs6I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Wu1Df8nS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Aj8As7KZ, 0, m, &cIf_Aj8As7KZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LrRasBHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S41LmQHg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PJlksfOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GKuUAZRb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_40Yzn0J9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gD0ejcST, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sQ4xzloD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_n5WANJvP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lYyFkvGQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Hsn8srAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Wu1Df8nS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_SvvMEBSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w42YnwFd, HV_BINOP_DIVIDE, 0, m, &cBinop_w42YnwFd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_aQnh1Ejj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4UxIfNKk, HV_BINOP_DIVIDE, 1, m, &cBinop_4UxIfNKk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_w42YnwFd, HV_BINOP_DIVIDE, 1, m, &cBinop_w42YnwFd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_kQbkA8Px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NF0JEzBJ, HV_BINOP_DIVIDE, 0, m, &cBinop_NF0JEzBJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_4yWTiYDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NF0JEzBJ, HV_BINOP_DIVIDE, 1, m, &cBinop_NF0JEzBJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ShEpcgSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SvvMEBSW, 0, m, &cVar_SvvMEBSW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TWUb8lLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4UxIfNKk, HV_BINOP_DIVIDE, 0, m, &cBinop_4UxIfNKk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KpaxiY1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aQnh1Ejj, 0, m, &cVar_aQnh1Ejj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4UxIfNKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_kQbkA8Px_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_w42YnwFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_4yWTiYDy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NF0JEzBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_5NdWUeud_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_iArektJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_yizyjPSR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fyM0ISHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_yeemLc29_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5NdWUeud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fyM0ISHt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yeemLc29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_iArektJ9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yizyjPSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jzv4RNU5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_szHQx403_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JRoGNJVI, 0, m, &cSlice_JRoGNJVI_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_JRoGNJVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ApHmH5Ly_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ApHmH5Ly_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_zEIlwV5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ApHmH5Ly_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ApHmH5Ly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uGfPaAjP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_dSu2lsKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6kJuchoK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6kJuchoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_0Fbtj61c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0Fbtj61c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_0W4buooc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0W4buooc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JE0dFYVT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gkfJq2j7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gkfJq2j7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HEaBQPle_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JE0dFYVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_WinaAGUa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WinaAGUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kXgwJLxF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HEaBQPle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kZL8sNjn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kZL8sNjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_aK0PsKrp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kXgwJLxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YU9Saie5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_aK0PsKrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J9bRORXp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YU9Saie5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6fu6NTyW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_J9bRORXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8bVpYlcl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_Oj4A7OKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qj8hLaeM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_bIZpjZpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pkcqIhoh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_R87j9nVG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xmpal60A_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_noUrZ42O_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8AdogxLZ_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q6s66hwF_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K9PCrZ6f_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yUJbym2H_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_Xmpal60A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HdwNwKU6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_noUrZ42O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_psGRutt1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_8AdogxLZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vbf4TyNu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Q6s66hwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DOxMOjr9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_K9PCrZ6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QEnUvz2n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_yUJbym2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3wjuR4iA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_lSVu5GeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ARjD9xHI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_O2SaXXXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bhHCMfgo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IFVpAQFw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YgKtrgnl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YgKtrgnl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ncBZq8nt, 1, m, &cDelay_ncBZq8nt_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uTQBYTqH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ncBZq8nt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ncBZq8nt, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lSVu5GeI, 0, m, &cIf_lSVu5GeI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YgKtrgnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ncBZq8nt, 0, m, &cDelay_ncBZq8nt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uTQBYTqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ncBZq8nt, 0, m, &cDelay_ncBZq8nt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cxbijBVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MDSaNsvc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f8hUYw2q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hJdf11BK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PltLYA0S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6rKecUy7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6rKecUy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IFVpAQFw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_PltLYA0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lSVu5GeI, 1, m, &cIf_lSVu5GeI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f8hUYw2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O2SaXXXd, 0, m, &cIf_O2SaXXXd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MDSaNsvc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O2SaXXXd, 1, m, &cIf_O2SaXXXd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bhHCMfgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Opn4Jii6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ARjD9xHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Opn4Jii6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_C8yCcb19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_J0pYTz0x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_S7KVMWuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0Aclvhmy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4ozAPSSK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_pbi4dQfT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_pbi4dQfT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8RDCL34R, 1, m, &cDelay_8RDCL34R_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hwAnyNuV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_8RDCL34R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8RDCL34R, m);
  cIf_onMessage(_c, &Context(_c)->cIf_C8yCcb19, 0, m, &cIf_C8yCcb19_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pbi4dQfT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8RDCL34R, 0, m, &cDelay_8RDCL34R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hwAnyNuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8RDCL34R, 0, m, &cDelay_8RDCL34R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d4qkulum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fAeTh8nk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QYTG6vnE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O3kzs31y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4uSdtnw3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QtZGL4t7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4uSdtnw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_C8yCcb19, 1, m, &cIf_C8yCcb19_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QtZGL4t7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4ozAPSSK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fAeTh8nk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S7KVMWuV, 1, m, &cIf_S7KVMWuV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QYTG6vnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S7KVMWuV, 0, m, &cIf_S7KVMWuV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0Aclvhmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uVjYDY1T, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_J0pYTz0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uVjYDY1T, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_byoN0JGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5Fq36Dxq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qL0dLI8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FBxfYQjy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pd1HVkfe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CjCPMoNS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CjCPMoNS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_bGJPAzYl, 1, m, &cDelay_bGJPAzYl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gvk31shl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_bGJPAzYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bGJPAzYl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_byoN0JGe, 0, m, &cIf_byoN0JGe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CjCPMoNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bGJPAzYl, 0, m, &cDelay_bGJPAzYl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gvk31shl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bGJPAzYl, 0, m, &cDelay_bGJPAzYl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fG96ulUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GTy3MmSy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xLJxZw77_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eZQCYCfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sc4580pY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YZASm7Xb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YZASm7Xb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pd1HVkfe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sc4580pY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_byoN0JGe, 1, m, &cIf_byoN0JGe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GTy3MmSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qL0dLI8P, 1, m, &cIf_qL0dLI8P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xLJxZw77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qL0dLI8P, 0, m, &cIf_qL0dLI8P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FBxfYQjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1UyiRAFS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5Fq36Dxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1UyiRAFS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_x75mQZ3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hGNyEsSZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_g0eapp7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mi1KQuoE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_z5SYQFk0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sQVadEB5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sQVadEB5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_SQJ3vaN8, 1, m, &cDelay_SQJ3vaN8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J29DB6RU_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_SQJ3vaN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SQJ3vaN8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_x75mQZ3i, 0, m, &cIf_x75mQZ3i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sQVadEB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SQJ3vaN8, 0, m, &cDelay_SQJ3vaN8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_J29DB6RU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SQJ3vaN8, 0, m, &cDelay_SQJ3vaN8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hCDkYMJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2LGafD3M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1BfSvBzQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0JQNMXuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oWdVc40F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NuOd6cd8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NuOd6cd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_z5SYQFk0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_oWdVc40F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x75mQZ3i, 1, m, &cIf_x75mQZ3i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1BfSvBzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g0eapp7g, 0, m, &cIf_g0eapp7g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2LGafD3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g0eapp7g, 1, m, &cIf_g0eapp7g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mi1KQuoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cekNCDO8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hGNyEsSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cekNCDO8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_R9PxDJp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Gv1eGJ6d_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1gcr4NZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W2a6X5mV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SCybbfPO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TN0JDJvU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TN0JDJvU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lgT8wfiG, 1, m, &cDelay_lgT8wfiG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rt0N0k6t_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_lgT8wfiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lgT8wfiG, m);
  cIf_onMessage(_c, &Context(_c)->cIf_R9PxDJp4, 0, m, &cIf_R9PxDJp4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TN0JDJvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lgT8wfiG, 0, m, &cDelay_lgT8wfiG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Rt0N0k6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lgT8wfiG, 0, m, &cDelay_lgT8wfiG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NM1l89Qt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jrCcapw7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5GCROxN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uhdLbk1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9PqvLcPh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5zf9y6yS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5zf9y6yS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SCybbfPO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_9PqvLcPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R9PxDJp4, 1, m, &cIf_R9PxDJp4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c5GCROxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1gcr4NZg, 0, m, &cIf_1gcr4NZg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jrCcapw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1gcr4NZg, 1, m, &cIf_1gcr4NZg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W2a6X5mV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mhu9rxNI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Gv1eGJ6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mhu9rxNI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_AXBxuG0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_t5CWKBx0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_F81Gy1Wv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9c2Sao3s_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_t02iIkHH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bBAL5gya_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bBAL5gya_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ICAqj3kt, 1, m, &cDelay_ICAqj3kt_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K6fQkoDb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ICAqj3kt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ICAqj3kt, m);
  cIf_onMessage(_c, &Context(_c)->cIf_AXBxuG0j, 0, m, &cIf_AXBxuG0j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bBAL5gya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ICAqj3kt, 0, m, &cDelay_ICAqj3kt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K6fQkoDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ICAqj3kt, 0, m, &cDelay_ICAqj3kt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UP0NZtwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4JOZpfq9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vI6frZI6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vk2cgpUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WQ1KzMJh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NyWYWE97_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WQ1KzMJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AXBxuG0j, 1, m, &cIf_AXBxuG0j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NyWYWE97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_t02iIkHH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4JOZpfq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F81Gy1Wv, 1, m, &cIf_F81Gy1Wv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vI6frZI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F81Gy1Wv, 0, m, &cIf_F81Gy1Wv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9c2Sao3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NScTiuMk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_t5CWKBx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NScTiuMk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_J9zy9h2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rUudx6Z7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_S9hc6vdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_euaGSqQn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Pm514ZxP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_awiTs4rw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_awiTs4rw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5dekMLTj, 1, m, &cDelay_5dekMLTj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3lFHHnWr_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5dekMLTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5dekMLTj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_J9zy9h2f, 0, m, &cIf_J9zy9h2f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_awiTs4rw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5dekMLTj, 0, m, &cDelay_5dekMLTj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3lFHHnWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5dekMLTj, 0, m, &cDelay_5dekMLTj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7or4icSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7AL1x4sH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JPmHplFx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PObRvU2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2jJ6pazh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q1Nu20cY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2jJ6pazh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J9zy9h2f, 1, m, &cIf_J9zy9h2f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q1Nu20cY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Pm514ZxP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_7AL1x4sH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S9hc6vdN, 1, m, &cIf_S9hc6vdN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JPmHplFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S9hc6vdN, 0, m, &cIf_S9hc6vdN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_euaGSqQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MJGn8zBx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rUudx6Z7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MJGn8zBx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_eYOt1iBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HwVAVohm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lkUORr64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_j1hOwUtu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0dCcVNC7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rThw58V2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rThw58V2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xyo9DM4D, 1, m, &cDelay_xyo9DM4D_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_etvY3ot6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xyo9DM4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xyo9DM4D, m);
  cIf_onMessage(_c, &Context(_c)->cIf_eYOt1iBx, 0, m, &cIf_eYOt1iBx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rThw58V2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xyo9DM4D, 0, m, &cDelay_xyo9DM4D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_etvY3ot6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xyo9DM4D, 0, m, &cDelay_xyo9DM4D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lWxFmtUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jWTGamTj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GBa0uQAr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XH8WfuUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZONkUYA2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aiyM0gND_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aiyM0gND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0dCcVNC7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZONkUYA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eYOt1iBx, 1, m, &cIf_eYOt1iBx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jWTGamTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lkUORr64, 1, m, &cIf_lkUORr64_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GBa0uQAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lkUORr64, 0, m, &cIf_lkUORr64_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_j1hOwUtu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WJNjnM0b, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HwVAVohm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WJNjnM0b, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_G8tfZ1G5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fzwwTIFh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bW8lBpYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QGs6veg6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lSroQhGF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jUFwAH32_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jUFwAH32_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_t1OEa1Zo, 1, m, &cDelay_t1OEa1Zo_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1IkSIIfH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_t1OEa1Zo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_t1OEa1Zo, m);
  cIf_onMessage(_c, &Context(_c)->cIf_G8tfZ1G5, 0, m, &cIf_G8tfZ1G5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jUFwAH32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_t1OEa1Zo, 0, m, &cDelay_t1OEa1Zo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1IkSIIfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_t1OEa1Zo, 0, m, &cDelay_t1OEa1Zo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6hMntqTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vavRyDe3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bOtwE3gl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DHJpLNNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I9L2cRj3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_itkWyvX9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_itkWyvX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lSroQhGF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_I9L2cRj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G8tfZ1G5, 1, m, &cIf_G8tfZ1G5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vavRyDe3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bW8lBpYr, 1, m, &cIf_bW8lBpYr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bOtwE3gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bW8lBpYr, 0, m, &cIf_bW8lBpYr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QGs6veg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hn2kkQd5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fzwwTIFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hn2kkQd5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_axAySBrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TBmwnqIT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_0rT7rU2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QqaiRt1V_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8kIUHiBs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_U266erqn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_U266erqn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XwsXlcyO, 1, m, &cDelay_XwsXlcyO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5x4wTcPE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_XwsXlcyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XwsXlcyO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_axAySBrJ, 0, m, &cIf_axAySBrJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U266erqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XwsXlcyO, 0, m, &cDelay_XwsXlcyO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5x4wTcPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XwsXlcyO, 0, m, &cDelay_XwsXlcyO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cryoL7Nn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3OEpxKZF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E0WtVzt1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Geu2Lg4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V5o4NrvL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2rGqyY9q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V5o4NrvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_axAySBrJ, 1, m, &cIf_axAySBrJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2rGqyY9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8kIUHiBs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3OEpxKZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0rT7rU2z, 1, m, &cIf_0rT7rU2z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E0WtVzt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0rT7rU2z, 0, m, &cIf_0rT7rU2z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QqaiRt1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2IVthB2H, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TBmwnqIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2IVthB2H, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_UtIQxqAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wmUnRMlM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_w7FIZ7V0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3VkGoDLL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tuo13TSr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bPLXfkSo_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bPLXfkSo_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_c9Yot7Xy, 1, m, &cDelay_c9Yot7Xy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_usHepfOA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_c9Yot7Xy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_c9Yot7Xy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_UtIQxqAN, 0, m, &cIf_UtIQxqAN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bPLXfkSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_c9Yot7Xy, 0, m, &cDelay_c9Yot7Xy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_usHepfOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_c9Yot7Xy, 0, m, &cDelay_c9Yot7Xy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NfDVXBqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g0sBNsEH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ADVbuYCP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fIIUWTL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4vAJZS8D_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8jx2uTb6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8jx2uTb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tuo13TSr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4vAJZS8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UtIQxqAN, 1, m, &cIf_UtIQxqAN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ADVbuYCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w7FIZ7V0, 0, m, &cIf_w7FIZ7V0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_g0sBNsEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w7FIZ7V0, 1, m, &cIf_w7FIZ7V0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3VkGoDLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u37Nps0Z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wmUnRMlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u37Nps0Z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_1wDijQ37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lZDKXplV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lvMQZPGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0EUahNz3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OAgI53I2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mKfmhy42_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mKfmhy42_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_bjqlbF7Y, 1, m, &cDelay_bjqlbF7Y_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rwaVuzRX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_bjqlbF7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bjqlbF7Y, m);
  cIf_onMessage(_c, &Context(_c)->cIf_1wDijQ37, 0, m, &cIf_1wDijQ37_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mKfmhy42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bjqlbF7Y, 0, m, &cDelay_bjqlbF7Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rwaVuzRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bjqlbF7Y, 0, m, &cDelay_bjqlbF7Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_63KlX7aL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3Pu8Tz8j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DkD4RnPX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8gZNTeoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1LMPbdUr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X0L5HGaA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X0L5HGaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OAgI53I2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1LMPbdUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1wDijQ37, 1, m, &cIf_1wDijQ37_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3Pu8Tz8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lvMQZPGT, 1, m, &cIf_lvMQZPGT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DkD4RnPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lvMQZPGT, 0, m, &cIf_lvMQZPGT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0EUahNz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NeHOBh6o, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lZDKXplV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NeHOBh6o, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HdwNwKU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_6lPB28Rr_sendMessage(_c, 0, m);
  cMsg_IEudJWiY_sendMessage(_c, 0, m);
  cMsg_VjlituOG_sendMessage(_c, 0, m);
  cMsg_zske8N3u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_psGRutt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_6lPB28Rr_sendMessage(_c, 0, m);
  cMsg_RGeczmIN_sendMessage(_c, 0, m);
  cMsg_dedJisDK_sendMessage(_c, 0, m);
  cMsg_SlIeBe3j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vbf4TyNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_AzX77oaM_sendMessage(_c, 0, m);
  cMsg_RGeczmIN_sendMessage(_c, 0, m);
  cMsg_zske8N3u_sendMessage(_c, 0, m);
  cMsg_o6Z8dXzd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DOxMOjr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_AzX77oaM_sendMessage(_c, 0, m);
  cMsg_hDgQsh39_sendMessage(_c, 0, m);
  cMsg_VjlituOG_sendMessage(_c, 0, m);
  cMsg_dEpzqqn0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QEnUvz2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_ExZUfTzZ_sendMessage(_c, 0, m);
  cMsg_SlIeBe3j_sendMessage(_c, 0, m);
  cMsg_nK4BLBV7_sendMessage(_c, 0, m);
  cMsg_VjlituOG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3wjuR4iA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_ExZUfTzZ_sendMessage(_c, 0, m);
  cMsg_dEpzqqn0_sendMessage(_c, 0, m);
  cMsg_RGeczmIN_sendMessage(_c, 0, m);
  cMsg_60mVXcmG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OPohzRN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hJdf11BK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cxbijBVM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nEeSBnSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hJdf11BK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cxbijBVM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LwYIU4rU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_O3kzs31y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_d4qkulum_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iQYEowLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_O3kzs31y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_d4qkulum_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dv0fXvck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eZQCYCfG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fG96ulUM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kDjnthu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eZQCYCfG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fG96ulUM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6lPB28Rr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_OPohzRN7_sendMessage(_c, 0, m);
  cMsg_iQYEowLF_sendMessage(_c, 0, m);
  cMsg_kDjnthu8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AzX77oaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_nEeSBnSR_sendMessage(_c, 0, m);
  cMsg_LwYIU4rU_sendMessage(_c, 0, m);
  cMsg_kDjnthu8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ExZUfTzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_nEeSBnSR_sendMessage(_c, 0, m);
  cMsg_iQYEowLF_sendMessage(_c, 0, m);
  cMsg_dv0fXvck_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SkYHRNh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0JQNMXuF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hCDkYMJ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DnLAHLwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0JQNMXuF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hCDkYMJ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C02iOztK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uhdLbk1q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NM1l89Qt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JzXfm8es_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uhdLbk1q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NM1l89Qt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fKy38NYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vk2cgpUh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UP0NZtwC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wsEHTci7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vk2cgpUh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UP0NZtwC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RGeczmIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_DnLAHLwn_sendMessage(_c, 0, m);
  cMsg_JzXfm8es_sendMessage(_c, 0, m);
  cMsg_wsEHTci7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IEudJWiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_DnLAHLwn_sendMessage(_c, 0, m);
  cMsg_C02iOztK_sendMessage(_c, 0, m);
  cMsg_fKy38NYV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hDgQsh39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_SkYHRNh4_sendMessage(_c, 0, m);
  cMsg_JzXfm8es_sendMessage(_c, 0, m);
  cMsg_fKy38NYV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aaCd5ys8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Geu2Lg4C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cryoL7Nn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qw66zEvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Geu2Lg4C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cryoL7Nn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zmpHXPEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fIIUWTL6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NfDVXBqO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UFnZ52Hq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fIIUWTL6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NfDVXBqO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1VpgTsDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8gZNTeoe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_63KlX7aL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7Qm16Wny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8gZNTeoe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_63KlX7aL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dEpzqqn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_aaCd5ys8_sendMessage(_c, 0, m);
  cMsg_UFnZ52Hq_sendMessage(_c, 0, m);
  cMsg_7Qm16Wny_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SlIeBe3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_qw66zEvJ_sendMessage(_c, 0, m);
  cMsg_zmpHXPEq_sendMessage(_c, 0, m);
  cMsg_7Qm16Wny_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zske8N3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_qw66zEvJ_sendMessage(_c, 0, m);
  cMsg_UFnZ52Hq_sendMessage(_c, 0, m);
  cMsg_1VpgTsDO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0iJfjldT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PObRvU2L_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7or4icSx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1yHgo5lA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PObRvU2L_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7or4icSx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mbjfYxsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XH8WfuUb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lWxFmtUj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_m8MH4gg0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XH8WfuUb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lWxFmtUj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pz7LUFZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DHJpLNNB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6hMntqTi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XaF6i9qd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DHJpLNNB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6hMntqTi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VjlituOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_1yHgo5lA_sendMessage(_c, 0, m);
  cMsg_m8MH4gg0_sendMessage(_c, 0, m);
  cMsg_XaF6i9qd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dedJisDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_1yHgo5lA_sendMessage(_c, 0, m);
  cMsg_mbjfYxsq_sendMessage(_c, 0, m);
  cMsg_pz7LUFZ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_60mVXcmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_0iJfjldT_sendMessage(_c, 0, m);
  cMsg_mbjfYxsq_sendMessage(_c, 0, m);
  cMsg_XaF6i9qd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nK4BLBV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_SkYHRNh4_sendMessage(_c, 0, m);
  cMsg_C02iOztK_sendMessage(_c, 0, m);
  cMsg_wsEHTci7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_o6Z8dXzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_0iJfjldT_sendMessage(_c, 0, m);
  cMsg_m8MH4gg0_sendMessage(_c, 0, m);
  cMsg_pz7LUFZ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_dD1rzvho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4Dgm7jO9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_A1cjFe70_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BIcwOZZg, 0, m, &cSlice_BIcwOZZg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5FqEYHot_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_BIcwOZZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oLy5czn3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oLy5czn3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_c9xBnI8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oLy5czn3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_oLy5czn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8JgDoyPF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GP6LDwfZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_L8XAFiQ0, 0, m, &cSlice_L8XAFiQ0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Be4p3QwC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_L8XAFiQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3bBhh0dE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3bBhh0dE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_M83fCIG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3bBhh0dE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_3bBhh0dE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_B25a8IGz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Be4p3QwC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_I4Qljcmx, 0, m, &cSlice_I4Qljcmx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_A1cjFe70_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_I4Qljcmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_y45ZwGfV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_y45ZwGfV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_5UAAzONG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_y45ZwGfV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_y45ZwGfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vDXrPMbf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5FqEYHot_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gTNAZqu1, 0, m, &cSlice_gTNAZqu1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_30DiLFwc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_gTNAZqu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EkzDBIjp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EkzDBIjp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_lGWefWbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EkzDBIjp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_EkzDBIjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PJrhQlVs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_30DiLFwc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_iMwWFtd8, 0, m, &cSlice_iMwWFtd8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6vRULCXm_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_iMwWFtd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_A0rrXdFx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_A0rrXdFx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_fTCEF38k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_A0rrXdFx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_A0rrXdFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZYD9MMCM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ofyGXzwU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Z3b8q0BN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Z3b8q0BN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EuAktXof, 1, m, &cDelay_EuAktXof_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VLZUXDVo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_EuAktXof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EuAktXof, m);
  cMsg_Gmk2ehTw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Z3b8q0BN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EuAktXof, 0, m, &cDelay_EuAktXof_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VLZUXDVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EuAktXof, 0, m, &cDelay_EuAktXof_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_whNx5gkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Aao0obeY, HV_BINOP_SUBTRACT, 0, m, &cBinop_Aao0obeY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_XcFDszuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0IFmErHL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kQvJhEBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0IFmErHL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_Gd2P1O9f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_whNx5gkl, 0, m, &cVar_whNx5gkl_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_hU5NBXq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PI0TqgMJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9BjX5fts_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gzAdW0lO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Aao0obeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NYYM3lxB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NYYM3lxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5jf1orus_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5jf1orus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_8XeXNH7s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mUbJreEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LoB8j3jV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PoLjeI5u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LoB8j3jV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XcFDszuh, 1, m, &cIf_XcFDszuh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PoLjeI5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wme5nUdk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_9SrMwYyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kQvJhEBK, 1, m, &cIf_kQvJhEBK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wme5nUdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_XcFDszuh, 0, m, &cIf_XcFDszuh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8XeXNH7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kQvJhEBK, 0, m, &cIf_kQvJhEBK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9BjX5fts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Aao0obeY, HV_BINOP_SUBTRACT, 1, m, &cBinop_Aao0obeY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gzAdW0lO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_whNx5gkl, 0, m, &cVar_whNx5gkl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PI0TqgMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cMsg_0IFmErHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7JfwaUPA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6vRULCXm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IT0klA8b, 0, m, &cSlice_IT0klA8b_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_IT0klA8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hE13J2p1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hE13J2p1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_iAahEpV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hE13J2p1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_hE13J2p1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2YaiIynC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qj8hLaeM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fZO0Ig5m, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pkcqIhoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oS6FfjSh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_PrbZ45mP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bIZpjZpk, 0, m, &cVar_bIZpjZpk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4Dgm7jO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OmSc8pO4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_93gyTGAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ofyGXzwU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_PtBNJu6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1rXhVz94_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Gmk2ehTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EU04SOaF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1rXhVz94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EU04SOaF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1qjJIaKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_u1MeAO3m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u1MeAO3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bshetkOD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bshetkOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m3LvETdm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_dTCyg6YT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jY4PtEiu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_pQGYgT7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nlUhnP5Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EtRa6Z6O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IryIIkpz_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dzFNbSqX_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XxHrQqjn_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TlbdHrxr_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JeE3BoV5_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IRnO0zKe_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_IryIIkpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UISPHsfF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_dzFNbSqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bf4G7FZa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_XxHrQqjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B9htKfsr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_TlbdHrxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bnBEXGtI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JeE3BoV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HX6toA4J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_IRnO0zKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uT3OZXlv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_kiT99krS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_I3G7cQRj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hNlmvR7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HpshdwLw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OseWUbFk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NzToHoZz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NzToHoZz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ssESGz4A, 1, m, &cDelay_ssESGz4A_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eVs6r6Xo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ssESGz4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ssESGz4A, m);
  cIf_onMessage(_c, &Context(_c)->cIf_kiT99krS, 0, m, &cIf_kiT99krS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NzToHoZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ssESGz4A, 0, m, &cDelay_ssESGz4A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eVs6r6Xo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ssESGz4A, 0, m, &cDelay_ssESGz4A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MmXvRc6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5Gj0ha4T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WUbMewZu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eFheB8rI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kkEuoOVD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l8mLC2aC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l8mLC2aC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OseWUbFk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kkEuoOVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kiT99krS, 1, m, &cIf_kiT99krS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WUbMewZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hNlmvR7A, 0, m, &cIf_hNlmvR7A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5Gj0ha4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hNlmvR7A, 1, m, &cIf_hNlmvR7A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HpshdwLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ai4Rrm7G, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_I3G7cQRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ai4Rrm7G, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_y9OLLYDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XbgEdAdy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qFRsnQaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_R2MEVpOM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gWE07stk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XDeQPqLJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XDeQPqLJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9qSdyX4g, 1, m, &cDelay_9qSdyX4g_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nNL4bYU7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9qSdyX4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9qSdyX4g, m);
  cIf_onMessage(_c, &Context(_c)->cIf_y9OLLYDN, 0, m, &cIf_y9OLLYDN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XDeQPqLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9qSdyX4g, 0, m, &cDelay_9qSdyX4g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nNL4bYU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9qSdyX4g, 0, m, &cDelay_9qSdyX4g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_l1CTjuO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6dopabm3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f7uYKaGC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AqTFfF5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qAzH9GW2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_akARNh7Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qAzH9GW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y9OLLYDN, 1, m, &cIf_y9OLLYDN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_akARNh7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gWE07stk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_6dopabm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qFRsnQaK, 1, m, &cIf_qFRsnQaK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f7uYKaGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qFRsnQaK, 0, m, &cIf_qFRsnQaK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R2MEVpOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xjcHCRuk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XbgEdAdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xjcHCRuk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2f7gCmyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bLaMwNS1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_n2k2xn05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JD4ZGHOK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SmzsH5Vc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ms0otMY9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ms0otMY9_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_j5caUFmy, 1, m, &cDelay_j5caUFmy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yWLgqqRa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_j5caUFmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_j5caUFmy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2f7gCmyB, 0, m, &cIf_2f7gCmyB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ms0otMY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_j5caUFmy, 0, m, &cDelay_j5caUFmy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yWLgqqRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_j5caUFmy, 0, m, &cDelay_j5caUFmy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CPBur5lt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a6YVMtkq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v16ah24t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wtRu6PtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m8GtgJec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FNXSHHTa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FNXSHHTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SmzsH5Vc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_m8GtgJec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2f7gCmyB, 1, m, &cIf_2f7gCmyB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a6YVMtkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n2k2xn05, 1, m, &cIf_n2k2xn05_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v16ah24t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n2k2xn05, 0, m, &cIf_n2k2xn05_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JD4ZGHOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3RXeUR7A, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bLaMwNS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3RXeUR7A, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_PM9e2rQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zGLWHpSV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FV030KCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JZEpO8d3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RRtj73d7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_l0sEh6mQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_l0sEh6mQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KvqV9Ydr, 1, m, &cDelay_KvqV9Ydr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lY6zPL8q_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_KvqV9Ydr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KvqV9Ydr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PM9e2rQz, 0, m, &cIf_PM9e2rQz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l0sEh6mQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KvqV9Ydr, 0, m, &cDelay_KvqV9Ydr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lY6zPL8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KvqV9Ydr, 0, m, &cDelay_KvqV9Ydr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MP8Gu4XI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uMMhrPRA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H5CNKAuL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pq83IDED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BRD5RqG3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f06ajgDs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f06ajgDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RRtj73d7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BRD5RqG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PM9e2rQz, 1, m, &cIf_PM9e2rQz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uMMhrPRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FV030KCa, 1, m, &cIf_FV030KCa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_H5CNKAuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FV030KCa, 0, m, &cIf_FV030KCa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JZEpO8d3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HBTMyIZf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zGLWHpSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HBTMyIZf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_oroNxklm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TaaHtnOj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ZBrIvZUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RdJd5WJn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AnZinC02_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sy8iZHvO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sy8iZHvO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_h9Owo7GV, 1, m, &cDelay_h9Owo7GV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VzP5Vmlk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_h9Owo7GV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h9Owo7GV, m);
  cIf_onMessage(_c, &Context(_c)->cIf_oroNxklm, 0, m, &cIf_oroNxklm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sy8iZHvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_h9Owo7GV, 0, m, &cDelay_h9Owo7GV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VzP5Vmlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_h9Owo7GV, 0, m, &cDelay_h9Owo7GV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hN63bQT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c1PyVy1y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FDFNcq68_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_woGMD4dr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6FWL4u8z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L7lSdvrH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L7lSdvrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AnZinC02_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_6FWL4u8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oroNxklm, 1, m, &cIf_oroNxklm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FDFNcq68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZBrIvZUc, 0, m, &cIf_ZBrIvZUc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c1PyVy1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZBrIvZUc, 1, m, &cIf_ZBrIvZUc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RdJd5WJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8YJRabq6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TaaHtnOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8YJRabq6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_SulS2nth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PApXg5aU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FEiydZ8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_75DjMWxJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tpYpkfbx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_e58oUOss_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_e58oUOss_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TQeZQSlc, 1, m, &cDelay_TQeZQSlc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v7uWITok_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TQeZQSlc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TQeZQSlc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SulS2nth, 0, m, &cIf_SulS2nth_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e58oUOss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TQeZQSlc, 0, m, &cDelay_TQeZQSlc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v7uWITok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TQeZQSlc, 0, m, &cDelay_TQeZQSlc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dB3A6ktZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_raKBepAT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PyBlpxSi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HJ00w5KV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K7PvzBMd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6OYj6zgw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K7PvzBMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SulS2nth, 1, m, &cIf_SulS2nth_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6OYj6zgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tpYpkfbx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_raKBepAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FEiydZ8P, 1, m, &cIf_FEiydZ8P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PyBlpxSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FEiydZ8P, 0, m, &cIf_FEiydZ8P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_75DjMWxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mb0pdEZa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PApXg5aU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mb0pdEZa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_slFgPi7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cBFY4w7N_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_d8uQYM0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0jdTRqNV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ke1Tk1Fo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SgweaeIo_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SgweaeIo_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jJfgfhcb, 1, m, &cDelay_jJfgfhcb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oL1OdnK7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jJfgfhcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jJfgfhcb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_slFgPi7w, 0, m, &cIf_slFgPi7w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SgweaeIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jJfgfhcb, 0, m, &cDelay_jJfgfhcb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oL1OdnK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jJfgfhcb, 0, m, &cDelay_jJfgfhcb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cKNYfJg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0rhVWVyN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JdCMeseq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V5ZvP3rk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B0NXZ0qV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GmmOTZif_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_B0NXZ0qV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_slFgPi7w, 1, m, &cIf_slFgPi7w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GmmOTZif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ke1Tk1Fo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_0rhVWVyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d8uQYM0Q, 1, m, &cIf_d8uQYM0Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JdCMeseq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d8uQYM0Q, 0, m, &cIf_d8uQYM0Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0jdTRqNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N3hcnKQo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cBFY4w7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N3hcnKQo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_8JgKCP0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_c5CIqs3C_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vcdi9adZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_klg8OsGY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ecKZqtFl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_D1II7pmh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_D1II7pmh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_D5LO328a, 1, m, &cDelay_D5LO328a_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YP1UkBwN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_D5LO328a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D5LO328a, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8JgKCP0I, 0, m, &cIf_8JgKCP0I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_D1II7pmh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_D5LO328a, 0, m, &cDelay_D5LO328a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YP1UkBwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_D5LO328a, 0, m, &cDelay_D5LO328a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BSUQ3cFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5sgfrmr3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lnxMYfyl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ivOLDLKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R09i4WNG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LEJoJnKe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LEJoJnKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ecKZqtFl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_R09i4WNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8JgKCP0I, 1, m, &cIf_8JgKCP0I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lnxMYfyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vcdi9adZ, 0, m, &cIf_vcdi9adZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5sgfrmr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vcdi9adZ, 1, m, &cIf_vcdi9adZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_klg8OsGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_REDl5Uqi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_c5CIqs3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_REDl5Uqi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Xa5CAnM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2x0M2ZPK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_GGXmeEzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ORxqeEMu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_f2wDlHx8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Rh2feSYv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Rh2feSYv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Hunrctuy, 1, m, &cDelay_Hunrctuy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ErpjnF8s_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Hunrctuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Hunrctuy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Xa5CAnM7, 0, m, &cIf_Xa5CAnM7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Rh2feSYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Hunrctuy, 0, m, &cDelay_Hunrctuy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ErpjnF8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Hunrctuy, 0, m, &cDelay_Hunrctuy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Owv2jgT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NwtMrPtw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NU6Uiq3M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E4CyJRWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X7R40HWp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_niOpCrDq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X7R40HWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Xa5CAnM7, 1, m, &cIf_Xa5CAnM7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_niOpCrDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_f2wDlHx8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NwtMrPtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GGXmeEzt, 1, m, &cIf_GGXmeEzt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NU6Uiq3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GGXmeEzt, 0, m, &cIf_GGXmeEzt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ORxqeEMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UqEeyZfd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2x0M2ZPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UqEeyZfd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_BpZlm9jY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IHN9dhTW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_VOstMcip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lYgV8CI8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tczFaWXn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HZRT9nBr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HZRT9nBr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kYX1yui1, 1, m, &cDelay_kYX1yui1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nWzUX68d_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_kYX1yui1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kYX1yui1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BpZlm9jY, 0, m, &cIf_BpZlm9jY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HZRT9nBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kYX1yui1, 0, m, &cDelay_kYX1yui1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nWzUX68d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kYX1yui1, 0, m, &cDelay_kYX1yui1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C37MGK93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0PPrFJwk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FS7XdsPi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VwidqHDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fv4qeDG9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M4moo6Ub_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_M4moo6Ub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tczFaWXn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Fv4qeDG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BpZlm9jY, 1, m, &cIf_BpZlm9jY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0PPrFJwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VOstMcip, 1, m, &cIf_VOstMcip_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FS7XdsPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VOstMcip, 0, m, &cIf_VOstMcip_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lYgV8CI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SbSYLvwI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IHN9dhTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SbSYLvwI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_PvhtSkbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nQS2BcXM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_yIE2iri9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Vu8Q0KXX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ezGR60gM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LRFjf3q4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LRFjf3q4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_iaseVmfn, 1, m, &cDelay_iaseVmfn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OnoUobm5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_iaseVmfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iaseVmfn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PvhtSkbO, 0, m, &cIf_PvhtSkbO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LRFjf3q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_iaseVmfn, 0, m, &cDelay_iaseVmfn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OnoUobm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_iaseVmfn, 0, m, &cDelay_iaseVmfn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_17Oz4weD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bmyN6pUa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Nkq0g33w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5A8WRchS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JrvBFNU5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XKemBP85_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XKemBP85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ezGR60gM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_JrvBFNU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PvhtSkbO, 1, m, &cIf_PvhtSkbO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bmyN6pUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yIE2iri9, 1, m, &cIf_yIE2iri9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Nkq0g33w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yIE2iri9, 0, m, &cIf_yIE2iri9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vu8Q0KXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XFQ13COj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nQS2BcXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XFQ13COj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_4aWnjP96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_piVNgyd0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_WD40CjnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_inGDJJlu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lZPL0Tc4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8aIyhnuG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8aIyhnuG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OOGVPRmC, 1, m, &cDelay_OOGVPRmC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3jpGHkK9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_OOGVPRmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OOGVPRmC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4aWnjP96, 0, m, &cIf_4aWnjP96_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8aIyhnuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OOGVPRmC, 0, m, &cDelay_OOGVPRmC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3jpGHkK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OOGVPRmC, 0, m, &cDelay_OOGVPRmC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NbDQY5Cb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xfEKXXme_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aapjxuqS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_82eZiG42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gyzlLdMN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hu9uf5Kk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hu9uf5Kk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lZPL0Tc4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_gyzlLdMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4aWnjP96, 1, m, &cIf_4aWnjP96_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xfEKXXme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WD40CjnL, 1, m, &cIf_WD40CjnL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aapjxuqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WD40CjnL, 0, m, &cIf_WD40CjnL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_inGDJJlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NolKfIJy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_piVNgyd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NolKfIJy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UISPHsfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_qZ8RJOgM_sendMessage(_c, 0, m);
  cMsg_mcLB1SdW_sendMessage(_c, 0, m);
  cMsg_GYoMHdOh_sendMessage(_c, 0, m);
  cMsg_EcI30HlM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Bf4G7FZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_qZ8RJOgM_sendMessage(_c, 0, m);
  cMsg_aIdjnUqD_sendMessage(_c, 0, m);
  cMsg_9sk6NXa2_sendMessage(_c, 0, m);
  cMsg_CeOzHXYt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_B9htKfsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_nqV9XVWH_sendMessage(_c, 0, m);
  cMsg_aIdjnUqD_sendMessage(_c, 0, m);
  cMsg_EcI30HlM_sendMessage(_c, 0, m);
  cMsg_8JLy2LqU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bnBEXGtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_nqV9XVWH_sendMessage(_c, 0, m);
  cMsg_JR5BLkTk_sendMessage(_c, 0, m);
  cMsg_GYoMHdOh_sendMessage(_c, 0, m);
  cMsg_xMcGoJID_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HX6toA4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_AJxL6fYv_sendMessage(_c, 0, m);
  cMsg_CeOzHXYt_sendMessage(_c, 0, m);
  cMsg_reuny1iy_sendMessage(_c, 0, m);
  cMsg_GYoMHdOh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uT3OZXlv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_AJxL6fYv_sendMessage(_c, 0, m);
  cMsg_xMcGoJID_sendMessage(_c, 0, m);
  cMsg_aIdjnUqD_sendMessage(_c, 0, m);
  cMsg_OpQA42im_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_x7zM37YK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eFheB8rI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MmXvRc6Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eYx2zf7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eFheB8rI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MmXvRc6Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mgmFtKbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AqTFfF5g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_l1CTjuO1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FzeU3QLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AqTFfF5g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_l1CTjuO1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sBLafFuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wtRu6PtR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CPBur5lt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kYE1yYJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wtRu6PtR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CPBur5lt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qZ8RJOgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_x7zM37YK_sendMessage(_c, 0, m);
  cMsg_FzeU3QLl_sendMessage(_c, 0, m);
  cMsg_kYE1yYJF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nqV9XVWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_eYx2zf7z_sendMessage(_c, 0, m);
  cMsg_mgmFtKbq_sendMessage(_c, 0, m);
  cMsg_kYE1yYJF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AJxL6fYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_eYx2zf7z_sendMessage(_c, 0, m);
  cMsg_FzeU3QLl_sendMessage(_c, 0, m);
  cMsg_sBLafFuH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EZIIrf6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pq83IDED_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MP8Gu4XI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bpbdXMba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pq83IDED_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MP8Gu4XI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6nebOtk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_woGMD4dr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hN63bQT5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IJ4nGMwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_woGMD4dr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hN63bQT5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IcvGMNfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HJ00w5KV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dB3A6ktZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bku3HagK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HJ00w5KV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dB3A6ktZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aIdjnUqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_bpbdXMba_sendMessage(_c, 0, m);
  cMsg_IJ4nGMwJ_sendMessage(_c, 0, m);
  cMsg_bku3HagK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mcLB1SdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_bpbdXMba_sendMessage(_c, 0, m);
  cMsg_6nebOtk9_sendMessage(_c, 0, m);
  cMsg_IcvGMNfp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JR5BLkTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_EZIIrf6r_sendMessage(_c, 0, m);
  cMsg_IJ4nGMwJ_sendMessage(_c, 0, m);
  cMsg_IcvGMNfp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gjmwbe1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VwidqHDQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_C37MGK93_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WrxWJdpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VwidqHDQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_C37MGK93_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7DUOWiPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5A8WRchS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_17Oz4weD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uW8COHRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5A8WRchS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_17Oz4weD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yylghYqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_82eZiG42_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NbDQY5Cb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZQcsRrVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_82eZiG42_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NbDQY5Cb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xMcGoJID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_gjmwbe1O_sendMessage(_c, 0, m);
  cMsg_uW8COHRA_sendMessage(_c, 0, m);
  cMsg_ZQcsRrVE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CeOzHXYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_WrxWJdpb_sendMessage(_c, 0, m);
  cMsg_7DUOWiPq_sendMessage(_c, 0, m);
  cMsg_ZQcsRrVE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EcI30HlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_WrxWJdpb_sendMessage(_c, 0, m);
  cMsg_uW8COHRA_sendMessage(_c, 0, m);
  cMsg_yylghYqJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9HLHaEf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_V5ZvP3rk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cKNYfJg3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DM0dXAEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_V5ZvP3rk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cKNYfJg3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8MKhe5rI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ivOLDLKY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BSUQ3cFZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_J2ZCBtYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ivOLDLKY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BSUQ3cFZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JxBeR8l4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_E4CyJRWw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Owv2jgT0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oRHarnBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_E4CyJRWw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Owv2jgT0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GYoMHdOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_DM0dXAEI_sendMessage(_c, 0, m);
  cMsg_J2ZCBtYb_sendMessage(_c, 0, m);
  cMsg_oRHarnBr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9sk6NXa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_DM0dXAEI_sendMessage(_c, 0, m);
  cMsg_8MKhe5rI_sendMessage(_c, 0, m);
  cMsg_JxBeR8l4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OpQA42im_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_9HLHaEf3_sendMessage(_c, 0, m);
  cMsg_8MKhe5rI_sendMessage(_c, 0, m);
  cMsg_oRHarnBr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_reuny1iy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_EZIIrf6r_sendMessage(_c, 0, m);
  cMsg_6nebOtk9_sendMessage(_c, 0, m);
  cMsg_bku3HagK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8JLy2LqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_9HLHaEf3_sendMessage(_c, 0, m);
  cMsg_J2ZCBtYb_sendMessage(_c, 0, m);
  cMsg_JxBeR8l4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_apzprhBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vYvn5LbA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OchJAyD7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lfx0QEzz, 0, m, &cSlice_lfx0QEzz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IRmMHTCr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_lfx0QEzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_A3gsJ7Ve_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_A3gsJ7Ve_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_lT7SXneM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_A3gsJ7Ve_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_A3gsJ7Ve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9KcC0fSq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yBeDLZpg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0k1UYMtF, 0, m, &cSlice_0k1UYMtF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hEZqoPGH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_0k1UYMtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DbqlOFYx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DbqlOFYx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Fr5ydkOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DbqlOFYx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_DbqlOFYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qEvkzBJt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hEZqoPGH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QwfN48Bk, 0, m, &cSlice_QwfN48Bk_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OchJAyD7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_QwfN48Bk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZzwQRmPW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZzwQRmPW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_SNedbURD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZzwQRmPW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ZzwQRmPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yjwZGhoS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IRmMHTCr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tufsCuQK, 0, m, &cSlice_tufsCuQK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZDmwt4u6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_tufsCuQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_csdejjgZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_csdejjgZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Mq40YHWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_csdejjgZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_csdejjgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4vrS2Acb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZDmwt4u6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8c4jbWAm, 0, m, &cSlice_8c4jbWAm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_S5QoT5i3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_8c4jbWAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dwcenFBK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dwcenFBK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_7QfeL9uu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dwcenFBK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dwcenFBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kJJJziUz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fisyVa6S_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HwFoRYKu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HwFoRYKu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rK1uMbyz, 1, m, &cDelay_rK1uMbyz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aVoDNPbX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_rK1uMbyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rK1uMbyz, m);
  cMsg_l4vCqeX4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HwFoRYKu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rK1uMbyz, 0, m, &cDelay_rK1uMbyz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aVoDNPbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rK1uMbyz, 0, m, &cDelay_rK1uMbyz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_wLwkwpan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8ytvcxgW, HV_BINOP_SUBTRACT, 0, m, &cBinop_8ytvcxgW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_ge7LTOZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_O1IAnJRl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_huyUjwpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_O1IAnJRl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_3SELgnaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wLwkwpan, 0, m, &cVar_wLwkwpan_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_cEiuOTs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WtFRStMA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GscHXyAg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SEy9NtYA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8ytvcxgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FcRIcGEI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FcRIcGEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xTnseHlM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xTnseHlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_zLmCPA1k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fTFPZI82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m07OKnvl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sIY0ywCz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sIY0ywCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wdA4u017_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_m07OKnvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ge7LTOZx, 1, m, &cIf_ge7LTOZx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rIj83MSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_huyUjwpj, 1, m, &cIf_huyUjwpj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wdA4u017_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ge7LTOZx, 0, m, &cIf_ge7LTOZx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zLmCPA1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_huyUjwpj, 0, m, &cIf_huyUjwpj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SEy9NtYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wLwkwpan, 0, m, &cVar_wLwkwpan_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WtFRStMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_GscHXyAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8ytvcxgW, HV_BINOP_SUBTRACT, 1, m, &cBinop_8ytvcxgW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_O1IAnJRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jtDRkTkJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_S5QoT5i3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1dEjVlWW, 0, m, &cSlice_1dEjVlWW_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_1dEjVlWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GTKM3IJg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GTKM3IJg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_2qY37F5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GTKM3IJg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_GTKM3IJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_K09PyThU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jY4PtEiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PcSQ6FKx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nlUhnP5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aEeksWFX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_gyFus9aD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pQGYgT7G, 0, m, &cVar_pQGYgT7G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vYvn5LbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_64gJ7tKS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_h5x3yc2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fisyVa6S_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QFIeHAfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XNBqrCen_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_l4vCqeX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DarPhv4Q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XNBqrCen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DarPhv4Q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Nw5mW83n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_oK8babFz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oK8babFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rpDeJVi2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rpDeJVi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ga5m3mKQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_581Knwc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cYpY0DdZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_1vLQPGIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FwUxgjOx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_VnxUnboj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FmmvVbzc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_YEFuJkRF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wsVgTEBt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_5sfuyrn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_piIHdgRg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_tXaTEpBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WX5HOkg8_sendMessage);
  cMsg_Bxgan7LV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WX5HOkg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tXaTEpBi, 1, m, &cVar_tXaTEpBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_enbEf8ck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wbnmWq18_sendMessage(_c, 0, m);
  cMsg_OVciTB5i_sendMessage(_c, 0, m);
  cMsg_rwsUvSuM_sendMessage(_c, 0, m);
  cMsg_PMSa6IBf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4CYDI1FS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kDBuYYiT, 0, m, &cSlice_kDBuYYiT_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_kDBuYYiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5NTAhYVo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5NTAhYVo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_jNrNVveR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5NTAhYVo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5NTAhYVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LD8z40W5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_pcpwBdcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_xSaGp9rq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xSaGp9rq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_mQTBtOyb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mQTBtOyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fqp3Ruxr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fqp3Ruxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_17HySG0p_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1GqtR3we_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_17HySG0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_FXROQaNG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1GqtR3we_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_voIE1ZTk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_FXROQaNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rQYyuiBW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_voIE1ZTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_R1CFFcIX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R1CFFcIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KzsYHoVu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rQYyuiBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bjjk77F8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_KzsYHoVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IoWMqcQU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Bjjk77F8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ejDWa4FM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IoWMqcQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eCfaiA5m, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_I2P4LNZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VEQYdZIN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_8GPIVeAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bwZkgUAV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4gRrldtf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xBeGA0g5_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O1YAKUks_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HFDEG9IJ_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GAFoUlah_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s45U0QrT_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KZtYuK6r_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_xBeGA0g5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wEffnNtv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_O1YAKUks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HuUFFg2p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_HFDEG9IJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tAe6Wlxj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_GAFoUlah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gYEIwTc2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_s45U0QrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_glYIO553_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_KZtYuK6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GjD6sD9g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_uqGYK3ZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HCzDPcn0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_66erumbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1icTVoUa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5jVqUP2W_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vW5YjeeV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vW5YjeeV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_x7TGAjcx, 1, m, &cDelay_x7TGAjcx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xQGk4m5e_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_x7TGAjcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_x7TGAjcx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_uqGYK3ZM, 0, m, &cIf_uqGYK3ZM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vW5YjeeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_x7TGAjcx, 0, m, &cDelay_x7TGAjcx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xQGk4m5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_x7TGAjcx, 0, m, &cDelay_x7TGAjcx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n3voxRR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E8MhALP0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QThrpuQi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ltofvhTK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sEcoiqNG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E0HsVrLR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E0HsVrLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5jVqUP2W_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sEcoiqNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uqGYK3ZM, 1, m, &cIf_uqGYK3ZM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QThrpuQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_66erumbU, 0, m, &cIf_66erumbU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E8MhALP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_66erumbU, 1, m, &cIf_66erumbU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1icTVoUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_69WkWKvF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HCzDPcn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_69WkWKvF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2XCCzXfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tA8utLVd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ghyjE3KI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zYyWuAbf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KGcvMBym_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_K4HM0X2P_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_K4HM0X2P_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_idI7GJEy, 1, m, &cDelay_idI7GJEy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dz6wcwDQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_idI7GJEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_idI7GJEy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2XCCzXfO, 0, m, &cIf_2XCCzXfO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K4HM0X2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_idI7GJEy, 0, m, &cDelay_idI7GJEy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dz6wcwDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_idI7GJEy, 0, m, &cDelay_idI7GJEy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lLUWwt8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HNCpzqGf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_waNbGUkT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LS7BGwD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bLcCIdBv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3kc57pfr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3kc57pfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KGcvMBym_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_bLcCIdBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2XCCzXfO, 1, m, &cIf_2XCCzXfO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_waNbGUkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ghyjE3KI, 0, m, &cIf_ghyjE3KI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HNCpzqGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ghyjE3KI, 1, m, &cIf_ghyjE3KI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zYyWuAbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WOqcMuL3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tA8utLVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WOqcMuL3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RJWXhOik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HrAbpCno_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_4qjBRpXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_L1NEdgk8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZlBC2MdX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KSeqIDXI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KSeqIDXI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2EVgC6YH, 1, m, &cDelay_2EVgC6YH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DFpOxGwh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_2EVgC6YH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2EVgC6YH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RJWXhOik, 0, m, &cIf_RJWXhOik_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KSeqIDXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2EVgC6YH, 0, m, &cDelay_2EVgC6YH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DFpOxGwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2EVgC6YH, 0, m, &cDelay_2EVgC6YH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jLY0aH6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8e1Z6nRB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Iy5S5rcm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0ZDl1aGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nwWXJaTX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vsq5B4tz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nwWXJaTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RJWXhOik, 1, m, &cIf_RJWXhOik_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vsq5B4tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZlBC2MdX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Iy5S5rcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4qjBRpXv, 0, m, &cIf_4qjBRpXv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8e1Z6nRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4qjBRpXv, 1, m, &cIf_4qjBRpXv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_L1NEdgk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FqWXKSmt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HrAbpCno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FqWXKSmt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_7G2x1xFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WB7xaspG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_nyaQEb8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pOaVwiwd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Tob0PlKX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SVhFhDV6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SVhFhDV6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VL3ynPg2, 1, m, &cDelay_VL3ynPg2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7ku1DGSQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_VL3ynPg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VL3ynPg2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7G2x1xFd, 0, m, &cIf_7G2x1xFd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SVhFhDV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VL3ynPg2, 0, m, &cDelay_VL3ynPg2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7ku1DGSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VL3ynPg2, 0, m, &cDelay_VL3ynPg2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uBpJWGzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uZWmTzeC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9OOHbNrl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eTAe4eai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IXXq1GaZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_usqLKhfU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_usqLKhfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Tob0PlKX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_IXXq1GaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7G2x1xFd, 1, m, &cIf_7G2x1xFd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9OOHbNrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nyaQEb8x, 0, m, &cIf_nyaQEb8x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uZWmTzeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nyaQEb8x, 1, m, &cIf_nyaQEb8x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pOaVwiwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eaJZyw5k, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WB7xaspG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eaJZyw5k, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_T1tEJHfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kP8k2ofJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_CoX64POT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9Lc6lee2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yVjHoqm5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2uonHqHj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2uonHqHj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AZgfyzjz, 1, m, &cDelay_AZgfyzjz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HrNBAYvV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_AZgfyzjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AZgfyzjz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_T1tEJHfz, 0, m, &cIf_T1tEJHfz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2uonHqHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AZgfyzjz, 0, m, &cDelay_AZgfyzjz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HrNBAYvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AZgfyzjz, 0, m, &cDelay_AZgfyzjz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ycCc5YQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2KaRZi1r_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lPhaL0Do_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OA037dUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ii6X1yEM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FGRXb0uN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FGRXb0uN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_yVjHoqm5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ii6X1yEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T1tEJHfz, 1, m, &cIf_T1tEJHfz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lPhaL0Do_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CoX64POT, 0, m, &cIf_CoX64POT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2KaRZi1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CoX64POT, 1, m, &cIf_CoX64POT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9Lc6lee2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YkYXmOHe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kP8k2ofJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YkYXmOHe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_eMYV9h02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HN2877xt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jJ55CWAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Re2OJloz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UNP29jHF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vSzTEFwr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vSzTEFwr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lkOn4XGS, 1, m, &cDelay_lkOn4XGS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OdsDJgAN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_lkOn4XGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lkOn4XGS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_eMYV9h02, 0, m, &cIf_eMYV9h02_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vSzTEFwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lkOn4XGS, 0, m, &cDelay_lkOn4XGS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OdsDJgAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lkOn4XGS, 0, m, &cDelay_lkOn4XGS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6bFYpZfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f90AhnXG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OZHXuLRb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sm5gef6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EPO4OpGt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_znMoK7Lm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_znMoK7Lm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UNP29jHF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_EPO4OpGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eMYV9h02, 1, m, &cIf_eMYV9h02_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OZHXuLRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jJ55CWAp, 0, m, &cIf_jJ55CWAp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f90AhnXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jJ55CWAp, 1, m, &cIf_jJ55CWAp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Re2OJloz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nrHpvxkH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HN2877xt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nrHpvxkH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_XJy9ESSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4ZdxadUc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_V0UHLmR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rKdxQgrU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TJo1ed0u_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rjxgFTse_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rjxgFTse_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_3JwbNLZe, 1, m, &cDelay_3JwbNLZe_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TEM0C77d_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_3JwbNLZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3JwbNLZe, m);
  cIf_onMessage(_c, &Context(_c)->cIf_XJy9ESSp, 0, m, &cIf_XJy9ESSp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rjxgFTse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3JwbNLZe, 0, m, &cDelay_3JwbNLZe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TEM0C77d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3JwbNLZe, 0, m, &cDelay_3JwbNLZe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eUIdOyqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sAllSXxG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oKFQvOTC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rbKEVQmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CpYJZgn9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OJOGvnYC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OJOGvnYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TJo1ed0u_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_CpYJZgn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XJy9ESSp, 1, m, &cIf_XJy9ESSp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oKFQvOTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V0UHLmR2, 0, m, &cIf_V0UHLmR2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sAllSXxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V0UHLmR2, 1, m, &cIf_V0UHLmR2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rKdxQgrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qz7dTHu5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4ZdxadUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qz7dTHu5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_gafbH4iM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5TvHW6SL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7sUBmv6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qw0Ct3mz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PhqnigzE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Klnfk2Ti_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Klnfk2Ti_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_L77Hit4c, 1, m, &cDelay_L77Hit4c_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9S1hQD1t_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_L77Hit4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_L77Hit4c, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gafbH4iM, 0, m, &cIf_gafbH4iM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Klnfk2Ti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_L77Hit4c, 0, m, &cDelay_L77Hit4c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9S1hQD1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_L77Hit4c, 0, m, &cDelay_L77Hit4c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ju3LEG3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CicDlMiH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RSpc3Q0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_S8bXjbP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AYXmuY7Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtUR5tCY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZtUR5tCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PhqnigzE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_AYXmuY7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gafbH4iM, 1, m, &cIf_gafbH4iM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RSpc3Q0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7sUBmv6i, 0, m, &cIf_7sUBmv6i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CicDlMiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7sUBmv6i, 1, m, &cIf_7sUBmv6i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qw0Ct3mz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L5WK36Ua, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5TvHW6SL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L5WK36Ua, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_4n0SZAeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Yw3P2TjY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_uPNyFdZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7GByDuaS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fEzNKVId_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2g4XCe2K_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2g4XCe2K_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XKdtF62Q, 1, m, &cDelay_XKdtF62Q_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Yz3t1klz_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_XKdtF62Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XKdtF62Q, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4n0SZAeC, 0, m, &cIf_4n0SZAeC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2g4XCe2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XKdtF62Q, 0, m, &cDelay_XKdtF62Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Yz3t1klz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XKdtF62Q, 0, m, &cDelay_XKdtF62Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Hznr6EDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yG7WqjLA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hapzzohg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aCY8CMaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7sGcQo4T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RzMFRWgV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7sGcQo4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4n0SZAeC, 1, m, &cIf_4n0SZAeC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RzMFRWgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fEzNKVId_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hapzzohg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uPNyFdZY, 0, m, &cIf_uPNyFdZY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yG7WqjLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uPNyFdZY, 1, m, &cIf_uPNyFdZY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7GByDuaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UYaDsbfU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Yw3P2TjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UYaDsbfU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_qD0FSMN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UUOj4c4z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7FDkC6Tj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SPmL8yM7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qeXDUQxG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wp4bsJxh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wp4bsJxh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_62n6flAg, 1, m, &cDelay_62n6flAg_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S0FLMt6K_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_62n6flAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_62n6flAg, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qD0FSMN7, 0, m, &cIf_qD0FSMN7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wp4bsJxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_62n6flAg, 0, m, &cDelay_62n6flAg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S0FLMt6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_62n6flAg, 0, m, &cDelay_62n6flAg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pHML5WhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TSGUpY1e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qj15FPrp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qA7JTHb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O3FkvpBj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QzCtBE4x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QzCtBE4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qeXDUQxG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_O3FkvpBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qD0FSMN7, 1, m, &cIf_qD0FSMN7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qj15FPrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7FDkC6Tj, 0, m, &cIf_7FDkC6Tj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TSGUpY1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7FDkC6Tj, 1, m, &cIf_7FDkC6Tj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SPmL8yM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_okPYuU48, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UUOj4c4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_okPYuU48, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_tNxgVM9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NFVHisjC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_amzqM7UF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BSt2rip7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fRp3bSqQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vIhwFlrr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vIhwFlrr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_v6gQNbGA, 1, m, &cDelay_v6gQNbGA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g0EOlu2B_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_v6gQNbGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_v6gQNbGA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tNxgVM9u, 0, m, &cIf_tNxgVM9u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vIhwFlrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_v6gQNbGA, 0, m, &cDelay_v6gQNbGA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_g0EOlu2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_v6gQNbGA, 0, m, &cDelay_v6gQNbGA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8IcXEWCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SrNdLbWx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FF79DfDT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m26BxbBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iLHM9MBt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XOx19S40_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XOx19S40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fRp3bSqQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_iLHM9MBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tNxgVM9u, 1, m, &cIf_tNxgVM9u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FF79DfDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_amzqM7UF, 0, m, &cIf_amzqM7UF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SrNdLbWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_amzqM7UF, 1, m, &cIf_amzqM7UF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BSt2rip7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R7azneKs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NFVHisjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R7azneKs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_izDO9NKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Fj60gLby_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_mdOvirVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NtunFLwS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_C4zZLadz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Wb17WarM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Wb17WarM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lWRv9PcY, 1, m, &cDelay_lWRv9PcY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f88dd5nm_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_lWRv9PcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lWRv9PcY, m);
  cIf_onMessage(_c, &Context(_c)->cIf_izDO9NKL, 0, m, &cIf_izDO9NKL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wb17WarM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lWRv9PcY, 0, m, &cDelay_lWRv9PcY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f88dd5nm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lWRv9PcY, 0, m, &cDelay_lWRv9PcY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uF4iHAZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e7XrBb5R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3POZsee0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mXcP8bez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d9NFJ2zp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LaHPasyI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d9NFJ2zp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_izDO9NKL, 1, m, &cIf_izDO9NKL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LaHPasyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_C4zZLadz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3POZsee0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mdOvirVY, 0, m, &cIf_mdOvirVY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e7XrBb5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mdOvirVY, 1, m, &cIf_mdOvirVY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NtunFLwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PMHA5GTN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Fj60gLby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PMHA5GTN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wEffnNtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_oi7SW8na_sendMessage(_c, 0, m);
  cMsg_qxc6gnsi_sendMessage(_c, 0, m);
  cMsg_tFtezqAx_sendMessage(_c, 0, m);
  cMsg_aNyPBijt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HuUFFg2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_oi7SW8na_sendMessage(_c, 0, m);
  cMsg_JLvhBNBX_sendMessage(_c, 0, m);
  cMsg_xLbWfh3G_sendMessage(_c, 0, m);
  cMsg_of3bJ92U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tAe6Wlxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_iwWzYw3u_sendMessage(_c, 0, m);
  cMsg_JLvhBNBX_sendMessage(_c, 0, m);
  cMsg_aNyPBijt_sendMessage(_c, 0, m);
  cMsg_AbTzQUck_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gYEIwTc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_iwWzYw3u_sendMessage(_c, 0, m);
  cMsg_vpSN75GP_sendMessage(_c, 0, m);
  cMsg_tFtezqAx_sendMessage(_c, 0, m);
  cMsg_5hXgnRaj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_glYIO553_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_6jNO99eQ_sendMessage(_c, 0, m);
  cMsg_of3bJ92U_sendMessage(_c, 0, m);
  cMsg_8Z0dAOqc_sendMessage(_c, 0, m);
  cMsg_tFtezqAx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GjD6sD9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_6jNO99eQ_sendMessage(_c, 0, m);
  cMsg_5hXgnRaj_sendMessage(_c, 0, m);
  cMsg_JLvhBNBX_sendMessage(_c, 0, m);
  cMsg_Hr2gKZlw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dpJLlAaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ltofvhTK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_n3voxRR2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OiOy7xBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ltofvhTK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_n3voxRR2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DtjpvZfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LS7BGwD4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lLUWwt8S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0D1Wc81g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LS7BGwD4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lLUWwt8S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BKmsrBtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0ZDl1aGq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jLY0aH6Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EweLwj6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0ZDl1aGq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jLY0aH6Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oi7SW8na_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_dpJLlAaP_sendMessage(_c, 0, m);
  cMsg_0D1Wc81g_sendMessage(_c, 0, m);
  cMsg_EweLwj6w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iwWzYw3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_OiOy7xBc_sendMessage(_c, 0, m);
  cMsg_DtjpvZfl_sendMessage(_c, 0, m);
  cMsg_EweLwj6w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6jNO99eQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_OiOy7xBc_sendMessage(_c, 0, m);
  cMsg_0D1Wc81g_sendMessage(_c, 0, m);
  cMsg_BKmsrBtN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SS14SviK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eTAe4eai_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uBpJWGzv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xm4tdbJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eTAe4eai_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uBpJWGzv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zVTPagC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OA037dUl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ycCc5YQP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LxO18lmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OA037dUl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ycCc5YQP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oYhv8weQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sm5gef6A_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6bFYpZfn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ycGK8kDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sm5gef6A_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6bFYpZfn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JLvhBNBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_xm4tdbJp_sendMessage(_c, 0, m);
  cMsg_LxO18lmq_sendMessage(_c, 0, m);
  cMsg_ycGK8kDB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qxc6gnsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_xm4tdbJp_sendMessage(_c, 0, m);
  cMsg_zVTPagC9_sendMessage(_c, 0, m);
  cMsg_oYhv8weQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vpSN75GP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_SS14SviK_sendMessage(_c, 0, m);
  cMsg_LxO18lmq_sendMessage(_c, 0, m);
  cMsg_oYhv8weQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FfRPGFow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qA7JTHb7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pHML5WhB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_y6klNxER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qA7JTHb7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pHML5WhB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TF3m9dU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_m26BxbBu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8IcXEWCw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_64Fh6US0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_m26BxbBu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8IcXEWCw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_55Ebacyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mXcP8bez_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uF4iHAZG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_knkhfwoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mXcP8bez_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uF4iHAZG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5hXgnRaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_FfRPGFow_sendMessage(_c, 0, m);
  cMsg_64Fh6US0_sendMessage(_c, 0, m);
  cMsg_knkhfwoL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_of3bJ92U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_y6klNxER_sendMessage(_c, 0, m);
  cMsg_TF3m9dU2_sendMessage(_c, 0, m);
  cMsg_knkhfwoL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aNyPBijt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_y6klNxER_sendMessage(_c, 0, m);
  cMsg_64Fh6US0_sendMessage(_c, 0, m);
  cMsg_55Ebacyr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_g9ef7jg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rbKEVQmz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eUIdOyqw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lNN4pL8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rbKEVQmz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eUIdOyqw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_k2ii8jXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_S8bXjbP4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ju3LEG3u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FzFEd8R5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_S8bXjbP4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ju3LEG3u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gecbJ9Jf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aCY8CMaB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Hznr6EDM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hWrAiu27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aCY8CMaB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Hznr6EDM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tFtezqAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_lNN4pL8I_sendMessage(_c, 0, m);
  cMsg_FzFEd8R5_sendMessage(_c, 0, m);
  cMsg_hWrAiu27_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xLbWfh3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_lNN4pL8I_sendMessage(_c, 0, m);
  cMsg_k2ii8jXM_sendMessage(_c, 0, m);
  cMsg_gecbJ9Jf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Hr2gKZlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_g9ef7jg3_sendMessage(_c, 0, m);
  cMsg_k2ii8jXM_sendMessage(_c, 0, m);
  cMsg_hWrAiu27_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8Z0dAOqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_SS14SviK_sendMessage(_c, 0, m);
  cMsg_zVTPagC9_sendMessage(_c, 0, m);
  cMsg_ycGK8kDB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AbTzQUck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_g9ef7jg3_sendMessage(_c, 0, m);
  cMsg_FzFEd8R5_sendMessage(_c, 0, m);
  cMsg_gecbJ9Jf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_4rBynSrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5aC7Kwmw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_L7aSQnB6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FzGijjJE, 0, m, &cSlice_FzGijjJE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xnarQ9Uj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_FzGijjJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8TDeVEaq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8TDeVEaq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_VgtG77b4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8TDeVEaq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_8TDeVEaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZOjQKwGI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Cdhulsuh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eLVFRSIH, 0, m, &cSlice_eLVFRSIH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_AcEit9y7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_eLVFRSIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Am2h0yJp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Am2h0yJp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Dft3JYeP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Am2h0yJp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Am2h0yJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VN4jK5OJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AcEit9y7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xwiiECaE, 0, m, &cSlice_xwiiECaE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_L7aSQnB6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_xwiiECaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zf7SEqgr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zf7SEqgr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ACBRmulD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zf7SEqgr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_zf7SEqgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LS9xq3sQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xnarQ9Uj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XyiY3Qg6, 0, m, &cSlice_XyiY3Qg6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bzNpGnnz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_XyiY3Qg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qFPXzzwF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qFPXzzwF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_0TXJyXQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qFPXzzwF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_qFPXzzwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nRje5SyF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bzNpGnnz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cytoYvui, 0, m, &cSlice_cytoYvui_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GIt1aaTc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_cytoYvui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nVRHYfFn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nVRHYfFn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_lZEtyw0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nVRHYfFn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_nVRHYfFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WcbraJ7f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ReLpchot_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_GzBaZprx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_GzBaZprx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OLC0XDzk, 1, m, &cDelay_OLC0XDzk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aawM36s6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_OLC0XDzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OLC0XDzk, m);
  cMsg_99FRwxAo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GzBaZprx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OLC0XDzk, 0, m, &cDelay_OLC0XDzk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aawM36s6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OLC0XDzk, 0, m, &cDelay_OLC0XDzk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_toqPhChe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_skzvmAOy, HV_BINOP_SUBTRACT, 0, m, &cBinop_skzvmAOy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_vaFZpcLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TFqXmKiZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_uN3XB0mf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TFqXmKiZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_vcgZ2LL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_toqPhChe, 0, m, &cVar_toqPhChe_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_JIyREpcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XP1A1zMc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GMzDeTVD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ReYUwblE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_skzvmAOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pV9kCSwy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pV9kCSwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Zfo7H9mu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Zfo7H9mu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_P0zLX0Pm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aonVNOnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uvcCXuh2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sUlC3dfd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uvcCXuh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vaFZpcLj, 1, m, &cIf_vaFZpcLj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sUlC3dfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R1C5ZxZk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Co1JVoqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uN3XB0mf, 1, m, &cIf_uN3XB0mf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R1C5ZxZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_vaFZpcLj, 0, m, &cIf_vaFZpcLj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_P0zLX0Pm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uN3XB0mf, 0, m, &cIf_uN3XB0mf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XP1A1zMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_GMzDeTVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_skzvmAOy, HV_BINOP_SUBTRACT, 1, m, &cBinop_skzvmAOy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ReYUwblE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_toqPhChe, 0, m, &cVar_toqPhChe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TFqXmKiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BpRSXwHJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GIt1aaTc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HL4SbNnF, 0, m, &cSlice_HL4SbNnF_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_HL4SbNnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NYFf2yaM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NYFf2yaM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_yXW42IFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NYFf2yaM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_NYFf2yaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OUZ9iJr0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VEQYdZIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wpj6s014, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bwZkgUAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T4I8O7Mc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_tOBFtw83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8GPIVeAd, 0, m, &cVar_8GPIVeAd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5aC7Kwmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2fnAS4nS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_qNbDfBgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ReLpchot_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_9hFI6RsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iT81JvfZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_99FRwxAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PaRdogbl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iT81JvfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PaRdogbl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JGKlQNTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_JLfJo1Rv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JLfJo1Rv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tsySGJWh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tsySGJWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V4LoWqTS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_ZoX8s6kT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ho9noGt5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_imyiyuSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MitdS5kd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Bgwc3mHz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OwMzva31_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PlaqVRih_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EGuhT6am_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WFcyk9jL_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VDI79CEi_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WoREJh0j_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_OwMzva31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mpjufMev_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_PlaqVRih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mNxDfDFM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_EGuhT6am_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zA0I1Q9a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_WFcyk9jL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_thmnvEKN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_VDI79CEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bh0dndSY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_WoREJh0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cxd6NOat_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_ayqKLEag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gY5Kbtlg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oUc0ciUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_e4aljwSI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9WU11ym9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ETQ0wTrf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ETQ0wTrf_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ChexeGmc, 1, m, &cDelay_ChexeGmc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G3PmqpqH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ChexeGmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ChexeGmc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ayqKLEag, 0, m, &cIf_ayqKLEag_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ETQ0wTrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ChexeGmc, 0, m, &cDelay_ChexeGmc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G3PmqpqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ChexeGmc, 0, m, &cDelay_ChexeGmc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_diBHX9ry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8DmmFJI5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AbTLwYLp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PiYzRwbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HHOhxfmu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wt1o7dBx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wt1o7dBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9WU11ym9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HHOhxfmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ayqKLEag, 1, m, &cIf_ayqKLEag_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8DmmFJI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oUc0ciUa, 1, m, &cIf_oUc0ciUa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AbTLwYLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oUc0ciUa, 0, m, &cIf_oUc0ciUa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e4aljwSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Pkc45DKp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gY5Kbtlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Pkc45DKp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_8W6tprpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2WOVqTMP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kW5I4Icb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oxZFO2HO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hgz3R2kH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cIZqOmBB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cIZqOmBB_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RpV4W9JK, 1, m, &cDelay_RpV4W9JK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ASgISPWO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_RpV4W9JK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RpV4W9JK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8W6tprpo, 0, m, &cIf_8W6tprpo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cIZqOmBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RpV4W9JK, 0, m, &cDelay_RpV4W9JK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ASgISPWO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RpV4W9JK, 0, m, &cDelay_RpV4W9JK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ev4XG2rt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8gA1tSLm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lL8rGXKq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bQA0qfh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XPbmXnNJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7hGK4kqK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7hGK4kqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hgz3R2kH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_XPbmXnNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8W6tprpo, 1, m, &cIf_8W6tprpo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8gA1tSLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kW5I4Icb, 1, m, &cIf_kW5I4Icb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lL8rGXKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kW5I4Icb, 0, m, &cIf_kW5I4Icb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oxZFO2HO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TACRu5EH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2WOVqTMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TACRu5EH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_hIC6Nnw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FSvSBJMd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_abGegoeO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_92O5OBxB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hHqG3Aro_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NKG4rZyE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NKG4rZyE_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JYvTkWYF, 1, m, &cDelay_JYvTkWYF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gyzPN4at_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_JYvTkWYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JYvTkWYF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_hIC6Nnw9, 0, m, &cIf_hIC6Nnw9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NKG4rZyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JYvTkWYF, 0, m, &cDelay_JYvTkWYF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gyzPN4at_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JYvTkWYF, 0, m, &cDelay_JYvTkWYF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jSqHWulW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kB57O6B8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TmGidzrC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qmXyZZpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qknW9e8b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x8VDyg9Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x8VDyg9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hHqG3Aro_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_qknW9e8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hIC6Nnw9, 1, m, &cIf_hIC6Nnw9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kB57O6B8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_abGegoeO, 1, m, &cIf_abGegoeO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TmGidzrC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_abGegoeO, 0, m, &cIf_abGegoeO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_92O5OBxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q2AwyQW0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FSvSBJMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q2AwyQW0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_gMoZKqCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lcqUnkuV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3gM0KqRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fJPfoLkn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BjtMPxkD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0Olx5lZp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0Olx5lZp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OtfELiQr, 1, m, &cDelay_OtfELiQr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mve3iZ8m_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_OtfELiQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OtfELiQr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gMoZKqCk, 0, m, &cIf_gMoZKqCk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0Olx5lZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OtfELiQr, 0, m, &cDelay_OtfELiQr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mve3iZ8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OtfELiQr, 0, m, &cDelay_OtfELiQr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zHawkv9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tRR9KBEP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_clzSF9uJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s0bgDExS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o1i1bZsF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W9XH81wH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W9XH81wH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BjtMPxkD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_o1i1bZsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gMoZKqCk, 1, m, &cIf_gMoZKqCk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_clzSF9uJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3gM0KqRp, 0, m, &cIf_3gM0KqRp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tRR9KBEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3gM0KqRp, 1, m, &cIf_3gM0KqRp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fJPfoLkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ysAZcFxE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lcqUnkuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ysAZcFxE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_45qL64rD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_q7KcV4zf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5SVHD2eO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VmYASTkJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9svxdn5O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nVo236TL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nVo236TL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EBDMiked, 1, m, &cDelay_EBDMiked_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vMSy0BDj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_EBDMiked_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EBDMiked, m);
  cIf_onMessage(_c, &Context(_c)->cIf_45qL64rD, 0, m, &cIf_45qL64rD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nVo236TL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EBDMiked, 0, m, &cDelay_EBDMiked_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vMSy0BDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EBDMiked, 0, m, &cDelay_EBDMiked_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nZkllvNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0IV3HXXh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pRlmu1Cg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_S3vl3wa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_26pGsSoa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QQyZEOWS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QQyZEOWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9svxdn5O_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_26pGsSoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_45qL64rD, 1, m, &cIf_45qL64rD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0IV3HXXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5SVHD2eO, 1, m, &cIf_5SVHD2eO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pRlmu1Cg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5SVHD2eO, 0, m, &cIf_5SVHD2eO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VmYASTkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hN4Pls2d, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_q7KcV4zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hN4Pls2d, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_I57f90tR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fQBJdtSj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lE9DM127_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4n99eZF3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_huhOndBX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Hlc6uNxU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Hlc6uNxU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yh80TAgo, 1, m, &cDelay_yh80TAgo_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LtwgcCaj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_yh80TAgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yh80TAgo, m);
  cIf_onMessage(_c, &Context(_c)->cIf_I57f90tR, 0, m, &cIf_I57f90tR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Hlc6uNxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yh80TAgo, 0, m, &cDelay_yh80TAgo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LtwgcCaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yh80TAgo, 0, m, &cDelay_yh80TAgo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oV5BSqhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gmhyi7Vu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_87EyCWoO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XaTL76cK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1H3MiUdz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qq2rJyV8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qq2rJyV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_huhOndBX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1H3MiUdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_I57f90tR, 1, m, &cIf_I57f90tR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_87EyCWoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lE9DM127, 0, m, &cIf_lE9DM127_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gmhyi7Vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lE9DM127, 1, m, &cIf_lE9DM127_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4n99eZF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6MxNGPwW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fQBJdtSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6MxNGPwW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_3FM8a92H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wWS65Z5n_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_aGaaIV6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bRwtHwQE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hpNZa9pR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_unYqvdBD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_unYqvdBD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XoJURZcB, 1, m, &cDelay_XoJURZcB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8hK6u2Ez_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_XoJURZcB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XoJURZcB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3FM8a92H, 0, m, &cIf_3FM8a92H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_unYqvdBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XoJURZcB, 0, m, &cDelay_XoJURZcB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8hK6u2Ez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XoJURZcB, 0, m, &cDelay_XoJURZcB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ovv7XhcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C5qe66dX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SJo7RtoV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2Qaw1UEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GW8HZFYN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zTy8Apnc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zTy8Apnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hpNZa9pR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_GW8HZFYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3FM8a92H, 1, m, &cIf_3FM8a92H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_C5qe66dX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aGaaIV6E, 1, m, &cIf_aGaaIV6E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SJo7RtoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aGaaIV6E, 0, m, &cIf_aGaaIV6E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bRwtHwQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GLKdnCcg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wWS65Z5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GLKdnCcg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Vqupt3e3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g3MCJ70V_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_But8wg8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sjoKNVYx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ClRx34CB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XTQnQ1D1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XTQnQ1D1_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UTvQuPD8, 1, m, &cDelay_UTvQuPD8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_voThDuwC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_UTvQuPD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UTvQuPD8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Vqupt3e3, 0, m, &cIf_Vqupt3e3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XTQnQ1D1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UTvQuPD8, 0, m, &cDelay_UTvQuPD8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_voThDuwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UTvQuPD8, 0, m, &cDelay_UTvQuPD8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XW7BTndz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aAKBsIlE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nWqAEGmG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nb9AkgAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c2X5rOfr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EkyiAeyL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c2X5rOfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Vqupt3e3, 1, m, &cIf_Vqupt3e3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EkyiAeyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ClRx34CB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_aAKBsIlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_But8wg8k, 1, m, &cIf_But8wg8k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nWqAEGmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_But8wg8k, 0, m, &cIf_But8wg8k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sjoKNVYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J19F3H07, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_g3MCJ70V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J19F3H07, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Xs91vK5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wdllHEMX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JpCafUaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gXmqiq2v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_F54XOz7X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_VxNDiFPm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_VxNDiFPm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AQDtqUT6, 1, m, &cDelay_AQDtqUT6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SQ9c4LnP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_AQDtqUT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AQDtqUT6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Xs91vK5t, 0, m, &cIf_Xs91vK5t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VxNDiFPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AQDtqUT6, 0, m, &cDelay_AQDtqUT6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SQ9c4LnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AQDtqUT6, 0, m, &cDelay_AQDtqUT6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iD16Hzmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hW24zcqE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h4xkAk6p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zk1AOZni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G6ePcD9i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t72A5oNe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G6ePcD9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Xs91vK5t, 1, m, &cIf_Xs91vK5t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t72A5oNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_F54XOz7X_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hW24zcqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JpCafUaF, 1, m, &cIf_JpCafUaF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h4xkAk6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JpCafUaF, 0, m, &cIf_JpCafUaF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gXmqiq2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rIE7SRqP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wdllHEMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rIE7SRqP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_MQvpu18S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0z9CQ689_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_08tDmS76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_igkoBMqr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MwjJ8hBN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_06Wgk7C0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_06Wgk7C0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cW1NbEdf, 1, m, &cDelay_cW1NbEdf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vy9zrQNq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cW1NbEdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cW1NbEdf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MQvpu18S, 0, m, &cIf_MQvpu18S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_06Wgk7C0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cW1NbEdf, 0, m, &cDelay_cW1NbEdf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vy9zrQNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cW1NbEdf, 0, m, &cDelay_cW1NbEdf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EQwLI1pF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jh9wvaM3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mYDHqCUF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iqASh8uD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EnGCeX1R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FpHmR5O6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FpHmR5O6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MwjJ8hBN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_EnGCeX1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MQvpu18S, 1, m, &cIf_MQvpu18S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Jh9wvaM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_08tDmS76, 1, m, &cIf_08tDmS76_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mYDHqCUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_08tDmS76, 0, m, &cIf_08tDmS76_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_igkoBMqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WsMcg8UO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0z9CQ689_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WsMcg8UO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_LunMRVi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ozKXrGsp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lCmEYyMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_COPPNO25_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VRh9Objy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rykolzRw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rykolzRw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9rUabswW, 1, m, &cDelay_9rUabswW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0VFtkqvJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9rUabswW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9rUabswW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LunMRVi2, 0, m, &cIf_LunMRVi2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rykolzRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9rUabswW, 0, m, &cDelay_9rUabswW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0VFtkqvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9rUabswW, 0, m, &cDelay_9rUabswW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_a6NIDd18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FHCKhIOM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mHjmVQf9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2SNsZYy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fp67h17T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UVOASXqi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UVOASXqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VRh9Objy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fp67h17T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LunMRVi2, 1, m, &cIf_LunMRVi2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mHjmVQf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lCmEYyMh, 0, m, &cIf_lCmEYyMh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FHCKhIOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lCmEYyMh, 1, m, &cIf_lCmEYyMh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_COPPNO25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aomvCmHE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ozKXrGsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aomvCmHE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_cITDaRg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gzQNFvSc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qGsIuYNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QpqheQXb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fGh5Wdjv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9qS3Uzy9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9qS3Uzy9_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TylRQdqF, 1, m, &cDelay_TylRQdqF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LeYWA26h_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TylRQdqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TylRQdqF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cITDaRg9, 0, m, &cIf_cITDaRg9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9qS3Uzy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TylRQdqF, 0, m, &cDelay_TylRQdqF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LeYWA26h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TylRQdqF, 0, m, &cDelay_TylRQdqF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pbxHejlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sLKalLK3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rjNnoa5e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fGY7BfR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DqFuGJkX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zWnaMUGX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zWnaMUGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fGh5Wdjv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_DqFuGJkX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cITDaRg9, 1, m, &cIf_cITDaRg9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sLKalLK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qGsIuYNH, 1, m, &cIf_qGsIuYNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rjNnoa5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qGsIuYNH, 0, m, &cIf_qGsIuYNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QpqheQXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XEcftdHw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gzQNFvSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XEcftdHw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mpjufMev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_MaVUjagV_sendMessage(_c, 0, m);
  cMsg_MVtEccyK_sendMessage(_c, 0, m);
  cMsg_qmRc9G3B_sendMessage(_c, 0, m);
  cMsg_ABJQwEfp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mNxDfDFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_MaVUjagV_sendMessage(_c, 0, m);
  cMsg_MjjSQKih_sendMessage(_c, 0, m);
  cMsg_eIN7bLaK_sendMessage(_c, 0, m);
  cMsg_9ePQAlOi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zA0I1Q9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_fC9Ugf3Q_sendMessage(_c, 0, m);
  cMsg_MjjSQKih_sendMessage(_c, 0, m);
  cMsg_ABJQwEfp_sendMessage(_c, 0, m);
  cMsg_omswnLES_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_thmnvEKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_fC9Ugf3Q_sendMessage(_c, 0, m);
  cMsg_Uzt1V4Di_sendMessage(_c, 0, m);
  cMsg_qmRc9G3B_sendMessage(_c, 0, m);
  cMsg_Ro7D66YT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Bh0dndSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_czIfwKaT_sendMessage(_c, 0, m);
  cMsg_9ePQAlOi_sendMessage(_c, 0, m);
  cMsg_HWm8wbAI_sendMessage(_c, 0, m);
  cMsg_qmRc9G3B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Cxd6NOat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_czIfwKaT_sendMessage(_c, 0, m);
  cMsg_Ro7D66YT_sendMessage(_c, 0, m);
  cMsg_MjjSQKih_sendMessage(_c, 0, m);
  cMsg_JcNO9Gdf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_G7QxxOUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PiYzRwbX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_diBHX9ry_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oozIwDru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PiYzRwbX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_diBHX9ry_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lw0dmQQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bQA0qfh6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ev4XG2rt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ww8t7qD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bQA0qfh6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ev4XG2rt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Gy7BQEz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qmXyZZpN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jSqHWulW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zJAc2PS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qmXyZZpN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jSqHWulW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MaVUjagV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_G7QxxOUt_sendMessage(_c, 0, m);
  cMsg_ww8t7qD8_sendMessage(_c, 0, m);
  cMsg_zJAc2PS8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fC9Ugf3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_oozIwDru_sendMessage(_c, 0, m);
  cMsg_lw0dmQQ2_sendMessage(_c, 0, m);
  cMsg_zJAc2PS8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_czIfwKaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_oozIwDru_sendMessage(_c, 0, m);
  cMsg_ww8t7qD8_sendMessage(_c, 0, m);
  cMsg_Gy7BQEz5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gV2sjTgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_s0bgDExS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zHawkv9i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nopB2bCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_s0bgDExS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zHawkv9i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FJMCCLAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_S3vl3wa2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nZkllvNL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DNfum9j1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_S3vl3wa2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nZkllvNL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MsPzd5Js_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XaTL76cK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oV5BSqhj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_O5GiobKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XaTL76cK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oV5BSqhj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MjjSQKih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_nopB2bCB_sendMessage(_c, 0, m);
  cMsg_DNfum9j1_sendMessage(_c, 0, m);
  cMsg_O5GiobKj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MVtEccyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_nopB2bCB_sendMessage(_c, 0, m);
  cMsg_FJMCCLAI_sendMessage(_c, 0, m);
  cMsg_MsPzd5Js_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Uzt1V4Di_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_gV2sjTgb_sendMessage(_c, 0, m);
  cMsg_DNfum9j1_sendMessage(_c, 0, m);
  cMsg_MsPzd5Js_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_buAv9A0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iqASh8uD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EQwLI1pF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tGYb2pK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iqASh8uD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EQwLI1pF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OKnvFDki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2SNsZYy1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_a6NIDd18_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tDxuuOGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2SNsZYy1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_a6NIDd18_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AB3oD8ND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fGY7BfR5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pbxHejlV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JQqcTwSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fGY7BfR5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pbxHejlV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ro7D66YT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_buAv9A0y_sendMessage(_c, 0, m);
  cMsg_tDxuuOGl_sendMessage(_c, 0, m);
  cMsg_JQqcTwSZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9ePQAlOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_tGYb2pK1_sendMessage(_c, 0, m);
  cMsg_OKnvFDki_sendMessage(_c, 0, m);
  cMsg_JQqcTwSZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ABJQwEfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_tGYb2pK1_sendMessage(_c, 0, m);
  cMsg_tDxuuOGl_sendMessage(_c, 0, m);
  cMsg_AB3oD8ND_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wdm0ytSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2Qaw1UEF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ovv7XhcH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aVcOujuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2Qaw1UEF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ovv7XhcH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lHyz2vkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nb9AkgAA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XW7BTndz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QysYLYr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nb9AkgAA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XW7BTndz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DDLbDO1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zk1AOZni_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iD16Hzmj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_980oje0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zk1AOZni_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iD16Hzmj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qmRc9G3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_aVcOujuV_sendMessage(_c, 0, m);
  cMsg_QysYLYr0_sendMessage(_c, 0, m);
  cMsg_980oje0r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_eIN7bLaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_aVcOujuV_sendMessage(_c, 0, m);
  cMsg_lHyz2vkp_sendMessage(_c, 0, m);
  cMsg_DDLbDO1L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JcNO9Gdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_wdm0ytSu_sendMessage(_c, 0, m);
  cMsg_lHyz2vkp_sendMessage(_c, 0, m);
  cMsg_980oje0r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HWm8wbAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_gV2sjTgb_sendMessage(_c, 0, m);
  cMsg_FJMCCLAI_sendMessage(_c, 0, m);
  cMsg_O5GiobKj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_omswnLES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_wdm0ytSu_sendMessage(_c, 0, m);
  cMsg_QysYLYr0_sendMessage(_c, 0, m);
  cMsg_DDLbDO1L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_3mCiBYhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rT9LetEd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2GNSo15N_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_p746wS7P, 0, m, &cSlice_p746wS7P_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Qr9auKT9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_p746wS7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LpBmec1L_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LpBmec1L_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_i2ZpbJJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LpBmec1L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_LpBmec1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_35P53LmB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_S1cSOjOu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_U7wQF1do, 0, m, &cSlice_U7wQF1do_sendMessage);
      break;
    }
    default: {
      cSwitchcase_P9tAY2jj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_U7wQF1do_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QkY2SipG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QkY2SipG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_E061iVAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QkY2SipG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_QkY2SipG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AWkXwkSE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_P9tAY2jj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hEFRwUkm, 0, m, &cSlice_hEFRwUkm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2GNSo15N_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_hEFRwUkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xFBbtWGj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xFBbtWGj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_lNPRH2MB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xFBbtWGj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xFBbtWGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2lIvgMws_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Qr9auKT9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_H9HYkPYK, 0, m, &cSlice_H9HYkPYK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_P6qQQIQq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_H9HYkPYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gONNJjoM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gONNJjoM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_47xNtCvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gONNJjoM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_gONNJjoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_trPS2f08_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_P6qQQIQq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_08za4JIx, 0, m, &cSlice_08za4JIx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QY1JqFg1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_08za4JIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xnap5PzR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xnap5PzR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_RGj2nIFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xnap5PzR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xnap5PzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BdLC17S2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_C9HqiK0e_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Jn3eL5ut_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Jn3eL5ut_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OK7JZkWp, 1, m, &cDelay_OK7JZkWp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JkTG6MyX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_OK7JZkWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OK7JZkWp, m);
  cMsg_qasAcqdt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Jn3eL5ut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OK7JZkWp, 0, m, &cDelay_OK7JZkWp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JkTG6MyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OK7JZkWp, 0, m, &cDelay_OK7JZkWp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_X0Cbs1Ef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PlUSfrCm, HV_BINOP_SUBTRACT, 0, m, &cBinop_PlUSfrCm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_pU6eSnkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NKt8gOs3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ItN2RFO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NKt8gOs3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_1dPjBiEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X0Cbs1Ef, 0, m, &cVar_X0Cbs1Ef_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_enKgWCs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vUdV83CD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OfYEUfhL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvt5GgMz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PlUSfrCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f7jWQKaQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_f7jWQKaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_j3antCoS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j3antCoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_iqQB4zGI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9QkEHfJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h2NUXASF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHnSgIwG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lHnSgIwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0hEleGi8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_h2NUXASF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pU6eSnkQ, 1, m, &cIf_pU6eSnkQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Vz5xbTDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ItN2RFO8, 1, m, &cIf_ItN2RFO8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0hEleGi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_pU6eSnkQ, 0, m, &cIf_pU6eSnkQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iqQB4zGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ItN2RFO8, 0, m, &cIf_ItN2RFO8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OfYEUfhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PlUSfrCm, HV_BINOP_SUBTRACT, 1, m, &cBinop_PlUSfrCm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hvt5GgMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X0Cbs1Ef, 0, m, &cVar_X0Cbs1Ef_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vUdV83CD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cMsg_NKt8gOs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rkz0pLsA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QY1JqFg1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_K2ZOmwJM, 0, m, &cSlice_K2ZOmwJM_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_K2ZOmwJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_l0lSI8yI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_l0lSI8yI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_HjbRCSEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_l0lSI8yI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_l0lSI8yI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VWVT6StR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Ho9noGt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7ue3O4bS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MitdS5kd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_y3Ps1lHi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_Gxla55EF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_imyiyuSt, 0, m, &cVar_imyiyuSt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rT9LetEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MgGaFfPB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NEW0EDlv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_C9HqiK0e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RckSMo6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_48Msl2hr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qasAcqdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_07yhCwhI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_48Msl2hr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_07yhCwhI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ETtwHfMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_q5rxwPrl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_q5rxwPrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UdhU0ATl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UdhU0ATl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6VoHkq2m, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_j6uvWIKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OGHmzCVp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_1e6HILXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t5px8smO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_6rYTSDjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fLhMIr2I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_s1OG7rt0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uMhgophq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Xu9yOu5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dCZ6keB3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_AlxebHFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FNorx4q0_sendMessage);
  cMsg_NzBfOdoN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_FNorx4q0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AlxebHFj, 1, m, &cVar_AlxebHFj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pqhbenHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MI7cZmAr_sendMessage(_c, 0, m);
  cMsg_aCw9xRrd_sendMessage(_c, 0, m);
  cMsg_szETdB5z_sendMessage(_c, 0, m);
  cMsg_RhNOniKM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RVXYrGgw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MwUpyl9d, 0, m, &cSlice_MwUpyl9d_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_MwUpyl9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_J6WZIzT1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_J6WZIzT1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_japzphwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_J6WZIzT1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_J6WZIzT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RVa5cbT7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_adWxFz2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fHeDa8uz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fHeDa8uz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_261DfBln_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_261DfBln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1iECcQB2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1iECcQB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kwgrZUjs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0RyVxwQV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kwgrZUjs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RCzjJbOD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0RyVxwQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6uLsOaE8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_RCzjJbOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VDDlxCFC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6uLsOaE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cSHand40_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cSHand40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zdXTc8mz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VDDlxCFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5jjK4Slv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_zdXTc8mz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AbtbkmBm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5jjK4Slv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SIm3w3Ih, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AbtbkmBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zhUtgIM3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_Clt6Zoyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WX8OhPiQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_OMJWE3G8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5LkN1QjN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_x9O9Onbl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ok7qcVDa_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kySLQJ4O_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vDNCTaZC_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PA0HHtcZ_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SZIBB7MN_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jUjSIGmW_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_Ok7qcVDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K3Mx4neC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_kySLQJ4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_98pum15y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_vDNCTaZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A60BB0AX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_PA0HHtcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ys8xF5dJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_SZIBB7MN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JCmHiEN9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_jUjSIGmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NceFt42x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_X3892LuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XvIcPMBJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vfCEankQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tM7szGnE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uxIJ79lt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_h5XjHNt5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_h5XjHNt5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_B2pPOvEW, 1, m, &cDelay_B2pPOvEW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_31t6yyDW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_B2pPOvEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_B2pPOvEW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_X3892LuM, 0, m, &cIf_X3892LuM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h5XjHNt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_B2pPOvEW, 0, m, &cDelay_B2pPOvEW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_31t6yyDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_B2pPOvEW, 0, m, &cDelay_B2pPOvEW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RyceSu7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ebpKfGSm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0HKm0ntw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i4IzaJ17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PW1GSBdT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SVANzDq5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PW1GSBdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X3892LuM, 1, m, &cIf_X3892LuM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SVANzDq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uxIJ79lt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ebpKfGSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vfCEankQ, 1, m, &cIf_vfCEankQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0HKm0ntw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vfCEankQ, 0, m, &cIf_vfCEankQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tM7szGnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9tgs0eVw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XvIcPMBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9tgs0eVw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_DRovn13X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fM4G3ENG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ZWORqBXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DA4IU6ea_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7r9sgiaI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cvworwwk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cvworwwk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_bpxVCz5n, 1, m, &cDelay_bpxVCz5n_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sgYMyg5i_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_bpxVCz5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bpxVCz5n, m);
  cIf_onMessage(_c, &Context(_c)->cIf_DRovn13X, 0, m, &cIf_DRovn13X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cvworwwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bpxVCz5n, 0, m, &cDelay_bpxVCz5n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sgYMyg5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bpxVCz5n, 0, m, &cDelay_bpxVCz5n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ejVdBn6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uz6SO5LK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ChprcXB8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_od8RmRQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lb8vta8b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_934cNpbJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lb8vta8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DRovn13X, 1, m, &cIf_DRovn13X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_934cNpbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7r9sgiaI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ChprcXB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZWORqBXa, 0, m, &cIf_ZWORqBXa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uz6SO5LK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZWORqBXa, 1, m, &cIf_ZWORqBXa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DA4IU6ea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DbZY1k9p, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fM4G3ENG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DbZY1k9p, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CCfgBMKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_i9uMqt38_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wlFdWLCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XmTfz03s_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qm3EXr3x_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tnSW8QBM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tnSW8QBM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IwMyulu1, 1, m, &cDelay_IwMyulu1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TVovFpJg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_IwMyulu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IwMyulu1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CCfgBMKe, 0, m, &cIf_CCfgBMKe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tnSW8QBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IwMyulu1, 0, m, &cDelay_IwMyulu1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TVovFpJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IwMyulu1, 0, m, &cDelay_IwMyulu1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2mgNSX4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aZ4Eg7OK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wSQUCEdv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CsXR21e1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gks8MFRY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a7KXFc2g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a7KXFc2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qm3EXr3x_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_gks8MFRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CCfgBMKe, 1, m, &cIf_CCfgBMKe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aZ4Eg7OK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wlFdWLCO, 1, m, &cIf_wlFdWLCO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wSQUCEdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wlFdWLCO, 0, m, &cIf_wlFdWLCO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XmTfz03s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8nHhH0J2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_i9uMqt38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8nHhH0J2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_5aIt18Al_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mXNCRUxL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_U2muVnui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8PgYzjIW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QYcyQTRq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_GBr3ORHj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_GBr3ORHj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_QA4vpxCa, 1, m, &cDelay_QA4vpxCa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBEXt1w6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_QA4vpxCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QA4vpxCa, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5aIt18Al, 0, m, &cIf_5aIt18Al_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GBr3ORHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QA4vpxCa, 0, m, &cDelay_QA4vpxCa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZBEXt1w6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QA4vpxCa, 0, m, &cDelay_QA4vpxCa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f3DxniCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XuLEZPHO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UU2DAtIJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZxeN6KYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bajueILs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A0Bfyd1c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A0Bfyd1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_QYcyQTRq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_bajueILs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5aIt18Al, 1, m, &cIf_5aIt18Al_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XuLEZPHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U2muVnui, 1, m, &cIf_U2muVnui_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UU2DAtIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U2muVnui, 0, m, &cIf_U2muVnui_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8PgYzjIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yk1lRhWZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mXNCRUxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yk1lRhWZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_cWPTSJhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zTfaLkhy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_QGgPEnjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_L1Vtba5D_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4YywiEtP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_McWXYVVz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_McWXYVVz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kSNpmi9p, 1, m, &cDelay_kSNpmi9p_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eQxzo2dg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_kSNpmi9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kSNpmi9p, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cWPTSJhM, 0, m, &cIf_cWPTSJhM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_McWXYVVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kSNpmi9p, 0, m, &cDelay_kSNpmi9p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eQxzo2dg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kSNpmi9p, 0, m, &cDelay_kSNpmi9p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NRUJvAkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9zCG8pgw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kFLwMQEl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2zj9TgWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UjksNfWv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aCeKMKGK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aCeKMKGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4YywiEtP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_UjksNfWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cWPTSJhM, 1, m, &cIf_cWPTSJhM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9zCG8pgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QGgPEnjQ, 1, m, &cIf_QGgPEnjQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kFLwMQEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QGgPEnjQ, 0, m, &cIf_QGgPEnjQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_L1Vtba5D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nuzbB8h7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zTfaLkhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nuzbB8h7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_XmgTY7xu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1Eu4CJtH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_foUQtTSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MTGZm2ML_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zR2xd7uc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tQlvWfmH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tQlvWfmH_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xrnmeCWU, 1, m, &cDelay_xrnmeCWU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OL0NW22N_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xrnmeCWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xrnmeCWU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_XmgTY7xu, 0, m, &cIf_XmgTY7xu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tQlvWfmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xrnmeCWU, 0, m, &cDelay_xrnmeCWU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OL0NW22N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xrnmeCWU, 0, m, &cDelay_xrnmeCWU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KQCv104w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2T4mHjVI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KFHAleCo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VYW3BK00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B5s5Z3Mx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XdCHSP18_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XdCHSP18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zR2xd7uc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_B5s5Z3Mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XmgTY7xu, 1, m, &cIf_XmgTY7xu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2T4mHjVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_foUQtTSO, 1, m, &cIf_foUQtTSO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KFHAleCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_foUQtTSO, 0, m, &cIf_foUQtTSO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MTGZm2ML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_65cMgABG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1Eu4CJtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_65cMgABG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_OIc0hwbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sALK8ejC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NY4R4myj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jsb15H8K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tFjrbYHJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_U4hGaS8n_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_U4hGaS8n_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GPw8gOW8, 1, m, &cDelay_GPw8gOW8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zLTjGOt6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_GPw8gOW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GPw8gOW8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OIc0hwbg, 0, m, &cIf_OIc0hwbg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U4hGaS8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GPw8gOW8, 0, m, &cDelay_GPw8gOW8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zLTjGOt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GPw8gOW8, 0, m, &cDelay_GPw8gOW8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GriKmvWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DQo3dZ61_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dttmndSX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5ZPZaiud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2cnev0xk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pISJ9RmK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pISJ9RmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tFjrbYHJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2cnev0xk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OIc0hwbg, 1, m, &cIf_OIc0hwbg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dttmndSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NY4R4myj, 0, m, &cIf_NY4R4myj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DQo3dZ61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NY4R4myj, 1, m, &cIf_NY4R4myj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jsb15H8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_asrZ7lxw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sALK8ejC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_asrZ7lxw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_OVtSd1RM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W6WNQiSH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_VoPSr4Gi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NX54w054_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ajOU6idu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_C3nurMbh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_C3nurMbh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TR8cfUKg, 1, m, &cDelay_TR8cfUKg_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JxD1Nrz0_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TR8cfUKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TR8cfUKg, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OVtSd1RM, 0, m, &cIf_OVtSd1RM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C3nurMbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TR8cfUKg, 0, m, &cDelay_TR8cfUKg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JxD1Nrz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TR8cfUKg, 0, m, &cDelay_TR8cfUKg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T7iMgoGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VvKyB5uO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gvaR8lUg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IInRhgDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_twN8sVtM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H8jDBIfz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_H8jDBIfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ajOU6idu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_twN8sVtM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OVtSd1RM, 1, m, &cIf_OVtSd1RM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VvKyB5uO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VoPSr4Gi, 1, m, &cIf_VoPSr4Gi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gvaR8lUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VoPSr4Gi, 0, m, &cIf_VoPSr4Gi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NX54w054_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Gso6HGdm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_W6WNQiSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Gso6HGdm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_zqyHvaK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_856hZlCS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zJ6rGqxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cr9QRgy6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_u3YeS0Nz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WuZlTtfO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WuZlTtfO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GvFhTwCC, 1, m, &cDelay_GvFhTwCC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_87HQjoDJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_GvFhTwCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GvFhTwCC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_zqyHvaK7, 0, m, &cIf_zqyHvaK7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WuZlTtfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GvFhTwCC, 0, m, &cDelay_GvFhTwCC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_87HQjoDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GvFhTwCC, 0, m, &cDelay_GvFhTwCC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PHrjVgnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tew4RnfE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TWv5UxZ8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hBo7a8y8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bm1RONOM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rH4UcnBo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rH4UcnBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_u3YeS0Nz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_bm1RONOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zqyHvaK7, 1, m, &cIf_zqyHvaK7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TWv5UxZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zJ6rGqxd, 0, m, &cIf_zJ6rGqxd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Tew4RnfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zJ6rGqxd, 1, m, &cIf_zJ6rGqxd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cr9QRgy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C1CpC1Ef, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_856hZlCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C1CpC1Ef, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CSYy1mxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hmzzROAT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RdzZpjb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fpeTpxCU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7CEMcnJq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BDjYAMI6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BDjYAMI6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_200DWjKS, 1, m, &cDelay_200DWjKS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cxwOTR2R_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_200DWjKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_200DWjKS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CSYy1mxs, 0, m, &cIf_CSYy1mxs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BDjYAMI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_200DWjKS, 0, m, &cDelay_200DWjKS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cxwOTR2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_200DWjKS, 0, m, &cDelay_200DWjKS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yyVbZrLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2P58esIu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VtkSduZ1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AcrwucDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_idvw8j4n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xnKtLZnM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xnKtLZnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7CEMcnJq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_idvw8j4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CSYy1mxs, 1, m, &cIf_CSYy1mxs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2P58esIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RdzZpjb7, 1, m, &cIf_RdzZpjb7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VtkSduZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RdzZpjb7, 0, m, &cIf_RdzZpjb7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fpeTpxCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yH6wYZhb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hmzzROAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yH6wYZhb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ABKLeIcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eabH8c5B_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_8SAYR2L9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dZ7jNMpc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UJte17ln_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oB524VdY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oB524VdY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AZxK5f6h, 1, m, &cDelay_AZxK5f6h_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HufhDbaH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_AZxK5f6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AZxK5f6h, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ABKLeIcK, 0, m, &cIf_ABKLeIcK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oB524VdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AZxK5f6h, 0, m, &cDelay_AZxK5f6h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HufhDbaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AZxK5f6h, 0, m, &cDelay_AZxK5f6h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IoIYp9Wn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QZZ3kOCS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y2GZseiU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DapG8Lit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9KlMqGVj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gQDZzkf9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gQDZzkf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UJte17ln_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_9KlMqGVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ABKLeIcK, 1, m, &cIf_ABKLeIcK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y2GZseiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8SAYR2L9, 0, m, &cIf_8SAYR2L9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QZZ3kOCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8SAYR2L9, 1, m, &cIf_8SAYR2L9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dZ7jNMpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lr0LSgxU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eabH8c5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lr0LSgxU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_qX80SwX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PcCnTlHc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BOR3lbj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FRjg8bEt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Htt91cw8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BjFBs8Wv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BjFBs8Wv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_C6Fmhkfo, 1, m, &cDelay_C6Fmhkfo_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2A1zqbVg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_C6Fmhkfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_C6Fmhkfo, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qX80SwX7, 0, m, &cIf_qX80SwX7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BjFBs8Wv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_C6Fmhkfo, 0, m, &cDelay_C6Fmhkfo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2A1zqbVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_C6Fmhkfo, 0, m, &cDelay_C6Fmhkfo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dFvoQBzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BrgtTlBm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zY2XVpXP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BJlCTDgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u0R5t5VT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ekGI9Rqk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ekGI9Rqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Htt91cw8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_u0R5t5VT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qX80SwX7, 1, m, &cIf_qX80SwX7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zY2XVpXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BOR3lbj2, 0, m, &cIf_BOR3lbj2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BrgtTlBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BOR3lbj2, 1, m, &cIf_BOR3lbj2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FRjg8bEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yp0LMf3D, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PcCnTlHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yp0LMf3D, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_K3Mx4neC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_e6fAb8kG_sendMessage(_c, 0, m);
  cMsg_R26d10PG_sendMessage(_c, 0, m);
  cMsg_80Fh35m2_sendMessage(_c, 0, m);
  cMsg_COvMFO1U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_98pum15y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_e6fAb8kG_sendMessage(_c, 0, m);
  cMsg_AQeuxT87_sendMessage(_c, 0, m);
  cMsg_k6czJ7Qg_sendMessage(_c, 0, m);
  cMsg_OLEHurE3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_A60BB0AX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_ncUnVZQi_sendMessage(_c, 0, m);
  cMsg_AQeuxT87_sendMessage(_c, 0, m);
  cMsg_COvMFO1U_sendMessage(_c, 0, m);
  cMsg_7Y6JtEDG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ys8xF5dJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_ncUnVZQi_sendMessage(_c, 0, m);
  cMsg_o0cYLmPQ_sendMessage(_c, 0, m);
  cMsg_80Fh35m2_sendMessage(_c, 0, m);
  cMsg_QcSPTMpS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JCmHiEN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_qnutoBUX_sendMessage(_c, 0, m);
  cMsg_OLEHurE3_sendMessage(_c, 0, m);
  cMsg_cgnn2kwX_sendMessage(_c, 0, m);
  cMsg_80Fh35m2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NceFt42x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_qnutoBUX_sendMessage(_c, 0, m);
  cMsg_QcSPTMpS_sendMessage(_c, 0, m);
  cMsg_AQeuxT87_sendMessage(_c, 0, m);
  cMsg_0A9nx8Ik_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mMaiQTo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i4IzaJ17_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RyceSu7q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lbR3GOEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i4IzaJ17_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RyceSu7q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kF7jFbMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_od8RmRQj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ejVdBn6H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oXSO0gd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_od8RmRQj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ejVdBn6H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H82tDmqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CsXR21e1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2mgNSX4y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qkJbrzTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CsXR21e1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2mgNSX4y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e6fAb8kG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_mMaiQTo0_sendMessage(_c, 0, m);
  cMsg_oXSO0gd5_sendMessage(_c, 0, m);
  cMsg_qkJbrzTu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ncUnVZQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_lbR3GOEw_sendMessage(_c, 0, m);
  cMsg_kF7jFbMD_sendMessage(_c, 0, m);
  cMsg_qkJbrzTu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qnutoBUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_lbR3GOEw_sendMessage(_c, 0, m);
  cMsg_oXSO0gd5_sendMessage(_c, 0, m);
  cMsg_H82tDmqP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_56GIdLuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZxeN6KYx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_f3DxniCZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IQNxaxKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZxeN6KYx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_f3DxniCZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3Ehrcja3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2zj9TgWF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NRUJvAkC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KzuQK9cf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2zj9TgWF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NRUJvAkC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VYz3sc84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VYW3BK00_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KQCv104w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NIESk8sC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VYW3BK00_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KQCv104w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AQeuxT87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_IQNxaxKa_sendMessage(_c, 0, m);
  cMsg_KzuQK9cf_sendMessage(_c, 0, m);
  cMsg_NIESk8sC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_R26d10PG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_IQNxaxKa_sendMessage(_c, 0, m);
  cMsg_3Ehrcja3_sendMessage(_c, 0, m);
  cMsg_VYz3sc84_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_o0cYLmPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_56GIdLuL_sendMessage(_c, 0, m);
  cMsg_KzuQK9cf_sendMessage(_c, 0, m);
  cMsg_VYz3sc84_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Ub7nUoN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AcrwucDk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yyVbZrLj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6WDrum6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AcrwucDk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yyVbZrLj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_avEpBiFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DapG8Lit_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IoIYp9Wn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uSP6puzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DapG8Lit_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IoIYp9Wn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MpETk9QA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BJlCTDgh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dFvoQBzT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oXlTA8m2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BJlCTDgh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dFvoQBzT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QcSPTMpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_Ub7nUoN8_sendMessage(_c, 0, m);
  cMsg_uSP6puzN_sendMessage(_c, 0, m);
  cMsg_oXlTA8m2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OLEHurE3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_6WDrum6N_sendMessage(_c, 0, m);
  cMsg_avEpBiFX_sendMessage(_c, 0, m);
  cMsg_oXlTA8m2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_COvMFO1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_6WDrum6N_sendMessage(_c, 0, m);
  cMsg_uSP6puzN_sendMessage(_c, 0, m);
  cMsg_MpETk9QA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CTALRRL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5ZPZaiud_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GriKmvWM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2OSPBwyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5ZPZaiud_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GriKmvWM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dYIwZGWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IInRhgDt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T7iMgoGR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yDJLncnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IInRhgDt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T7iMgoGR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uUCCrbRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hBo7a8y8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PHrjVgnx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sGxsONme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hBo7a8y8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PHrjVgnx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_80Fh35m2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_2OSPBwyK_sendMessage(_c, 0, m);
  cMsg_yDJLncnp_sendMessage(_c, 0, m);
  cMsg_sGxsONme_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_k6czJ7Qg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_2OSPBwyK_sendMessage(_c, 0, m);
  cMsg_dYIwZGWs_sendMessage(_c, 0, m);
  cMsg_uUCCrbRk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0A9nx8Ik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_CTALRRL4_sendMessage(_c, 0, m);
  cMsg_dYIwZGWs_sendMessage(_c, 0, m);
  cMsg_sGxsONme_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cgnn2kwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_56GIdLuL_sendMessage(_c, 0, m);
  cMsg_3Ehrcja3_sendMessage(_c, 0, m);
  cMsg_NIESk8sC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7Y6JtEDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_CTALRRL4_sendMessage(_c, 0, m);
  cMsg_yDJLncnp_sendMessage(_c, 0, m);
  cMsg_uUCCrbRk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_WMrGwTmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FF6NBflv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_snDcVXc6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_C51KiI8W, 0, m, &cSlice_C51KiI8W_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pSqxqXGa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_C51KiI8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GCSPhrzM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GCSPhrzM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_EW2X8Ct7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GCSPhrzM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_GCSPhrzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0tKO5vnk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CzIE49Ck_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aNJajyXD, 0, m, &cSlice_aNJajyXD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lb7L5rBb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_aNJajyXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ou5OOcKR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ou5OOcKR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qGgomkPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ou5OOcKR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ou5OOcKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KPCmRHBr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lb7L5rBb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_s73Zijn5, 0, m, &cSlice_s73Zijn5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_snDcVXc6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_s73Zijn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_isNXhLfK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_isNXhLfK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_7LsTmTX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_isNXhLfK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_isNXhLfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AcmkmZuE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pSqxqXGa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aMFUgKAD, 0, m, &cSlice_aMFUgKAD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UoinScod_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_aMFUgKAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RObzfdU9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RObzfdU9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_lDiTs6tI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RObzfdU9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_RObzfdU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dIGu07Lq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UoinScod_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xM3l11R9, 0, m, &cSlice_xM3l11R9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wFow4ftN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_xM3l11R9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MLdvWCZm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MLdvWCZm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Zxh8KC1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MLdvWCZm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_MLdvWCZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gqFwzkTz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_iq0deRJD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_gWK3N8gi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_gWK3N8gi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6QZ1rGwq, 1, m, &cDelay_6QZ1rGwq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pWm1XvRq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6QZ1rGwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6QZ1rGwq, m);
  cMsg_SaEr5skt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gWK3N8gi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6QZ1rGwq, 0, m, &cDelay_6QZ1rGwq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pWm1XvRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6QZ1rGwq, 0, m, &cDelay_6QZ1rGwq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_o6w5MxAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0TULY9QE, HV_BINOP_SUBTRACT, 0, m, &cBinop_0TULY9QE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_tOohxStX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LZabi34i_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dRIowNZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LZabi34i_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_FqfYkyAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o6w5MxAC, 0, m, &cVar_o6w5MxAC_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_Ji0eJU6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5sXOOuMn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4jA8aKIY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4HsnSYMD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0TULY9QE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wrSEn1bb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wrSEn1bb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hrCbjkQw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hrCbjkQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_shRpUFtH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YnvGv4wV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v6YI5Ewb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R3ApNvEZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_R3ApNvEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j43YWbVL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_v6YI5Ewb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tOohxStX, 1, m, &cIf_tOohxStX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fpOUENna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dRIowNZS, 1, m, &cIf_dRIowNZS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_j43YWbVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_tOohxStX, 0, m, &cIf_tOohxStX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_shRpUFtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dRIowNZS, 0, m, &cIf_dRIowNZS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4HsnSYMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o6w5MxAC, 0, m, &cVar_o6w5MxAC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5sXOOuMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_4jA8aKIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0TULY9QE, HV_BINOP_SUBTRACT, 1, m, &cBinop_0TULY9QE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LZabi34i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qNa9P7QN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wFow4ftN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ypqlEIcG, 0, m, &cSlice_ypqlEIcG_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ypqlEIcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lxEZfQF0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lxEZfQF0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_QKTHFUJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lxEZfQF0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_lxEZfQF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ucEet2P3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WX8OhPiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e7eMtbwg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5LkN1QjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lBf3Oew8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_b2E4jNZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OMJWE3G8, 0, m, &cVar_OMJWE3G8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FF6NBflv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZLla85wY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BuhzkVN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iq0deRJD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_aB5zTLb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NeRmSUP3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SaEr5skt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IukNwyPa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NeRmSUP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IukNwyPa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_czz1UwKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_c6B3OUsS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c6B3OUsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0SBo9XV3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0SBo9XV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JtA5RVrk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_6xYnj5YY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y3nAnR6t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_mQo5nD7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xNkruj3R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_m1393Zml_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_am0UclMP_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d3sgcW8W_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OERbq6Mc_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZNXvgXFl_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J5qmVMD0_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lO242lOf_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_am0UclMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x4yQD5l7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_d3sgcW8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oYLE4Hbp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_OERbq6Mc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TWvBefD1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ZNXvgXFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dIr5P07T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_J5qmVMD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RMdnxSR9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_lO242lOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2ijstTmM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_85Od2iKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_R7A7BekI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2uuf3j0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ytqAfLVb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MKYU6icX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6KCGje2e_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6KCGje2e_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wULsN3Kw, 1, m, &cDelay_wULsN3Kw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BN0871l9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wULsN3Kw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wULsN3Kw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_85Od2iKo, 0, m, &cIf_85Od2iKo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6KCGje2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wULsN3Kw, 0, m, &cDelay_wULsN3Kw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BN0871l9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wULsN3Kw, 0, m, &cDelay_wULsN3Kw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KrPmDUON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OY3WLGmG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jlYpFoos_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KNd1PhRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w41c0UnX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zheoMRYB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zheoMRYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MKYU6icX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_w41c0UnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_85Od2iKo, 1, m, &cIf_85Od2iKo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OY3WLGmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2uuf3j0S, 1, m, &cIf_2uuf3j0S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jlYpFoos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2uuf3j0S, 0, m, &cIf_2uuf3j0S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ytqAfLVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_77cbYjrW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_R7A7BekI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_77cbYjrW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_MnH1fX0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_is8PjFVj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_S5ljgGVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0FCZvJ37_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RKVfGWa5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Sz1KrpVT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Sz1KrpVT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_W6gULqam, 1, m, &cDelay_W6gULqam_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XU5JtNd9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_W6gULqam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_W6gULqam, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MnH1fX0f, 0, m, &cIf_MnH1fX0f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Sz1KrpVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_W6gULqam, 0, m, &cDelay_W6gULqam_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XU5JtNd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_W6gULqam, 0, m, &cDelay_W6gULqam_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ud9eqBNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QMb2YFQN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UJkZpzsu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uis8yiYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uYzO9UXG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JOmE1N32_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uYzO9UXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MnH1fX0f, 1, m, &cIf_MnH1fX0f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JOmE1N32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RKVfGWa5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QMb2YFQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S5ljgGVo, 1, m, &cIf_S5ljgGVo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UJkZpzsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S5ljgGVo, 0, m, &cIf_S5ljgGVo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0FCZvJ37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Agu4Knfp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_is8PjFVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Agu4Knfp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_oq9xePxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_O6dZ8T3h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KY64qmzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z7c5ag5D_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UbhS91gW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jvdtBsoA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jvdtBsoA_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2JYfjnkn, 1, m, &cDelay_2JYfjnkn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wApdo1ux_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_2JYfjnkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2JYfjnkn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_oq9xePxq, 0, m, &cIf_oq9xePxq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jvdtBsoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2JYfjnkn, 0, m, &cDelay_2JYfjnkn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wApdo1ux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2JYfjnkn, 0, m, &cDelay_2JYfjnkn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6bngRHu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L4E9xv9l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gQZMhAMB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_smmzmQwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NuPgaMIn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DsXlGkWO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NuPgaMIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oq9xePxq, 1, m, &cIf_oq9xePxq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DsXlGkWO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UbhS91gW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_L4E9xv9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KY64qmzR, 1, m, &cIf_KY64qmzR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gQZMhAMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KY64qmzR, 0, m, &cIf_KY64qmzR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z7c5ag5D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VX3Jzxxd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_O6dZ8T3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VX3Jzxxd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_JuzUgZ84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NPD1C8dE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_6j3nt6v3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RccBfIXC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AITUkoDz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sTHeSIOc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sTHeSIOc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tQHPn1EO, 1, m, &cDelay_tQHPn1EO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ghKUMh0h_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tQHPn1EO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tQHPn1EO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_JuzUgZ84, 0, m, &cIf_JuzUgZ84_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sTHeSIOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tQHPn1EO, 0, m, &cDelay_tQHPn1EO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ghKUMh0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tQHPn1EO, 0, m, &cDelay_tQHPn1EO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yyyvHEmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gIZR5fEX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_66Qjb8Yo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ao5YW7Ma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TJTGih9J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aB8ptOta_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TJTGih9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JuzUgZ84, 1, m, &cIf_JuzUgZ84_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aB8ptOta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AITUkoDz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_gIZR5fEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6j3nt6v3, 1, m, &cIf_6j3nt6v3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_66Qjb8Yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6j3nt6v3, 0, m, &cIf_6j3nt6v3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RccBfIXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OC57oWxP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NPD1C8dE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OC57oWxP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ZhYAdAQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4FpKSVnK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zpnmdaOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AdWzjJCZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XFOsL2Kj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7EW7o8JA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7EW7o8JA_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_W2HcfOl5, 1, m, &cDelay_W2HcfOl5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X0mCO4ef_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_W2HcfOl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_W2HcfOl5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZhYAdAQE, 0, m, &cIf_ZhYAdAQE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7EW7o8JA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_W2HcfOl5, 0, m, &cDelay_W2HcfOl5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X0mCO4ef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_W2HcfOl5, 0, m, &cDelay_W2HcfOl5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JFLABaUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r9X7t8ew_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PH1HadYn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_t7Mxwyzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L9QGvj2V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aAYhNjNU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aAYhNjNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XFOsL2Kj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_L9QGvj2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZhYAdAQE, 1, m, &cIf_ZhYAdAQE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r9X7t8ew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zpnmdaOg, 1, m, &cIf_zpnmdaOg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PH1HadYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zpnmdaOg, 0, m, &cIf_zpnmdaOg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AdWzjJCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KrFrWn1R, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4FpKSVnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KrFrWn1R, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_JErM0S6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nXZ4qrLc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hHjJtlWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pBr0J2CU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QtqM8NZa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_C0R8BlWk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_C0R8BlWk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nqa3bm97, 1, m, &cDelay_nqa3bm97_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0pzq1fns_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_nqa3bm97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nqa3bm97, m);
  cIf_onMessage(_c, &Context(_c)->cIf_JErM0S6S, 0, m, &cIf_JErM0S6S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C0R8BlWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nqa3bm97, 0, m, &cDelay_nqa3bm97_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0pzq1fns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nqa3bm97, 0, m, &cDelay_nqa3bm97_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Nn1x4GuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6PyqHntJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y018eB0V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BlI7UEYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TH7IwKDG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0EXD79Jt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0EXD79Jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_QtqM8NZa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_TH7IwKDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JErM0S6S, 1, m, &cIf_JErM0S6S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y018eB0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hHjJtlWA, 0, m, &cIf_hHjJtlWA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6PyqHntJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hHjJtlWA, 1, m, &cIf_hHjJtlWA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pBr0J2CU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p7r21KzS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nXZ4qrLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p7r21KzS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_F7MyXYCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dV9QhaDn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vm2QN0t0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_k7rtDddf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BkrGUG6Y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_s1hMmy8b_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_s1hMmy8b_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CL3mQzId, 1, m, &cDelay_CL3mQzId_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8K8wk4fB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_CL3mQzId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CL3mQzId, m);
  cIf_onMessage(_c, &Context(_c)->cIf_F7MyXYCX, 0, m, &cIf_F7MyXYCX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_s1hMmy8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CL3mQzId, 0, m, &cDelay_CL3mQzId_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8K8wk4fB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CL3mQzId, 0, m, &cDelay_CL3mQzId_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sjjqi0Gj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TuMxSyKg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vN9LAeVN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MpxtiEyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ljsre9WR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PmRsKtuf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ljsre9WR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F7MyXYCX, 1, m, &cIf_F7MyXYCX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PmRsKtuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BkrGUG6Y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vN9LAeVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vm2QN0t0, 0, m, &cIf_vm2QN0t0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TuMxSyKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vm2QN0t0, 1, m, &cIf_vm2QN0t0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_k7rtDddf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pYemoRag, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dV9QhaDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pYemoRag, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_yUFbeLTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nSEt6bX4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jVmeXM9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sPK9YERi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8ZxhYjME_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ih6HHZ2d_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ih6HHZ2d_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_N7Ti76fN, 1, m, &cDelay_N7Ti76fN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zJFXaA2j_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_N7Ti76fN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_N7Ti76fN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_yUFbeLTT, 0, m, &cIf_yUFbeLTT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ih6HHZ2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_N7Ti76fN, 0, m, &cDelay_N7Ti76fN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zJFXaA2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_N7Ti76fN, 0, m, &cDelay_N7Ti76fN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kC90IAPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jlffFnUs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d6Z3gOFI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MGvqN8Xn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PUuUVjyK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MuopIoW0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MuopIoW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8ZxhYjME_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_PUuUVjyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yUFbeLTT, 1, m, &cIf_yUFbeLTT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d6Z3gOFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jVmeXM9E, 0, m, &cIf_jVmeXM9E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jlffFnUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jVmeXM9E, 1, m, &cIf_jVmeXM9E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sPK9YERi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2b3hOLJC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nSEt6bX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2b3hOLJC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Cz5yjzp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hSw7tmGm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_fFeYzYGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_drwU1ofH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_37JnVZzD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_RQfKphIZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_RQfKphIZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WkJLDFQd, 1, m, &cDelay_WkJLDFQd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uwRGvn9I_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_WkJLDFQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WkJLDFQd, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Cz5yjzp9, 0, m, &cIf_Cz5yjzp9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RQfKphIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WkJLDFQd, 0, m, &cDelay_WkJLDFQd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uwRGvn9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WkJLDFQd, 0, m, &cDelay_WkJLDFQd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DOwrpjdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8MVUx8pM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kglxmfzk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SSjtci3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HJOKiK8E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dKwipPMr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dKwipPMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_37JnVZzD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HJOKiK8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Cz5yjzp9, 1, m, &cIf_Cz5yjzp9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Kglxmfzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fFeYzYGi, 0, m, &cIf_fFeYzYGi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8MVUx8pM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fFeYzYGi, 1, m, &cIf_fFeYzYGi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_drwU1ofH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aYmJYLQG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hSw7tmGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aYmJYLQG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_paeEFSSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OkXcgjrZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_h2DJrqrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0fT7CZPZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_f8xfXiV4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_z7aNa7vO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_z7aNa7vO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vQrVyuLQ, 1, m, &cDelay_vQrVyuLQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mI6ZFycz_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vQrVyuLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vQrVyuLQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_paeEFSSx, 0, m, &cIf_paeEFSSx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z7aNa7vO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vQrVyuLQ, 0, m, &cDelay_vQrVyuLQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mI6ZFycz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vQrVyuLQ, 0, m, &cDelay_vQrVyuLQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jZHV1FpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xt1j3QlZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6wiyNV1w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yZ9xhyaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YX7Ckiom_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5SkJgHK6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5SkJgHK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_f8xfXiV4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YX7Ckiom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_paeEFSSx, 1, m, &cIf_paeEFSSx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Xt1j3QlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h2DJrqrP, 1, m, &cIf_h2DJrqrP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6wiyNV1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h2DJrqrP, 0, m, &cIf_h2DJrqrP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0fT7CZPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fHQFuWGv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OkXcgjrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fHQFuWGv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_cLLaQk9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nzjZdva4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_xc1EBUsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7pu6SQNi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_piXcVaTs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AN02i7yi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AN02i7yi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_E6PAGGso, 1, m, &cDelay_E6PAGGso_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tUxH3jjy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_E6PAGGso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_E6PAGGso, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cLLaQk9p, 0, m, &cIf_cLLaQk9p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AN02i7yi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_E6PAGGso, 0, m, &cDelay_E6PAGGso_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tUxH3jjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_E6PAGGso, 0, m, &cDelay_E6PAGGso_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T0ZCrwcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H7S5uJ8r_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gqvWtVnr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Hg4Srymt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HKj26URJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_52FtaCV8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_52FtaCV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_piXcVaTs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HKj26URJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cLLaQk9p, 1, m, &cIf_cLLaQk9p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gqvWtVnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xc1EBUsm, 0, m, &cIf_xc1EBUsm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_H7S5uJ8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xc1EBUsm, 1, m, &cIf_xc1EBUsm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7pu6SQNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CCRHszti, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nzjZdva4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CCRHszti, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_WxbktpZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vlagjmym_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_PJTr92UP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wKO8e8lT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_29AX3GTh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_RZRVP1c3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_RZRVP1c3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_X0QNDpUl, 1, m, &cDelay_X0QNDpUl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6K0Uzaz4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_X0QNDpUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_X0QNDpUl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WxbktpZk, 0, m, &cIf_WxbktpZk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RZRVP1c3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_X0QNDpUl, 0, m, &cDelay_X0QNDpUl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6K0Uzaz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_X0QNDpUl, 0, m, &cDelay_X0QNDpUl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JhOaOgGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ebfsWMJa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CLMPxv4F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_F6rLqL6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mIHtDZTk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_srJUyxSr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mIHtDZTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WxbktpZk, 1, m, &cIf_WxbktpZk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_srJUyxSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_29AX3GTh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ebfsWMJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PJTr92UP, 1, m, &cIf_PJTr92UP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CLMPxv4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PJTr92UP, 0, m, &cIf_PJTr92UP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wKO8e8lT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zXwH0fOf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vlagjmym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zXwH0fOf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_x4yQD5l7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_HGdUlmfF_sendMessage(_c, 0, m);
  cMsg_SXgJ95hb_sendMessage(_c, 0, m);
  cMsg_qRsOBcF3_sendMessage(_c, 0, m);
  cMsg_AgqUwe1s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_oYLE4Hbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_HGdUlmfF_sendMessage(_c, 0, m);
  cMsg_RlgVCXuJ_sendMessage(_c, 0, m);
  cMsg_nPmHGZu7_sendMessage(_c, 0, m);
  cMsg_oKjxMZAa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TWvBefD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_zDiBRLbh_sendMessage(_c, 0, m);
  cMsg_RlgVCXuJ_sendMessage(_c, 0, m);
  cMsg_AgqUwe1s_sendMessage(_c, 0, m);
  cMsg_SLCnpjSS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dIr5P07T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_zDiBRLbh_sendMessage(_c, 0, m);
  cMsg_PiGLLyl2_sendMessage(_c, 0, m);
  cMsg_qRsOBcF3_sendMessage(_c, 0, m);
  cMsg_4q6J0yRc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RMdnxSR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_GYEN7I3A_sendMessage(_c, 0, m);
  cMsg_oKjxMZAa_sendMessage(_c, 0, m);
  cMsg_mX8kFlAt_sendMessage(_c, 0, m);
  cMsg_qRsOBcF3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2ijstTmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_GYEN7I3A_sendMessage(_c, 0, m);
  cMsg_4q6J0yRc_sendMessage(_c, 0, m);
  cMsg_RlgVCXuJ_sendMessage(_c, 0, m);
  cMsg_tVivWkTR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_joSYQvZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KNd1PhRz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KrPmDUON_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_67R2xyex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KNd1PhRz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KrPmDUON_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ztNbHTef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uis8yiYE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ud9eqBNJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wpz1CrOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uis8yiYE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ud9eqBNJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_70FGT7S8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_smmzmQwZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6bngRHu4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kTLWfECV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_smmzmQwZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6bngRHu4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HGdUlmfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_joSYQvZh_sendMessage(_c, 0, m);
  cMsg_Wpz1CrOU_sendMessage(_c, 0, m);
  cMsg_kTLWfECV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zDiBRLbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_67R2xyex_sendMessage(_c, 0, m);
  cMsg_ztNbHTef_sendMessage(_c, 0, m);
  cMsg_kTLWfECV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GYEN7I3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_67R2xyex_sendMessage(_c, 0, m);
  cMsg_Wpz1CrOU_sendMessage(_c, 0, m);
  cMsg_70FGT7S8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IgMBhAKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ao5YW7Ma_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yyyvHEmr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VU1mwRI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ao5YW7Ma_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yyyvHEmr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cMrjJMtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t7Mxwyzg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JFLABaUe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y3eIVaM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t7Mxwyzg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JFLABaUe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nCGDn2nr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BlI7UEYj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Nn1x4GuN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AzFPKrqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BlI7UEYj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Nn1x4GuN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RlgVCXuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_VU1mwRI1_sendMessage(_c, 0, m);
  cMsg_Y3eIVaM0_sendMessage(_c, 0, m);
  cMsg_AzFPKrqL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SXgJ95hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_VU1mwRI1_sendMessage(_c, 0, m);
  cMsg_cMrjJMtT_sendMessage(_c, 0, m);
  cMsg_nCGDn2nr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PiGLLyl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_IgMBhAKA_sendMessage(_c, 0, m);
  cMsg_Y3eIVaM0_sendMessage(_c, 0, m);
  cMsg_nCGDn2nr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_n6fOIomI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yZ9xhyaC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jZHV1FpA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_21BDddxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yZ9xhyaC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jZHV1FpA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iIBjj2K7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Hg4Srymt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T0ZCrwcJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_euOeusm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Hg4Srymt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T0ZCrwcJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DQbo7net_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_F6rLqL6q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JhOaOgGF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ardUjwXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_F6rLqL6q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JhOaOgGF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4q6J0yRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_n6fOIomI_sendMessage(_c, 0, m);
  cMsg_euOeusm5_sendMessage(_c, 0, m);
  cMsg_ardUjwXB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_oKjxMZAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_21BDddxJ_sendMessage(_c, 0, m);
  cMsg_iIBjj2K7_sendMessage(_c, 0, m);
  cMsg_ardUjwXB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AgqUwe1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_21BDddxJ_sendMessage(_c, 0, m);
  cMsg_euOeusm5_sendMessage(_c, 0, m);
  cMsg_DQbo7net_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MKzaTalL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MpxtiEyD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sjjqi0Gj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mywzsE9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MpxtiEyD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sjjqi0Gj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PltlOXuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MGvqN8Xn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kC90IAPv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IaakVvBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MGvqN8Xn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kC90IAPv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZJcNhQfw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SSjtci3I_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DOwrpjdh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aISIWgOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SSjtci3I_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DOwrpjdh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qRsOBcF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_mywzsE9n_sendMessage(_c, 0, m);
  cMsg_IaakVvBo_sendMessage(_c, 0, m);
  cMsg_aISIWgOU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nPmHGZu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_mywzsE9n_sendMessage(_c, 0, m);
  cMsg_PltlOXuO_sendMessage(_c, 0, m);
  cMsg_ZJcNhQfw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tVivWkTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_MKzaTalL_sendMessage(_c, 0, m);
  cMsg_PltlOXuO_sendMessage(_c, 0, m);
  cMsg_aISIWgOU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mX8kFlAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_IgMBhAKA_sendMessage(_c, 0, m);
  cMsg_cMrjJMtT_sendMessage(_c, 0, m);
  cMsg_AzFPKrqL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SLCnpjSS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_MKzaTalL_sendMessage(_c, 0, m);
  cMsg_IaakVvBo_sendMessage(_c, 0, m);
  cMsg_ZJcNhQfw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ZwjETQDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PrtJ805V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_18iX0F4O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0HdJ3KLb, 0, m, &cSlice_0HdJ3KLb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oNU46fE8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_0HdJ3KLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KZIjm06L_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KZIjm06L_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_k8pweSoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KZIjm06L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_KZIjm06L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sXvzAFpW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6moHQryK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mJxDlffu, 0, m, &cSlice_mJxDlffu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pRTBmhGY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_mJxDlffu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jvg9fZuz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jvg9fZuz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_NxWm7J2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jvg9fZuz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_jvg9fZuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Zrq52lhK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pRTBmhGY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_B9IE28nt, 0, m, &cSlice_B9IE28nt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_18iX0F4O_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_B9IE28nt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ANDQfATH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ANDQfATH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_8C4eOfTs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ANDQfATH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ANDQfATH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qfHqTJ5K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oNU46fE8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pSVYJCy6, 0, m, &cSlice_pSVYJCy6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_v4BP7GnA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_pSVYJCy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jxp6Kpqt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jxp6Kpqt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_TGRleW5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jxp6Kpqt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_jxp6Kpqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mIG0QdlH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_v4BP7GnA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YzpUrc8l, 0, m, &cSlice_YzpUrc8l_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UpgpXrax_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_YzpUrc8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0xazvgR4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0xazvgR4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_rEXjIWTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0xazvgR4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_0xazvgR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DgYnVEDk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_O7gau1pm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Q3BC2Ge9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Q3BC2Ge9_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KeJUWUKU, 1, m, &cDelay_KeJUWUKU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LoZHgAe8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_KeJUWUKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KeJUWUKU, m);
  cMsg_FZ128egR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Q3BC2Ge9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KeJUWUKU, 0, m, &cDelay_KeJUWUKU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LoZHgAe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KeJUWUKU, 0, m, &cDelay_KeJUWUKU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_3njrxZ2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_47ThQ5GM, HV_BINOP_SUBTRACT, 0, m, &cBinop_47ThQ5GM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_A4fz3pR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3dWgQNg1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7jJk5oYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3dWgQNg1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_KfxuD6TR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3njrxZ2M, 0, m, &cVar_3njrxZ2M_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_fiGc2qn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_srdAqWN5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwzFddQj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_woPvPjRa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_47ThQ5GM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BuFvWfIf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BuFvWfIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QEzVBLUq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QEzVBLUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_kQSddKrg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ki3VpObY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yX9Zselk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PB7FDkUU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PB7FDkUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3XoVqJM8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_yX9Zselk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A4fz3pR5, 1, m, &cIf_A4fz3pR5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gy82WFyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7jJk5oYe, 1, m, &cIf_7jJk5oYe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3XoVqJM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_A4fz3pR5, 0, m, &cIf_A4fz3pR5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kQSddKrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7jJk5oYe, 0, m, &cIf_7jJk5oYe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_woPvPjRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3njrxZ2M, 0, m, &cVar_3njrxZ2M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_srdAqWN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_ZwzFddQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_47ThQ5GM, HV_BINOP_SUBTRACT, 1, m, &cBinop_47ThQ5GM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3dWgQNg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X5XYuGDA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UpgpXrax_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fZq7jbN3, 0, m, &cSlice_fZq7jbN3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_fZq7jbN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mpqMIoRD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mpqMIoRD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_oPf1ERCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mpqMIoRD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_mpqMIoRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tN7KX4u8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_y3nAnR6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fGAaMbC9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xNkruj3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qKQvoe99, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_CxLiBHgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mQo5nD7E, 0, m, &cVar_mQo5nD7E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PrtJ805V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lVdl2olh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_LGnYlDTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_35E5h5RS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_qxN5vDrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_O7gau1pm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FZ128egR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zS1cQmAk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_35E5h5RS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zS1cQmAk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qhupatXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_7jLADnVe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7jLADnVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HPCLfjp8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HPCLfjp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FeTzf2sk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_G96eb8EG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c5Lxb23a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_3GEbv2a2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nrlq75pH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Sh94fjUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lOelayyu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XUOFNk95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_szHQx403_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GP6LDwfZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yBeDLZpg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sAnxzqdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_szHQx403_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GP6LDwfZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yBeDLZpg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_kOO9IsAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QWg5XA9h, 0, m, &cVar_QWg5XA9h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YogoqD3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_szHQx403_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GP6LDwfZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yBeDLZpg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IpHLFrhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_szHQx403_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GP6LDwfZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yBeDLZpg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9Tpsb7UI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_szHQx403_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GP6LDwfZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yBeDLZpg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MOPAb0CE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_2xlSJCPv, 0, m, &cVar_2xlSJCPv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PoFbsPo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_HjXN0Ank, 0, m, &cVar_HjXN0Ank_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_19dctzJM, 0, m, &cVar_19dctzJM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Afk1tPnT, 0, m, &cVar_Afk1tPnT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gwHreIBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_kOO9IsAN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VP7HxV5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_p2DyqGNN_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UDwLoU5o_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_P7Ehb8hX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_p2DyqGNN_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UDwLoU5o_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2GNHzTBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_p2DyqGNN_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UDwLoU5o_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VokDtX4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_p2DyqGNN_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UDwLoU5o_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jzv4RNU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_p2DyqGNN_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UDwLoU5o_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_W0NE5Kru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_VRJULdfm, 0, m, &cVar_VRJULdfm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0fiERpFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_FgMXNGIE, 0, m, &cVar_FgMXNGIE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AwFZpHnv, 0, m, &cVar_AwFZpHnv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_P7kGlOd9, 0, m, &cVar_P7kGlOd9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WIGbMiaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_szHQx403_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GP6LDwfZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yBeDLZpg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cYpY0DdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4CYDI1FS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cdhulsuh_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_S1cSOjOu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wsVgTEBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4CYDI1FS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cdhulsuh_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_S1cSOjOu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_4ZeHFvUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1vLQPGIC, 0, m, &cVar_1vLQPGIC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FmmvVbzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4CYDI1FS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cdhulsuh_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_S1cSOjOu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_piIHdgRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4CYDI1FS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cdhulsuh_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_S1cSOjOu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Bxgan7LV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4CYDI1FS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cdhulsuh_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_S1cSOjOu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wbnmWq18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_YEFuJkRF, 0, m, &cVar_YEFuJkRF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OVciTB5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_VnxUnboj, 0, m, &cVar_VnxUnboj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5sfuyrn6, 0, m, &cVar_5sfuyrn6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tXaTEpBi, 0, m, &cVar_tXaTEpBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rwsUvSuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_4ZeHFvUK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FwUxgjOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4CYDI1FS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cdhulsuh_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_S1cSOjOu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OGHmzCVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RVXYrGgw_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CzIE49Ck_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6moHQryK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uMhgophq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RVXYrGgw_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CzIE49Ck_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6moHQryK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_I2FGQuGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1e6HILXf, 0, m, &cVar_1e6HILXf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fLhMIr2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RVXYrGgw_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CzIE49Ck_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6moHQryK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dCZ6keB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RVXYrGgw_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CzIE49Ck_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6moHQryK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NzBfOdoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RVXYrGgw_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CzIE49Ck_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6moHQryK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MI7cZmAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_s1OG7rt0, 0, m, &cVar_s1OG7rt0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aCw9xRrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_6rYTSDjx, 0, m, &cVar_6rYTSDjx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Xu9yOu5a, 0, m, &cVar_Xu9yOu5a_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AlxebHFj, 0, m, &cVar_AlxebHFj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_szETdB5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_I2FGQuGo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_t5px8smO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RVXYrGgw_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CzIE49Ck_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6moHQryK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wpMltKed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_G96eb8EG, 0, m, &cVar_G96eb8EG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_c5Lxb23a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_szHQx403_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GP6LDwfZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yBeDLZpg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PMSa6IBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_3GEbv2a2, 0, m, &cVar_3GEbv2a2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nrlq75pH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4CYDI1FS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cdhulsuh_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_S1cSOjOu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RhNOniKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Sh94fjUY, 0, m, &cVar_Sh94fjUY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lOelayyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RVXYrGgw_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CzIE49Ck_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6moHQryK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cReceive_Mp9V8uLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jMC6zvXd_sendMessage(_c, 0, m);
  cMsg_luzq25KS_sendMessage(_c, 0, m);
  cMsg_MLGejcIc_sendMessage(_c, 0, m);
  cMsg_CK0Ql1JM_sendMessage(_c, 0, m);
  cMsg_vGg8KU27_sendMessage(_c, 0, m);
  cMsg_T1k4X9Cs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_m0Vc20vo, 0, m, &cVar_m0Vc20vo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OENN9mS6, 0, m, &cVar_OENN9mS6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5xuEdGxO, 0, m, &cVar_5xuEdGxO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5BBDrIb1, 0, m, &cVar_5BBDrIb1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_e1sEp9ve, 0, m, &cVar_e1sEp9ve_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ua7fajCy, 0, m, &cVar_ua7fajCy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_v5LxHMPg, 0, m, &cVar_v5LxHMPg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0JcAXdMt, 0, m, &cVar_0JcAXdMt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BPwKfckO, 0, m, &cVar_BPwKfckO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NDae5hLR, 0, m, &cVar_NDae5hLR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TU5GhfIl, 0, m, &cVar_TU5GhfIl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_l9YylZc9, 0, m, &cVar_l9YylZc9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ig47BK8P, 0, m, &cVar_Ig47BK8P_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_05JEKXfM, 0, m, &cVar_05JEKXfM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qOLIP4vi, 0, m, &cVar_qOLIP4vi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fiXderSY, 0, m, &cVar_fiXderSY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JZCqzOUf, 0, m, &cVar_JZCqzOUf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HDCKI7bg, 0, m, &cVar_HDCKI7bg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZVcCdinu, 0, m, &cVar_ZVcCdinu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6HVuIM0B, 0, m, &cVar_6HVuIM0B_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3YxGIfqG, 0, m, &cVar_3YxGIfqG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GGCOpbLJ, 0, m, &cVar_GGCOpbLJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c9xBnI8G, 0, m, &cVar_c9xBnI8G_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_M83fCIG2, 0, m, &cVar_M83fCIG2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5UAAzONG, 0, m, &cVar_5UAAzONG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lGWefWbR, 0, m, &cVar_lGWefWbR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fTCEF38k, 0, m, &cVar_fTCEF38k_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iAahEpV5, 0, m, &cVar_iAahEpV5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lT7SXneM, 0, m, &cVar_lT7SXneM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Fr5ydkOR, 0, m, &cVar_Fr5ydkOR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SNedbURD, 0, m, &cVar_SNedbURD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Mq40YHWg, 0, m, &cVar_Mq40YHWg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7QfeL9uu, 0, m, &cVar_7QfeL9uu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2qY37F5t, 0, m, &cVar_2qY37F5t_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VgtG77b4, 0, m, &cVar_VgtG77b4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Dft3JYeP, 0, m, &cVar_Dft3JYeP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ACBRmulD, 0, m, &cVar_ACBRmulD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0TXJyXQW, 0, m, &cVar_0TXJyXQW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lZEtyw0M, 0, m, &cVar_lZEtyw0M_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yXW42IFC, 0, m, &cVar_yXW42IFC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_i2ZpbJJ0, 0, m, &cVar_i2ZpbJJ0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E061iVAs, 0, m, &cVar_E061iVAs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lNPRH2MB, 0, m, &cVar_lNPRH2MB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_47xNtCvu, 0, m, &cVar_47xNtCvu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RGj2nIFy, 0, m, &cVar_RGj2nIFy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HjbRCSEJ, 0, m, &cVar_HjbRCSEJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EW2X8Ct7, 0, m, &cVar_EW2X8Ct7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qGgomkPo, 0, m, &cVar_qGgomkPo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7LsTmTX5, 0, m, &cVar_7LsTmTX5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lDiTs6tI, 0, m, &cVar_lDiTs6tI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Zxh8KC1Z, 0, m, &cVar_Zxh8KC1Z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QKTHFUJw, 0, m, &cVar_QKTHFUJw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_k8pweSoF, 0, m, &cVar_k8pweSoF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NxWm7J2N, 0, m, &cVar_NxWm7J2N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8C4eOfTs, 0, m, &cVar_8C4eOfTs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TGRleW5p, 0, m, &cVar_TGRleW5p_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rEXjIWTS, 0, m, &cVar_rEXjIWTS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oPf1ERCy, 0, m, &cVar_oPf1ERCy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zEIlwV5j, 0, m, &cVar_zEIlwV5j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jNrNVveR, 0, m, &cVar_jNrNVveR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_japzphwf, 0, m, &cVar_japzphwf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ahtvu1s2_sendMessage);
  cMsg_0fiERpFx_sendMessage(_c, 0, m);
  cMsg_W0NE5Kru_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_enbEf8ck_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pqhbenHk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3qc0W03f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FgMXNGIE, 0, m, &cVar_FgMXNGIE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Sj9Eiy1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AwFZpHnv, 0, m, &cVar_AwFZpHnv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_CxmzKkM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P7kGlOd9, 0, m, &cVar_P7kGlOd9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_O2goxc45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OENN9mS6, 0, m, &cVar_OENN9mS6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_w4TkuJ3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PohJjaoD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WNOQLMOo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cZRsYZDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g4zNVHhP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Np1OC2JM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xMBXQg0X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dtYzCdR8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_U8DLnmL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0N6NgLPF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GNjFznof_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sk1zkC2I_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C3QsM7qN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_U3apDi9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HMYZuVv5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z1GN2wKU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mn1FeQuY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_95XvjZ3a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_8hNvUIyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_alsCAW9Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_alsCAW9Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_conJjrk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ETIXt2TV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MmVBZlVM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_iBG1Kp6n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_8sLwF1ok_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_k5csx9Vi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HC87nd3H_sendMessage);
  cMsg_7bbAcTzI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_7vUadh1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ck8TVKEt, HV_BINOP_MULTIPLY, 0, m, &cBinop_ck8TVKEt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Cfq0M0sl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_9wsXUfTt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_VwDYbti5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3kbvE3iZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_3kbvE3iZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iC0qfXzF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_UTop13RN_sendMessage);
  cMsg_HiTmROqD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_iNyXsMch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JBSbfXUm, HV_BINOP_MULTIPLY, 0, m, &cBinop_JBSbfXUm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fErdnAh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8UAV8X9B_sendMessage(_c, 0, m);
  cMsg_LJP6aCC2_sendMessage(_c, 0, m);
  cMsg_8tNC6FIN_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_BCEE370E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3eLHJgNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_j1eHzF2E_sendMessage);
  cMsg_N51SbXpZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_urx2DN0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e1sEp9ve, 0, m, &cVar_e1sEp9ve_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_XquoLF4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pIRMcl4N_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_69b6jdno_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_btM8hIZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TjK76G2k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nTjU2imZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iageSayo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m0mvRESl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qySrtmQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NF95rGIb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CeMbVcX0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3WxUgMmq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sX2Ng8bq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_lRpP0hsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WggiHaNe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N33uqKR2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BXijdTbf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g5lvB5bf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_6PxujwKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tT1z7LRs, HV_BINOP_MULTIPLY, 0, m, &cBinop_tT1z7LRs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ITeliLSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mEFwBMYG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MQoM6M89_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_2kBvZNRU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_rWZklM9e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_0nte55Mp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rxzXrZHg_sendMessage);
  cMsg_25gGFcGx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_QaRU7Ygz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xXL6YYNb, HV_BINOP_MULTIPLY, 0, m, &cBinop_xXL6YYNb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_e4B9sPNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_bpfk01RM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pu0YKREN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v8Hefri0, HV_BINOP_MULTIPLY, 1, m, &cBinop_v8Hefri0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_slWZOd6c_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1oYQvzdZ_sendMessage);
  cMsg_jqB29Z69_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_oETZPW2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_POtlFmRC, HV_BINOP_MULTIPLY, 0, m, &cBinop_POtlFmRC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_H65yZ30g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oeXdGiZU_sendMessage(_c, 0, m);
  cMsg_Iq8GclSv_sendMessage(_c, 0, m);
  cMsg_29MM8uN1_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_0bD7l6Iz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hPsxYuyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_61dDhOlK_sendMessage);
  cMsg_DtZAVpLb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_mlK7DrTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VRJULdfm, 0, m, &cVar_VRJULdfm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_VONRHEsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mcglm4nA, 0, m, &cVar_mcglm4nA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GQulbnvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2xlSJCPv, 0, m, &cVar_2xlSJCPv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yeAe2wmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HjXN0Ank, 0, m, &cVar_HjXN0Ank_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qaZgB91j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_19dctzJM, 0, m, &cVar_19dctzJM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5TXpXGiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Afk1tPnT, 0, m, &cVar_Afk1tPnT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_FNHFSRAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_kOO9IsAN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_uGfPaAjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_dSu2lsKZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_8JgDoyPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Oj4A7OKa, 0, m, &cVar_Oj4A7OKa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PJrhQlVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dD1rzvho, 0, m, &cVar_dD1rzvho_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vDXrPMbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_PrbZ45mP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_B25a8IGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_R87j9nVG_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PtBNJu6a_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_93gyTGAL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZYD9MMCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mUbJreEk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9SrMwYyk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2YaiIynC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1qjJIaKv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_9KcC0fSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dTCyg6YT, 0, m, &cVar_dTCyg6YT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4vrS2Acb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_apzprhBi, 0, m, &cVar_apzprhBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yjwZGhoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_gyFus9aD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qEvkzBJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EtRa6Z6O_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QFIeHAfJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h5x3yc2S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_kJJJziUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fTFPZI82_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rIj83MSV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_K09PyThU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nw5mW83n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_LD8z40W5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pcpwBdcA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZOjQKwGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I2P4LNZk, 0, m, &cVar_I2P4LNZk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_nRje5SyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4rBynSrH, 0, m, &cVar_4rBynSrH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_LS9xq3sQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_tOBFtw83_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_VN4jK5OJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4gRrldtf_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9hFI6RsL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qNbDfBgV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WcbraJ7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aonVNOnL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Co1JVoqe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_OUZ9iJr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JGKlQNTc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_35P53LmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZoX8s6kT, 0, m, &cVar_ZoX8s6kT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_trPS2f08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3mCiBYhv, 0, m, &cVar_3mCiBYhv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2lIvgMws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_Gxla55EF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AWkXwkSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Bgwc3mHz_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RckSMo6a_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NEW0EDlv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_BdLC17S2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9QkEHfJt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Vz5xbTDn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_VWVT6StR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ETtwHfMt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_goCIr6U1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_581Knwc0, 0, m, &cVar_581Knwc0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7qyJXOw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YEFuJkRF, 0, m, &cVar_YEFuJkRF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cyPZSapt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VnxUnboj, 0, m, &cVar_VnxUnboj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ssXx6hgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5sfuyrn6, 0, m, &cVar_5sfuyrn6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_MdRNnIwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tXaTEpBi, 0, m, &cVar_tXaTEpBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_P2NWIZcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_4ZeHFvUK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_RVa5cbT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_adWxFz2r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_0tKO5vnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Clt6Zoyn, 0, m, &cVar_Clt6Zoyn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_dIGu07Lq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WMrGwTmP, 0, m, &cVar_WMrGwTmP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AcmkmZuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_b2E4jNZm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_KPCmRHBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_x9O9Onbl_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aB5zTLb1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BuhzkVN2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_gqFwzkTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YnvGv4wV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fpOUENna_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ucEet2P3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_czz1UwKn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_sXvzAFpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6xYnj5YY, 0, m, &cVar_6xYnj5YY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_mIG0QdlH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZwjETQDb, 0, m, &cVar_ZwjETQDb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qfHqTJ5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_CxLiBHgj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Zrq52lhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_m1393Zml_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LGnYlDTp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qxN5vDrj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_DgYnVEDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ki3VpObY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gy82WFyB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_tN7KX4u8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qhupatXs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_XhlqMELE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j6uvWIKl, 0, m, &cVar_j6uvWIKl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2wx4snFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_s1OG7rt0, 0, m, &cVar_s1OG7rt0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_iVKiS28S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6rYTSDjx, 0, m, &cVar_6rYTSDjx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_A6BwoHJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Xu9yOu5a, 0, m, &cVar_Xu9yOu5a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_CY5kSDMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AlxebHFj, 0, m, &cVar_AlxebHFj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_o8mRO4Bl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_I2FGQuGo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pC3fK8Sj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_G96eb8EG, 0, m, &cVar_G96eb8EG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_OvJd2g86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3GEbv2a2, 0, m, &cVar_3GEbv2a2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_h6Ksl2zW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Sh94fjUY, 0, m, &cVar_Sh94fjUY_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_M3NGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14, Bf15, Bf16, Bf17, Bf18, Bf19, Bf20;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_8gpLsLxH, VOf(Bf0));
    __hv_line_f(&sLine_xKTUl20e, VOf(Bf1));
    __hv_line_f(&sLine_1BFSvd7e, VOf(Bf2));
    __hv_line_f(&sLine_S8oitVEB, VOf(Bf3));
    __hv_line_f(&sLine_IjY6WXbY, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_vMzzKipS, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_3GE3uPId, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_sXWwoWC5, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_BwceLg0b, VOf(Bf1));
    __hv_line_f(&sLine_dhPTGs5Z, VOf(Bf0));
    __hv_line_f(&sLine_e4C4VoPu, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_4wsJdvgg, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_Rds01OCF, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_koqR3SLU, VOf(Bf5));
    __hv_line_f(&sLine_aCddIJlP, VOf(Bf1));
    __hv_line_f(&sLine_XC1pk1Pj, VOf(Bf2));
    __hv_line_f(&sLine_XkP9wYM6, VOf(Bf4));
    __hv_line_f(&sLine_nZCXD3W8, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_sQ8A27L8, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_FB4Lp3v4, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_AOhYMSCx, VOf(Bf6));
    __hv_line_f(&sLine_0qtg9GTz, VOf(Bf2));
    __hv_line_f(&sLine_hJe11JTT, VOf(Bf1));
    __hv_line_f(&sLine_fIk6GPA8, VOf(Bf5));
    __hv_line_f(&sLine_0TXHjwy5, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_45oztHpv, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_S41LmQHg, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_YsOK3q8m, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_LxPvXehJ, VOf(Bf2));
    __hv_line_f(&sLine_TYdsVxTG, VOf(Bf6));
    __hv_line_f(&sLine_EiYTq00V, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_eXUYnWl9, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_GKuUAZRb, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_wOBivBL0, VOf(Bf8));
    __hv_line_f(&sLine_J3LuU9yn, VOf(Bf2));
    __hv_line_f(&sLine_rei1ZE9S, VOf(Bf1));
    __hv_line_f(&sLine_VIRQ1hLE, VOf(Bf7));
    __hv_line_f(&sLine_tFOJ0HXl, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_27ECAHYi, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_gD0ejcST, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_xKR11wq8, VIf(Bf0));
    __hv_varwrite_f(&sVarf_YYpfE8vd, VIf(Bf6));
    __hv_varwrite_f(&sVarf_BDdpu7ib, VIf(Bf4));
    __hv_varwrite_f(&sVarf_4LCaiTDf, VIf(Bf7));
    __hv_varread_f(&sVarf_KmSAnXtT, VOf(Bf7));
    __hv_varread_f(&sVarf_oc2lKD8U, VOf(Bf4));
    __hv_varread_f(&sVarf_740iwOxx, VOf(Bf6));
    __hv_varread_f(&sVarf_S1ZXCq5C, VOf(Bf0));
    __hv_varread_f(&sVarf_Zo0VrZCI, VOf(Bf9));
    __hv_varread_f(&sVarf_SoCHF71H, VOf(Bf1));
    __hv_line_f(&sLine_8bVpYlcl, VOf(Bf2));
    __hv_line_f(&sLine_6fu6NTyW, VOf(Bf8));
    __hv_mul_f(VIf(Bf0), VIf(Bf8), VOf(Bf0));
    __hv_fma_f(VIf(Bf6), VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varwrite_f(&sVarf_740iwOxx, VIf(Bf7));
    __hv_varwrite_f(&sVarf_Zo0VrZCI, VIf(Bf4));
    __hv_varread_f(&sVarf_ClZDZOO0, VOf(Bf2));
    __hv_varread_f(&sVarf_kuXZFnFu, VOf(Bf9));
    __hv_varread_f(&sVarf_O4xkAT0b, VOf(Bf1));
    __hv_varread_f(&sVarf_ZfzWhi2h, VOf(Bf6));
    __hv_varread_f(&sVarf_wbiKmOrQ, VOf(Bf10));
    __hv_varread_f(&sVarf_GQp3Pyfj, VOf(Bf11));
    __hv_varread_f(&sVarf_wQiL2RQe, VOf(Bf12));
    __hv_varwrite_f(&sVarf_n6Kh2wKY, VIf(Bf7));
    __hv_varread_f(&sVarf_Wydcnaol, VOf(Bf13));
    __hv_line_f(&sLine_2IVthB2H, VOf(Bf14));
    __hv_mul_f(VIf(Bf13), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_Vf5bU7Me, VOf(Bf15));
    __hv_line_f(&sLine_u37Nps0Z, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_8e2PBywl, VOf(Bf14));
    __hv_line_f(&sLine_NeHOBh6o, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_ZfzWhi2h, VIf(Bf17));
    __hv_varread_f(&sVarf_n6Kh2wKY, VOf(Bf17));
    __hv_line_f(&sLine_Opn4Jii6, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_cekNCDO8, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_MJGn8zBx, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_wbiKmOrQ, VIf(Bf16));
    __hv_line_f(&sLine_uVjYDY1T, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_Mhu9rxNI, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_WJNjnM0b, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_GQp3Pyfj, VIf(Bf16));
    __hv_line_f(&sLine_1UyiRAFS, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_NScTiuMk, VOf(Bf17));
    __hv_mul_f(VIf(Bf15), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_hn2kkQd5, VOf(Bf16));
    __hv_mul_f(VIf(Bf13), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_wQiL2RQe, VIf(Bf16));
    __hv_varwrite_f(&sVarf_Wydcnaol, VIf(Bf2));
    __hv_varwrite_f(&sVarf_Vf5bU7Me, VIf(Bf9));
    __hv_varwrite_f(&sVarf_8e2PBywl, VIf(Bf1));
    sEnv_process(this, &sEnv_Gd2P1O9f, VIf(Bf6), &sEnv_Gd2P1O9f_sendMessage);
    sEnv_process(this, &sEnv_hU5NBXq2, VIf(Bf7), &sEnv_hU5NBXq2_sendMessage);
    __hv_line_f(&sLine_7JfwaUPA, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_EU04SOaF, VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_m3LvETdm, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_ZzHqHHdh, VOf(Bf6));
    __hv_line_f(&sLine_oS6FfjSh, VOf(Bf1));
    __hv_var_k_f(VOf(Bf9), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_ClZDZOO0, VIf(Bf9));
    __hv_varwrite_f(&sVarf_ZzHqHHdh, VIf(Bf10));
    __hv_varwrite_f(&sVarf_z2uePwkE, VIf(Bf11));
    __hv_varwrite_f(&sVarf_TzEVZb9I, VIf(Bf12));
    __hv_varread_f(&sVarf_TzEVZb9I, VOf(Bf12));
    __hv_line_f(&sLine_OmSc8pO4, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf11), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf9));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf12), VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_O4xkAT0b, VIf(Bf10));
    __hv_varread_f(&sVarf_z2uePwkE, VOf(Bf10));
    __hv_line_f(&sLine_fZO0Ig5m, VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf9));
    __hv_sub_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_neg_f(VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_kuXZFnFu, VIf(Bf10));
    __hv_varwrite_f(&sVarf_S1ZXCq5C, VIf(Bf7));
    __hv_varread_f(&sVarf_icgUy75s, VOf(Bf7));
    __hv_varread_f(&sVarf_f5nmAiSL, VOf(Bf10));
    __hv_varread_f(&sVarf_7b5yGqqk, VOf(Bf9));
    __hv_varread_f(&sVarf_gxfIuslo, VOf(Bf11));
    __hv_varread_f(&sVarf_XSiyPETZ, VOf(Bf6));
    __hv_varread_f(&sVarf_H6DhoqA8, VOf(Bf12));
    __hv_varread_f(&sVarf_oVr0Pxkh, VOf(Bf1));
    __hv_varwrite_f(&sVarf_bBZfNgTW, VIf(Bf4));
    __hv_varread_f(&sVarf_xaU3Y9u6, VOf(Bf2));
    __hv_line_f(&sLine_SbSYLvwI, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_Q8CsfXKn, VOf(Bf17));
    __hv_line_f(&sLine_XFQ13COj, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_varread_f(&sVarf_Laxrfx8d, VOf(Bf16));
    __hv_line_f(&sLine_NolKfIJy, VOf(Bf15));
    __hv_mul_f(VIf(Bf16), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_gxfIuslo, VIf(Bf15));
    __hv_varread_f(&sVarf_bBZfNgTW, VOf(Bf15));
    __hv_line_f(&sLine_ai4Rrm7G, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_HBTMyIZf, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_N3hcnKQo, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_XSiyPETZ, VIf(Bf13));
    __hv_line_f(&sLine_xjcHCRuk, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_8YJRabq6, VOf(Bf18));
    __hv_mul_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_REDl5Uqi, VOf(Bf13));
    __hv_mul_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_H6DhoqA8, VIf(Bf13));
    __hv_line_f(&sLine_3RXeUR7A, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_Mb0pdEZa, VOf(Bf15));
    __hv_mul_f(VIf(Bf17), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_line_f(&sLine_UqEeyZfd, VOf(Bf13));
    __hv_mul_f(VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_oVr0Pxkh, VIf(Bf13));
    __hv_varwrite_f(&sVarf_xaU3Y9u6, VIf(Bf7));
    __hv_varwrite_f(&sVarf_Q8CsfXKn, VIf(Bf10));
    __hv_varwrite_f(&sVarf_Laxrfx8d, VIf(Bf9));
    sEnv_process(this, &sEnv_3SELgnaC, VIf(Bf11), &sEnv_3SELgnaC_sendMessage);
    sEnv_process(this, &sEnv_cEiuOTs7, VIf(Bf4), &sEnv_cEiuOTs7_sendMessage);
    __hv_line_f(&sLine_jtDRkTkJ, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_DarPhv4Q, VOf(Bf11));
    __hv_mul_f(VIf(Bf4), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_ga5m3mKQ, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_dkzVQRGk, VOf(Bf11));
    __hv_line_f(&sLine_aEeksWFX, VOf(Bf9));
    __hv_var_k_f(VOf(Bf10), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_floor_f(VIf(Bf9), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_div_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_icgUy75s, VIf(Bf10));
    __hv_varwrite_f(&sVarf_dkzVQRGk, VIf(Bf6));
    __hv_varwrite_f(&sVarf_XI9McXIg, VIf(Bf12));
    __hv_varwrite_f(&sVarf_tAgFyoWp, VIf(Bf1));
    __hv_varread_f(&sVarf_tAgFyoWp, VOf(Bf1));
    __hv_line_f(&sLine_64gJ7tKS, VOf(Bf12));
    __hv_mul_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf12), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf12), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf12), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_7b5yGqqk, VIf(Bf6));
    __hv_varread_f(&sVarf_XI9McXIg, VOf(Bf6));
    __hv_line_f(&sLine_PcSQ6FKx, VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf10));
    __hv_sub_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_abs_f(VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf12), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_f5nmAiSL, VIf(Bf6));
    __hv_varwrite_f(&sVarf_SoCHF71H, VIf(Bf4));
    __hv_varwrite_f(&sVarf_gSxOzEVH, VIf(Bf0));
    __hv_varread_f(&sVarf_xKR11wq8, VOf(Bf0));
    __hv_varread_f(&sVarf_YYpfE8vd, VOf(Bf4));
    __hv_varread_f(&sVarf_9NTS9ehV, VOf(Bf6));
    __hv_varread_f(&sVarf_JPWigo7k, VOf(Bf10));
    __hv_varread_f(&sVarf_sO93V4Uu, VOf(Bf12));
    __hv_varread_f(&sVarf_IkFlSehr, VOf(Bf11));
    __hv_line_f(&sLine_eCfaiA5m, VOf(Bf1));
    __hv_line_f(&sLine_ejDWa4FM, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf10));
    __hv_fma_f(VIf(Bf6), VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_9NTS9ehV, VIf(Bf0));
    __hv_varwrite_f(&sVarf_sO93V4Uu, VIf(Bf4));
    __hv_varread_f(&sVarf_DRs3ztqL, VOf(Bf1));
    __hv_varread_f(&sVarf_fCQUxXof, VOf(Bf12));
    __hv_varread_f(&sVarf_b0zUknuW, VOf(Bf11));
    __hv_varread_f(&sVarf_zGtH5SIP, VOf(Bf6));
    __hv_varread_f(&sVarf_cejG6Nlk, VOf(Bf7));
    __hv_varread_f(&sVarf_yf2giuu7, VOf(Bf13));
    __hv_varread_f(&sVarf_TgtUX2gs, VOf(Bf15));
    __hv_varwrite_f(&sVarf_9KxqXH6s, VIf(Bf0));
    __hv_varread_f(&sVarf_zml5aHWa, VOf(Bf2));
    __hv_line_f(&sLine_okPYuU48, VOf(Bf17));
    __hv_mul_f(VIf(Bf2), VIf(Bf17), VOf(Bf17));
    __hv_varread_f(&sVarf_ug7gKEy7, VOf(Bf18));
    __hv_line_f(&sLine_R7azneKs, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_rxbgbOjV, VOf(Bf17));
    __hv_line_f(&sLine_PMHA5GTN, VOf(Bf14));
    __hv_mul_f(VIf(Bf17), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_varwrite_f(&sVarf_zGtH5SIP, VIf(Bf14));
    __hv_varread_f(&sVarf_9KxqXH6s, VOf(Bf14));
    __hv_line_f(&sLine_69WkWKvF, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_eaJZyw5k, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_Qz7dTHu5, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_cejG6Nlk, VIf(Bf16));
    __hv_line_f(&sLine_WOqcMuL3, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_YkYXmOHe, VOf(Bf19));
    __hv_mul_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_L5WK36Ua, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_yf2giuu7, VIf(Bf16));
    __hv_line_f(&sLine_FqWXKSmt, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_nrHpvxkH, VOf(Bf14));
    __hv_mul_f(VIf(Bf18), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_line_f(&sLine_UYaDsbfU, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_TgtUX2gs, VIf(Bf16));
    __hv_varwrite_f(&sVarf_zml5aHWa, VIf(Bf1));
    __hv_varwrite_f(&sVarf_ug7gKEy7, VIf(Bf12));
    __hv_varwrite_f(&sVarf_rxbgbOjV, VIf(Bf11));
    sEnv_process(this, &sEnv_vcgZ2LL6, VIf(Bf6), &sEnv_vcgZ2LL6_sendMessage);
    sEnv_process(this, &sEnv_JIyREpcF, VIf(Bf0), &sEnv_JIyREpcF_sendMessage);
    __hv_line_f(&sLine_BpRSXwHJ, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_PaRdogbl, VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_V4LoWqTS, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_T7UcQyBo, VOf(Bf6));
    __hv_line_f(&sLine_T4I8O7Mc, VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_DRs3ztqL, VIf(Bf12));
    __hv_varwrite_f(&sVarf_T7UcQyBo, VIf(Bf7));
    __hv_varwrite_f(&sVarf_MIxuz5pw, VIf(Bf13));
    __hv_varwrite_f(&sVarf_SSlweyh4, VIf(Bf15));
    __hv_varread_f(&sVarf_SSlweyh4, VOf(Bf15));
    __hv_line_f(&sLine_2fnAS4nS, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf13), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf15), VIf(Bf7), VOf(Bf12));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf15), VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_b0zUknuW, VIf(Bf7));
    __hv_varread_f(&sVarf_MIxuz5pw, VOf(Bf7));
    __hv_line_f(&sLine_Wpj6s014, VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf7), VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf12));
    __hv_sub_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_abs_f(VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf13), VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_neg_f(VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_fCQUxXof, VIf(Bf7));
    __hv_varwrite_f(&sVarf_JPWigo7k, VIf(Bf0));
    __hv_varread_f(&sVarf_cLq7k8qF, VOf(Bf0));
    __hv_varread_f(&sVarf_FPSX6p5b, VOf(Bf7));
    __hv_varread_f(&sVarf_CeoHOFM9, VOf(Bf12));
    __hv_varread_f(&sVarf_EuvKND7z, VOf(Bf13));
    __hv_varread_f(&sVarf_aCmEaCB8, VOf(Bf6));
    __hv_varread_f(&sVarf_zT3dEssM, VOf(Bf15));
    __hv_varread_f(&sVarf_f2xbb8gy, VOf(Bf11));
    __hv_varwrite_f(&sVarf_2UuEqcD9, VIf(Bf4));
    __hv_varread_f(&sVarf_ckIr5NfA, VOf(Bf1));
    __hv_line_f(&sLine_WsMcg8UO, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_m0eubqHj, VOf(Bf14));
    __hv_line_f(&sLine_aomvCmHE, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_CCruBUQt, VOf(Bf16));
    __hv_line_f(&sLine_XEcftdHw, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_varwrite_f(&sVarf_EuvKND7z, VIf(Bf18));
    __hv_varread_f(&sVarf_2UuEqcD9, VOf(Bf18));
    __hv_line_f(&sLine_Pkc45DKp, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_ysAZcFxE, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_GLKdnCcg, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_aCmEaCB8, VIf(Bf2));
    __hv_line_f(&sLine_TACRu5EH, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_hN4Pls2d, VOf(Bf19));
    __hv_mul_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_J19F3H07, VOf(Bf2));
    __hv_mul_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_zT3dEssM, VIf(Bf2));
    __hv_line_f(&sLine_q2AwyQW0, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_6MxNGPwW, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_rIE7SRqP, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_f2xbb8gy, VIf(Bf2));
    __hv_varwrite_f(&sVarf_ckIr5NfA, VIf(Bf0));
    __hv_varwrite_f(&sVarf_m0eubqHj, VIf(Bf7));
    __hv_varwrite_f(&sVarf_CCruBUQt, VIf(Bf12));
    sEnv_process(this, &sEnv_1dPjBiEk, VIf(Bf13), &sEnv_1dPjBiEk_sendMessage);
    sEnv_process(this, &sEnv_enKgWCs2, VIf(Bf4), &sEnv_enKgWCs2_sendMessage);
    __hv_line_f(&sLine_rkz0pLsA, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_07yhCwhI, VOf(Bf13));
    __hv_mul_f(VIf(Bf4), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_6VoHkq2m, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_vv5iwHZm, VOf(Bf13));
    __hv_line_f(&sLine_y3Ps1lHi, VOf(Bf12));
    __hv_var_k_f(VOf(Bf7), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf13), VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_div_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_cLq7k8qF, VIf(Bf7));
    __hv_varwrite_f(&sVarf_vv5iwHZm, VIf(Bf6));
    __hv_varwrite_f(&sVarf_2QMMPMjs, VIf(Bf15));
    __hv_varwrite_f(&sVarf_fc9KDPDS, VIf(Bf11));
    __hv_varread_f(&sVarf_fc9KDPDS, VOf(Bf11));
    __hv_line_f(&sLine_MgGaFfPB, VOf(Bf15));
    __hv_mul_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf11), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf15), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf15), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_mul_f(VIf(Bf15), VIf(Bf15), VOf(Bf11));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf11), VIf(Bf6), VOf(Bf7));
    __hv_var_k_f(VOf(Bf13), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf11), VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf15), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_CeoHOFM9, VIf(Bf6));
    __hv_varread_f(&sVarf_2QMMPMjs, VOf(Bf6));
    __hv_line_f(&sLine_7ue3O4bS, VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf7));
    __hv_sub_f(VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_abs_f(VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf15), VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_FPSX6p5b, VIf(Bf6));
    __hv_varwrite_f(&sVarf_IkFlSehr, VIf(Bf4));
    __hv_varwrite_f(&sVarf_iFMk81KR, VIf(Bf10));
    __hv_varread_f(&sVarf_BDdpu7ib, VOf(Bf10));
    __hv_varread_f(&sVarf_4LCaiTDf, VOf(Bf4));
    __hv_varread_f(&sVarf_W6iEKoY7, VOf(Bf6));
    __hv_varread_f(&sVarf_xT9XsFaX, VOf(Bf7));
    __hv_varread_f(&sVarf_5DlaoNim, VOf(Bf15));
    __hv_varread_f(&sVarf_C2UMUZIV, VOf(Bf13));
    __hv_line_f(&sLine_zhUtgIM3, VOf(Bf11));
    __hv_line_f(&sLine_SIm3w3Ih, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf11), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf15), VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_W6iEKoY7, VIf(Bf10));
    __hv_varwrite_f(&sVarf_5DlaoNim, VIf(Bf4));
    __hv_varread_f(&sVarf_YOZs2DVd, VOf(Bf11));
    __hv_varread_f(&sVarf_3MLa2HWK, VOf(Bf15));
    __hv_varread_f(&sVarf_RcT1jPL8, VOf(Bf13));
    __hv_varread_f(&sVarf_6WIvKO1X, VOf(Bf6));
    __hv_varread_f(&sVarf_kOOZrFhP, VOf(Bf0));
    __hv_varread_f(&sVarf_JrDnlNHO, VOf(Bf2));
    __hv_varread_f(&sVarf_qITs2nKH, VOf(Bf18));
    __hv_varwrite_f(&sVarf_VLyKH5JU, VIf(Bf10));
    __hv_varread_f(&sVarf_iYTnRa6G, VOf(Bf1));
    __hv_line_f(&sLine_yH6wYZhb, VOf(Bf14));
    __hv_mul_f(VIf(Bf1), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_8dLzlYVj, VOf(Bf19));
    __hv_line_f(&sLine_lr0LSgxU, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_MMxWYGzI, VOf(Bf14));
    __hv_line_f(&sLine_yp0LMf3D, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_6WIvKO1X, VIf(Bf17));
    __hv_varread_f(&sVarf_VLyKH5JU, VOf(Bf17));
    __hv_line_f(&sLine_9tgs0eVw, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_yk1lRhWZ, VOf(Bf20));
    __hv_mul_f(VIf(Bf14), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_asrZ7lxw, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_kOOZrFhP, VIf(Bf16));
    __hv_line_f(&sLine_DbZY1k9p, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_nuzbB8h7, VOf(Bf20));
    __hv_mul_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_Gso6HGdm, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_JrDnlNHO, VIf(Bf16));
    __hv_line_f(&sLine_8nHhH0J2, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_65cMgABG, VOf(Bf17));
    __hv_mul_f(VIf(Bf19), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_C1CpC1Ef, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_qITs2nKH, VIf(Bf16));
    __hv_varwrite_f(&sVarf_iYTnRa6G, VIf(Bf11));
    __hv_varwrite_f(&sVarf_8dLzlYVj, VIf(Bf15));
    __hv_varwrite_f(&sVarf_MMxWYGzI, VIf(Bf13));
    sEnv_process(this, &sEnv_FqfYkyAB, VIf(Bf6), &sEnv_FqfYkyAB_sendMessage);
    sEnv_process(this, &sEnv_Ji0eJU6W, VIf(Bf10), &sEnv_Ji0eJU6W_sendMessage);
    __hv_line_f(&sLine_qNa9P7QN, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_IukNwyPa, VOf(Bf6));
    __hv_mul_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_JtA5RVrk, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_lPTUjxxA, VOf(Bf6));
    __hv_line_f(&sLine_lBf3Oew8, VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_YOZs2DVd, VIf(Bf15));
    __hv_varwrite_f(&sVarf_lPTUjxxA, VIf(Bf0));
    __hv_varwrite_f(&sVarf_18XO6nvd, VIf(Bf2));
    __hv_varwrite_f(&sVarf_9nNyWmk3, VIf(Bf18));
    __hv_varread_f(&sVarf_9nNyWmk3, VOf(Bf18));
    __hv_line_f(&sLine_ZLla85wY, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf18), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf2), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf18), VIf(Bf0), VOf(Bf15));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf18), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_RcT1jPL8, VIf(Bf0));
    __hv_varread_f(&sVarf_18XO6nvd, VOf(Bf0));
    __hv_line_f(&sLine_e7eMtbwg, VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf0), VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf15));
    __hv_sub_f(VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_3MLa2HWK, VIf(Bf0));
    __hv_varwrite_f(&sVarf_xT9XsFaX, VIf(Bf10));
    __hv_varread_f(&sVarf_RNGg40al, VOf(Bf10));
    __hv_varread_f(&sVarf_bF81wwx9, VOf(Bf0));
    __hv_varread_f(&sVarf_asIvEpak, VOf(Bf15));
    __hv_varread_f(&sVarf_AquSokwA, VOf(Bf2));
    __hv_varread_f(&sVarf_6I8HNCff, VOf(Bf6));
    __hv_varread_f(&sVarf_t1DNI8Qx, VOf(Bf18));
    __hv_varread_f(&sVarf_JvNoxnd6, VOf(Bf13));
    __hv_varwrite_f(&sVarf_p3YIGcOF, VIf(Bf4));
    __hv_varread_f(&sVarf_J23k8DWH, VOf(Bf11));
    __hv_line_f(&sLine_fHQFuWGv, VOf(Bf16));
    __hv_mul_f(VIf(Bf11), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_15HeWC4S, VOf(Bf17));
    __hv_line_f(&sLine_CCRHszti, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_BWLUurPE, VOf(Bf16));
    __hv_line_f(&sLine_zXwH0fOf, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_varwrite_f(&sVarf_AquSokwA, VIf(Bf19));
    __hv_varread_f(&sVarf_p3YIGcOF, VOf(Bf19));
    __hv_line_f(&sLine_77cbYjrW, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_OC57oWxP, VOf(Bf20));
    __hv_mul_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_pYemoRag, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_6I8HNCff, VIf(Bf1));
    __hv_line_f(&sLine_Agu4Knfp, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_KrFrWn1R, VOf(Bf20));
    __hv_mul_f(VIf(Bf11), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_2b3hOLJC, VOf(Bf1));
    __hv_mul_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_t1DNI8Qx, VIf(Bf1));
    __hv_line_f(&sLine_VX3Jzxxd, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_p7r21KzS, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_aYmJYLQG, VOf(Bf1));
    __hv_mul_f(VIf(Bf11), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_JvNoxnd6, VIf(Bf1));
    __hv_varwrite_f(&sVarf_J23k8DWH, VIf(Bf10));
    __hv_varwrite_f(&sVarf_15HeWC4S, VIf(Bf0));
    __hv_varwrite_f(&sVarf_BWLUurPE, VIf(Bf15));
    sEnv_process(this, &sEnv_KfxuD6TR, VIf(Bf2), &sEnv_KfxuD6TR_sendMessage);
    sEnv_process(this, &sEnv_fiGc2qn4, VIf(Bf4), &sEnv_fiGc2qn4_sendMessage);
    __hv_line_f(&sLine_X5XYuGDA, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_zS1cQmAk, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_FeTzf2sk, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_ZaPMLG49, VOf(Bf2));
    __hv_line_f(&sLine_qKQvoe99, VOf(Bf15));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf2), VIf(Bf0), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_div_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_RNGg40al, VIf(Bf0));
    __hv_varwrite_f(&sVarf_ZaPMLG49, VIf(Bf6));
    __hv_varwrite_f(&sVarf_K06Dv6mD, VIf(Bf18));
    __hv_varwrite_f(&sVarf_ChLgByKY, VIf(Bf13));
    __hv_varread_f(&sVarf_ChLgByKY, VOf(Bf13));
    __hv_line_f(&sLine_lVdl2olh, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf13), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf18), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_mul_f(VIf(Bf18), VIf(Bf18), VOf(Bf13));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf13), VIf(Bf6), VOf(Bf0));
    __hv_var_k_f(VOf(Bf2), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf13), VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf18), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_asIvEpak, VIf(Bf6));
    __hv_varread_f(&sVarf_K06Dv6mD, VOf(Bf6));
    __hv_line_f(&sLine_fGAaMbC9, VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_floor_f(VIf(Bf18), VOf(Bf0));
    __hv_sub_f(VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_abs_f(VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf18), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_bF81wwx9, VIf(Bf6));
    __hv_varwrite_f(&sVarf_C2UMUZIV, VIf(Bf4));
    __hv_varwrite_f(&sVarf_eSX7Ct8Q, VIf(Bf7));
    __hv_varwrite_f(&sVarf_eR0W3xYR, VIf(Bf8));
    __hv_varwrite_f(&sVarf_d7dCHSaV, VIf(Bf9));
    __hv_varwrite_f(&sVarf_QRPqVnnR, VIf(Bf12));
    __hv_varwrite_f(&sVarf_KmSAnXtT, VIf(Bf3));
    __hv_varwrite_f(&sVarf_oc2lKD8U, VIf(Bf5));
    __hv_varread_f(&sVarf_gSxOzEVH, VOf(Bf5));
    __hv_varread_f(&sVarf_iFMk81KR, VOf(Bf3));
    __hv_varread_f(&sVarf_eSX7Ct8Q, VOf(Bf12));
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf5), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf12), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_eR0W3xYR, VOf(Bf12));
    __hv_varread_f(&sVarf_d7dCHSaV, VOf(Bf5));
    __hv_varread_f(&sVarf_QRPqVnnR, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_M3NGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_M3NGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
